/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_EN_H__
#define __INTERNAL_TERRITORY_NAMES_EN_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_EN[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_EN
        "Vatican|Holy See",
        "Monaco",
        "Gibraltar",
        "Tokelau",
        "Cocos Islands|Keeling Islands",
        "Saint-Barthelemy",
        "Nauru",
        "Tuvalu",
        "Macau|Aomen",
        "Sint Maarten",
        "Saint Martin",
        "Norfolk and Philip Island|Philip Island|Norfolk Island",
        "Pitcairn Islands|Pitcairn, Henderson, Ducie and Oeno Islands",
        "Bouvet Island",
        "Bermuda|Somers Isles",
        "British Indian Ocean Territory",
        "San Marino",
        "Guernsey",
        "Anguilla",
        "Montserrat",
        "Jersey",
        "Christmas Island",
        "Wallis and Futuna|Futuna|Wallis",
        "British Virgin Islands|Virgin Islands, British",
        "Liechtenstein",
        "Aruba",
        "Marshall Islands",
        "American Samoa|Samoa, American",
        "Cook Islands",
        "Saint Pierre and Miquelon|Miquelon|Saint Pierre",
        "Niue",
        "Saint Kitts and Nevis|Nevis|Saint Kitts",
        "Cayman islands",
        "Bonaire, St Eustasuis and Saba|Bonaire|Saba|St Eustasius",
        "Maldives",
        "Saint Helena, Ascension and Tristan da Cunha|Saint Helena|Ascension|Tristan da Cunha",
        "Malta",
        "Grenada",
        "Virgin Islands of the United States|US Virgin Islands|American Virgin Islands",
        "Mayotte|Maore",
        "Svalbard and Jan Mayen|Svalbard|Jan Mayen|Spitsbergen",
        "Saint Vincent and the Grenadines|Saint Vincent|Grenadines",
        "Heard Island and McDonald Islands|Heard Island|McDonald Islands",
        "Barbados",
        "Antigua and Barbuda|Antigua|Barbuda",
        "Curacao",
        "Seychelles",
        "Palau",
        "Northern Mariana Islands",
        "Andorra",
        "Guam",
        "Isle of Mann|Mann",
        "Saint Lucia",
        "Micronesia|Federated States of Micronesia",
        "Singapore",
        "Tonga",
        "Dominica",
        "Bahrain",
        "Kiribati",
        "Turks and Caicos Islands|Turks Islands|Caicos Islands",
        "Sao Tome and Principe|Sao Tome|Principe",
        "Hong Kong|Xianggang",
        "Martinique",
        "Faroe Islands",
        "Guadeloupe",
        "Comoros",
        "Mauritius",
        "Reunion",
        "Luxembourg",
        "Samoa",
        "South Georgia and the South Sandwich Islands|South Georgia|South Sandwich Islands",
        "French Polynesia",
        "Cape Verde|Cabo Verde|Republic of Cabo Verde",
        "Trinidad and Tobago|Trinidad|Tobago",
        "Brunei",
        "French Southern and Antarctic Lands",
        "Puerto Rico",
        "Cyprus",
        "Lebanon|Lebanese Republic",
        "Jamaica",
        "Gambia|The Gambia",
        "Qatar",
        "Falkland Islands|The Falklands",
        "Vanuatu",
        "Montenegro",
        "Bahamas",
        "Timor-Leste|East Timor",
        "Swaziland",
        "Kuwait",
        "Fiji",
        "New Caledonia",
        "Slovenia",
        "Israel",
        "Palestinian territories|State of Palestine",
        "El Salvador",
        "Belize",
        "Djibouti",
        "Macedonia|FYROM|Former Yugoslav Republic of Macedonia",
        "Rwanda",
        "Haiti",
        "Burundi",
        "Equatorial Guinea",
        "Albania",
        "Solomon Islands",
        "Armenia",
        "Lesotho",
        "Belgium",
        "Moldova",
        "Guinea-Bissau",
        "Taiwan|Republic of China",
        "Bhutan",
        "Switzerland|Swiss Confederation",
        "Netherlands|The Netherlands",
        "Denmark",
        "Estonia",
        "Dominican Republic",
        "Slovakia|Slovak Republic",
        "Costa Rica",
        "Bosnia and Herzegovina",
        "Croatia",
        "Togo|Togolese Republic",
        "Latvia",
        "Lithuania",
        "Sri Lanka",
        "Georgia",
        "Ireland",
        "Sierra Leone",
        "Panama",
        "Czech Republic",
        "French Guiana|Guiana",
        "United Arab Emirates|Emirates",
        "Austria",
        "Azerbaijan",
        "Serbia",
        "Jordan",
        "Portugal|Portuguese Republic",
        "Hungary",
        "South Korea|Republic of Korea|Korea, South",
        "Iceland",
        "Guatemala",
        "Cuba",
        "Bulgaria",
        "Liberia",
        "Honduras",
        "Benin",
        "Eritrea",
        "Malawi",
        "North Korea|Democratic People's Republic of Korea|Korea, North",
        "Nicaragua",
        "Greece|Hellenic Republic|Hellas",
        "Tajikistan",
        "Bangladesh",
        "Nepal",
        "Tunisia|Tunisian Republic",
        "Suriname",
        "Uruguay",
        "Cambodia",
        "Syria|Syrian Arab Republic",
        "Senegal",
        "Kyrgyzstan|Kyrgyz Republic",
        "Belarus",
        "Guyana",
        "Laos|Lao People's Democratic Republic",
        "Romania",
        "Ghana",
        "Uganda",
        "United Kingdom|Scotland|Great Britain|England|Northern Ireland|Ireland, Northern|Britain|United Kingdom of Great Britain and Northern Ireland",
        "Guinea|Guinea-Conakry",
        "Ecuador",
        "Western Sahara|Sahrawi Arab Democratic Republic",
        "Gabon|Gabonese Republic",
        "New Zealand",
        "Burkina Faso",
        "Philippines",
        "Italy|Italian Republic",
        "Oman",
        "Poland",
        "Ivory Coast|Cote d'Ivoire|Republic of Cote d'Ivoire",
        "Norway",
        "Malaysia",
        "Vietnam",
        "Finland",
        "Congo-Brazzaville|West Congo|Republic of the Congo",
        "Germany",
        "Japan",
        "Zimbabwe",
        "Paraguay",
        "Iraq",
        "Morocco",
        "Uzbekistan",
        "Sweden",
        "Papua New Guinea",
        "Cameroon",
        "Turkmenistan",
        "Spain",
        "Thailand",
        "Yemen",
        "France|French Republic",
        "Aaland Islands",
        "Kenya",
        "Botswana",
        "Madagascar",
        "Ukraine",
        "South Sudan",
        "Central African Republic",
        "Somalia",
        "Afghanistan",
        "Myanmar|Burma",
        "Zambia",
        "Chile",
        "Turkey",
        "Pakistan",
        "Mozambique",
        "Namibia",
        "Venezuela",
        "Nigeria",
        "Tanzania",
        "Egypt",
        "Mauritania",
        "Bolivia",
        "Ethiopia",
        "Colombia",
        "South Africa",
        "Mali",
        "Angola",
        "Niger",
        "Chad",
        "Peru",
        "Mongolia",
        "Iran|Persia",
        "Libya",
        "Sudan",
        "Indonesia",
        "Federal District",
        "Tlaxcala",
        "Morelos",
        "Aguascalientes",
        "Colima",
        "Queretaro",
        "Hidalgo",
        "Mexico State",
        "Tabasco",
        "Nayarit",
        "Guanajuato",
        "Puebla",
        "Yucatan",
        "Quintana Roo",
        "Sinaloa",
        "Campeche",
        "Michoacan",
        "San Luis Potosi",
        "Guerrero",
        "Nuevo Leon|New Leon",
        "Baja California",
        "Veracruz",
        "Chiapas",
        "Baja California Sur",
        "Zacatecas",
        "Jalisco",
        "Tamaulipas",
        "Oaxaca",
        "Durango",
        "Coahuila",
        "Sonora",
        "Chihuahua",
        "Greenland",
        "Saudi Arabia",
        "Congo-Kinshasa|Democratic Republic of the Congo|East Congo",
        "Algeria",
        "Kazakhstan",
        "Argentina|Argentine Republic",
        "Daman and Diu",
        "Dadra and Nagar Haveli|Dadra|Nagar Haveli",
        "Chandigarh",
        "Andaman and Nicobar|Andaman|Nicobar",
        "Lakshadweep",
        "Delhi",
        "Meghalaya",
        "Nagaland",
        "Manipur",
        "Tripura",
        "Mizoram",
        "Sikkim",
        "Punjab",
        "Haryana",
        "Arunachal Pradesh",
        "Assam",
        "Bihar",
        "Uttarakhand",
        "Goa",
        "Kerala",
        "Tamil Nadu",
        "Himachal Pradesh",
        "Jammu and Kashmir|Jammu|Kashmir",
        "Chhattisgarh",
        "Jharkhand",
        "Karnataka",
        "Rajasthan",
        "Odisha|Orissa",
        "Gujarat",
        "West Bengal",
        "Madhya Pradesh",
        "Telangana",
        "Andhra Pradesh",
        "Maharashtra",
        "Uttar Pradesh",
        "Puducherry",
        "New South Wales",
        "Australian Capital Territory",
        "Jervis Bay Territory",
        "Northern Territory",
        "South Australia",
        "Tasmania",
        "Victoria",
        "Western Australia",
        "Queensland",
        "Distrito Federal",
        "Sergipe",
        "Alagoas",
        "Rio de Janeiro",
        "Espirito Santo",
        "Rio Grande do Norte",
        "Paraiba",
        "Santa Catarina",
        "Pernambuco",
        "Amapa",
        "Ceara",
        "Acre",
        "Parana",
        "Roraima",
        "Rondonia",
        "Sao Paulo",
        "Piaui",
        "Tocantins",
        "Rio Grande do Sul",
        "Maranhao",
        "Goias",
        "Mato Grosso do Sul",
        "Bahia",
        "Minas Gerais",
        "Mato Grosso",
        "Para",
        "Amazonas",
        "District of Columbia|Washington, D.C.",
        "Rhode Island",
        "Delaware",
        "Connecticut",
        "New Jersey",
        "New Hampshire",
        "Vermont",
        "Massachusetts",
        "Hawaii",
        "Maryland",
        "West Virginia",
        "South Carolina",
        "Maine",
        "Indiana",
        "Kentucky",
        "Tennessee",
        "Virginia",
        "Ohio",
        "Pennsylvania",
        "Mississippi",
        "Louisiana",
        "Alabama",
        "Arkansas",
        "North Carolina",
        "New York",
        "Iowa",
        "Illinois",
        "Georgia",
        "Wisconsin",
        "Florida",
        "Missouri",
        "Oklahoma",
        "North Dakota",
        "Washington",
        "South Dakota",
        "Nebraska",
        "Kansas",
        "Idaho",
        "Utah",
        "Minnesota",
        "Michigan",
        "Wyoming",
        "Oregon",
        "Colorado",
        "Nevada",
        "Arizona",
        "New Mexico",
        "Montana",
        "California",
        "Texas",
        "Alaska",
        "British Columbia",
        "Alberta",
        "Ontario",
        "Quebec",
        "Saskatchewan",
        "Manitoba",
        "Newfoundland and Labrador|Newfoundland|Labrador",
        "New Brunswick",
        "Nova Scotia",
        "Prince Edward Island",
        "Yukon",
        "Northwest Territories",
        "Nunavut",
        "India",
        "Australia",
        "Brazil",
        "USA|United States of America|America",
        "Mexico|United Mexican States",
        "Moscow",
        "Saint Petersburg",
        "Kaliningrad Oblast",
        "Ingushetia",
        "Adygea Republic",
        "North Ossetia-Alania Republic",
        "Kabardino-Balkar Republic",
        "Karachay-Cherkess Republic",
        "Chechen Republic|Chechnya|Ichkeria",
        "Chuvash Republic",
        "Ivanovo Oblast",
        "Lipetsk Oblast",
        "Oryol Oblast",
        "Tula Oblast",
        "Belgorod Oblast",
        "Vladimir Oblast",
        "Kursk Oblast",
        "Kaluga Oblast",
        "Tambov Oblast",
        "Bryansk Oblast",
        "Yaroslavl Oblast",
        "Ryazan Oblast",
        "Astrakhan Oblast",
        "Moscow Oblast",
        "Smolensk Oblast",
        "Dagestan Republic",
        "Voronezh Oblast",
        "Novgorod Oblast",
        "Pskov Oblast",
        "Kostroma Oblast",
        "Stavropol Krai",
        "Krasnodar Krai",
        "Kalmykia Republic",
        "Tver Oblast",
        "Leningrad Oblast",
        "Rostov Oblast",
        "Volgograd Oblast",
        "Vologda Oblast",
        "Murmansk Oblast",
        "Karelia Republic",
        "Nenets Autonomous Okrug",
        "Komi Republic",
        "Arkhangelsk Oblast",
        "Mordovia Republic",
        "Nizhny Novgorod Oblast",
        "Penza Oblast",
        "Kirov Oblast",
        "Mari El Republic",
        "Orenburg Oblast",
        "Ulyanovsk Oblast",
        "Perm Krai",
        "Bashkortostan Republic",
        "Udmurt Republic",
        "Tatarstan Republic",
        "Samara Oblast",
        "Saratov Oblast",
        "Yamalo-Nenets",
        "Khanty-Mansi",
        "Sverdlovsk Oblast",
        "Tyumen Oblast",
        "Kurgan Oblast",
        "Chelyabinsk Oblast",
        "Buryatia Republic",
        "Zabaykalsky Krai",
        "Irkutsk Oblast",
        "Novosibirsk Oblast",
        "Tomsk Oblast",
        "Omsk Oblast",
        "Khakassia Republic",
        "Kemerovo Oblast",
        "Altai Republic",
        "Altai Krai",
        "Tuva Republic",
        "Krasnoyarsk Krai",
        "Magadan Oblast",
        "Chukotka Okrug",
        "Kamchatka Krai",
        "Sakhalin Oblast",
        "Primorsky Krai",
        "Jewish Autonomous Oblast",
        "Khabarovsk Krai",
        "Amur Oblast",
        "Sakha Republic|Yakutia Republic",
        "Canada",
        "Russia|Russian Federation",
        "Shanghai",
        "Tianjin",
        "Beijing",
        "Hainan",
        "Ningxia Hui",
        "Chongqing",
        "Zhejiang",
        "Jiangsu",
        "Fujian",
        "Anhui",
        "Liaoning",
        "Shandong",
        "Shanxi",
        "Jiangxi",
        "Henan",
        "Guizhou",
        "Guangdong",
        "Hubei",
        "Jilin",
        "Hebei|Yanzhao",
        "Shaanxi",
        "Nei Mongol|Inner Mongolia",
        "Heilongjiang",
        "Hunan",
        "Guangxi Zhuang",
        "Sichuan",
        "Yunnan",
        "Xizang|Tibet",
        "Gansu",
        "Qinghai|Tsinghai",
        "Xinjiang Uyghur",
        "China",
        "United States Minor Outlying Islands",
        "Clipperton Island",
        "Antarctica",
        "International|Worldwide|Earth",
#else // MAPCODE_SUPPORT_LANGUAGE_EN
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_EN
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_EN_H__
