/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_HR_H__
#define __INTERNAL_TERRITORY_NAMES_HR_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_HR[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_HR // Croatian
        /*     VAT */ "Vatikan|Sveta Stolica",
        /*     MCO */ "Monako",
        /*     GIB */ "Gibraltar",
        /*     TKL */ "Tokelau",
        /*     CCK */ "Kokosovi otoci|Keeling otoci",
        /*     BLM */ "Sveti Bartolomej",
        /*     NRU */ "Nauru",
        /*     TUV */ "Tuvalu",
        /*     MAC */ "Makao",
        /*     SXM */ "Sveti Martin NLD",
        /*     MAF */ "Sveti Martin Otok FRA",
        /*     NFK */ "Norfolk i Filip Otoci|Filip Otok",
        /*     PCN */ "Pitcairn otoci",
        /*     BVT */ "Bouvetov otok",
        /*     BMU */ "Bermudi",
        /*     IOT */ "Britanski Indijskooceanski teritorij",
        /*     SMR */ "San Marino",
        /*     GGY */ "Guernsey",
        /*     AIA */ "Anguilla",
        /*     MSR */ "Montserrat",
        /*     JEY */ "Jersey",
        /*     CXR */ "Božićni otok",
        /*     WLF */ "Wallis i Futuna|Futuna",
        /*     VGB */ "Britanski Djevičanski Otoci|Djevičanski Otoci, Britanski",
        /*     LIE */ "Lihtenštajn",
        /*     ABW */ "Aruba",
        /*     MHL */ "Maršalovi Otoci",
        /*     ASM */ "Američka Samoa|Samoa, Američka",
        /*     COK */ "Cookovi otoci",
        /*     SPM */ "Sveti Petar i Mikelon|Mikelon",
        /*     NIU */ "Niue",
        /*     KNA */ "Sveti Kristofor i Nevis|Nevis",
        /*     CYM */ "Kajmanski Otoci",
        /*     BES */ "Saba i karipski otoci Bonaire i Sveti Eustazije|Bonaire|Sveti Eustazije",
        /*     MDV */ "Maldivi",
        /*     SHN */ "Sveta Helena otok, Ascension i Tristan da Cunha|Ascension|Tristan da Cunha",
        /*     MLT */ "Malta",
        /*     GRD */ "Grenada",
        /*     VIR */ "SAD Djevičanski otoci|Djevičanski otoci, SAD",
        /*     MYT */ "Mayotte",
        /*     SJM */ "Svalbard i Jan Mayen|Jan Mayen",
        /*     VCT */ "Sveti Vincent i Grenadini|Grenadini",
        /*     HMD */ "Otok Heard i otočje McDonald|Otočje McDonald",
        /*     BRB */ "Barbados",
        /*     ATG */ "Antigva i Barbuda|Barbuda",
        /*     CUW */ "Curaçao",
        /*     SYC */ "Sejšeli",
        /*     PLW */ "Palau",
        /*     MNP */ "Sjeverni Marijanski otoci",
        /*     AND */ "Andora",
        /*     GUM */ "Guam",
        /*     IMN */ "Otok Man",
        /*     LCA */ "Sveta Lucija",
        /*     FSM */ "Mikronezija|Savezne Države Mikronezije",
        /*     SGP */ "Singapur",
        /*     TON */ "Tonga",
        /*     DMA */ "Dominika",
        /*     BHR */ "Bahrein",
        /*     KIR */ "Kiribati",
        /*     TCA */ "Otoci Turks i Caicos|Otoki Caicos",
        /*     STP */ "Sveti Toma i Princip|Princip",
        /*     HKG */ "Hong Kong",
        /*     MTQ */ "Martinique",
        /*     FRO */ "Farski Otoci",
        /*     GLP */ "Gvadalupe",
        /*     COM */ "Komori",
        /*     MUS */ "Mauricijus",
        /*     REU */ "Réunion Otok",
        /*     LUX */ "Luksemburg",
        /*     WSM */ "Samoa",
        /*     SGS */ "Južna Georgija i otočje Južni Sandwich",
        /*     PYF */ "Francuska Polinezija",
        /*     CPV */ "Zelenortska Republika",
        /*     TTO */ "Trinidad i Tobago|Tobago",
        /*     BRN */ "Brunej",
        /*     ATF */ "Francuski južni i antarktički teritoriji",
        /*     PRI */ "Portoriko",
        /*     CYP */ "Cipar",
        /*     LBN */ "Libanon",
        /*     JAM */ "Jamajka",
        /*     GMB */ "Gambija",
        /*     QAT */ "Katar",
        /*     FLK */ "Falklandski otoci",
        /*     VUT */ "Vanuatu",
        /*     MNE */ "Crna Gora",
        /*     BHS */ "Bahami",
        /*     TLS */ "Istočni Timor",
        /*     SWZ */ "Svazi",
        /*     KWT */ "Kuvajt",
        /*     FJI */ "Fidži",
        /*     NCL */ "Nova Kaledonija",
        /*     SVN */ "Slovenija",
        /*     ISR */ "Izrael",
        /*     PSE */ "Palestina",
        /*     SLV */ "Salvador",
        /*     BLZ */ "Belize",
        /*     DJI */ "Džibuti",
        /*     MKD */ "Makedonija",
        /*     RWA */ "Ruanda",
        /*     HTI */ "Haiti",
        /*     BDI */ "Burundi",
        /*     GNQ */ "Ekvatorijalna Gvineja",
        /*     ALB */ "Albanija",
        /*     SLB */ "Salomonski Otoci",
        /*     ARM */ "Armenija",
        /*     LSO */ "Lesoto",
        /*     BEL */ "Belgija",
        /*     MDA */ "Moldavija",
        /*     GNB */ "Gvineja Bisao",
        /*     TWN */ "Tajvan",
        /*     BTN */ "Butan|Kraljevina Butan",
        /*     CHE */ "Švicarska",
        /*     NLD */ "Nizozemska|Holandija",
        /*     DNK */ "Danska",
        /*     EST */ "Estonija",
        /*     DOM */ "Dominikanska Republika",
        /*     SVK */ "Slovačka",
        /*     CRI */ "Kostarika",
        /*     BIH */ "Bosna i Hercegovina",
        /*     HRV */ "Hrvatska",
        /*     TGO */ "Togo",
        /*     LVA */ "Letonija",
        /*     LTU */ "Litva",
        /*     LKA */ "Šri Lanka",
        /*     GEO */ "Gruzija",
        /*     IRL */ "Irska",
        /*     SLE */ "Sijera Leone",
        /*     PAN */ "Panama",
        /*     CZE */ "Češka Republika",
        /*     GUF */ "Francuska Gvajana",
        /*     ARE */ "Ujedinjeni Arapski Emirati",
        /*     AUT */ "Austrija",
        /*     AZE */ "Azerbejdžan",
        /*     SRB */ "Srbija",
        /*     JOR */ "Jordan",
        /*     PRT */ "Portugal",
        /*     HUN */ "Mađarska",
        /*     KOR */ "Južna Koreja",
        /*     ISL */ "Island",
        /*     GTM */ "Gvatemala",
        /*     CUB */ "Kuba",
        /*     BGR */ "Bugarska",
        /*     LBR */ "Liberija",
        /*     HND */ "Honduras",
        /*     BEN */ "Benin",
        /*     ERI */ "Eritreja",
        /*     MWI */ "Malavi",
        /*     PRK */ "Sjeverna Koreja",
        /*     NIC */ "Nikaragva",
        /*     GRC */ "Grčka",
        /*     TJK */ "Tadžikistan",
        /*     BGD */ "Bangladeš",
        /*     NPL */ "Nepal",
        /*     TUN */ "Tunis",
        /*     SUR */ "Surinam",
        /*     URY */ "Urugvaj",
        /*     KHM */ "Kambodža",
        /*     SYR */ "Sirija",
        /*     SEN */ "Senegal",
        /*     KGZ */ "Kirgistan",
        /*     BLR */ "Bjelorusija",
        /*     GUY */ "Gvajana",
        /*     LAO */ "Laos",
        /*     ROU */ "Rumunjska",
        /*     GHA */ "Gana",
        /*     UGA */ "Uganda",
        /*     GBR */ "Ujedinjeno Kraljevstvo|Velika Britanija|Škotska|Sjeverna Irska|Irska, Sjeverna",
        /*     GIN */ "Gvineja",
        /*     ECU */ "Ekvador",
        /*     ESH */ "Zapadna Sahara",
        /*     GAB */ "Gabon",
        /*     NZL */ "Novi Zeland",
        /*     BFA */ "Burkina Faso",
        /*     PHL */ "Filipini",
        /*     ITA */ "Italija",
        /*     OMN */ "Oman",
        /*     POL */ "Poljska",
        /*     CIV */ "Obala Bjelokosti",
        /*     NOR */ "Norveška",
        /*     MYS */ "Malezija",
        /*     VNM */ "Vijetnam",
        /*     FIN */ "Finska",
        /*     COG */ "Kongo-Brazzaville",
        /*     DEU */ "Njemačka",
        /*     JPN */ "Japan",
        /*     ZWE */ "Zimbabve",
        /*     PRY */ "Paragvaj",
        /*     IRQ */ "Irak",
        /*     MAR */ "Maroko",
        /*     UZB */ "Uzbekistan",
        /*     SWE */ "Švedska",
        /*     PNG */ "Papua Nova Gvineja",
        /*     CMR */ "Kamerun",
        /*     TKM */ "Turkmenistan",
        /*     ESP */ "Španjolska",
        /*     THA */ "Tajland",
        /*     YEM */ "Jemen",
        /*     FRA */ "Francuska",
        /*     ALA */ "Alandski otoci",
        /*     KEN */ "Kenija",
        /*     BWA */ "Bocvana",
        /*     MDG */ "Madagaskar",
        /*     UKR */ "Ukrajina",
        /*     SSD */ "Južni Sudan",
        /*     CAF */ "Srednjoafrička Republika",
        /*     SOM */ "Somalija",
        /*     AFG */ "Afganistan",
        /*     MMR */ "Mianmar|Burma",
        /*     ZMB */ "Zambija",
        /*     CHL */ "Čile",
        /*     TUR */ "Turska",
        /*     PAK */ "Pakistan",
        /*     MOZ */ "Mozambik",
        /*     NAM */ "Namibija",
        /*     VEN */ "Venecuela",
        /*     NGA */ "Nigerija",
        /*     TZA */ "Tanzanija",
        /*     EGY */ "Egipat",
        /*     MRT */ "Mauritanija",
        /*     BOL */ "Bolivija",
        /*     ETH */ "Etiopija",
        /*     COL */ "Kolumbija",
        /*     ZAF */ "Južna Afrika",
        /*     MLI */ "Mali",
        /*     AGO */ "Angola",
        /*     NER */ "Niger",
        /*     TCD */ "Čad",
        /*     PER */ "Peru",
        /*     MNG */ "Mongolija",
        /*     IRN */ "Iran",
        /*     LBY */ "Libija",
        /*     SDN */ "Sudan",
        /*     IDN */ "Indonezija",
        /*     DIF */ "Savezna oblast",
        /*     TLA */ "Tlaxcala",
        /*     MOR */ "Morelos",
        /*     AGU */ "Aguascalientes",
        /*   MX-CL */ "Colima",
        /*     QUE */ "Queretaro",
        /*     HID */ "Hidalgo",
        /*   MX-MX */ "Država Meksiko|Meksiko, Država",
        /*     TAB */ "Tabasco",
        /*     NAY */ "Nayarit",
        /*     GUA */ "Guanajuato",
        /*     PUE */ "Puebla",
        /*     YUC */ "Yucatan",
        /*     ROO */ "Quintana Roo",
        /*     SIN */ "Sinaloa",
        /*     CAM */ "Campeche",
        /*     MIC */ "Michoacan",
        /*     SLP */ "San Luis Potosi",
        /*     GRO */ "Guerrero",
        /*     NLE */ "Nuevo Leon",
        /*     BCN */ "Baja California",
        /*     VER */ "Veracruz",
        /*     CHP */ "Chiapas",
        /*     BCS */ "Baja California Sur",
        /*     ZAC */ "Zacatecas",
        /*     JAL */ "Jalisco",
        /*     TAM */ "Tamaulipas",
        /*     OAX */ "Oaxaca",
        /*     DUR */ "Durango",
        /*     COA */ "Coahuila",
        /*     SON */ "Sonora",
        /*     CHH */ "Chihuahua",
        /*     GRL */ "Grenland",
        /*     SAU */ "Saudijska Arabija",
        /*     COD */ "Kongo-Kinshasa",
        /*     DZA */ "Alžir",
        /*     KAZ */ "Kazahstan",
        /*     ARG */ "Argentina",
        /*   IN-DD */ "Daman and Diu",
        /*   IN-DN */ "Dadra i Nagar Haveli",
        /*   IN-CH */ "Chandigarh",
        /*   IN-AN */ "Andaman and Nicobar",
        /*   IN-LD */ "Lakshadweep",
        /*   IN-DL */ "Delhi",
        /*   IN-ML */ "Meghalaya",
        /*   IN-NL */ "Nagaland",
        /*   IN-MN */ "Manipur",
        /*   IN-TR */ "Tripura",
        /*   IN-MZ */ "Mizoram",
        /*   IN-SK */ "Sikkim",
        /*   IN-PB */ "Punjab",
        /*   IN-HR */ "Haryana",
        /*   IN-AR */ "Arunachal Pradesh",
        /*   IN-AS */ "Assam",
        /*   IN-BR */ "Bihar",
        /*   IN-UT */ "Uttarakhand",
        /*   IN-GA */ "Goa",
        /*   IN-KL */ "Kerala",
        /*   IN-TN */ "Tamil Nadu",
        /*   IN-HP */ "Himachal Pradesh",
        /*   IN-JK */ "Jammu i Kašmir|Kašmir",
        /*   IN-CT */ "Chhattisgarh",
        /*   IN-JH */ "Jharkhand",
        /*   IN-KA */ "Karnataka",
        /*   IN-RJ */ "Rajasthan",
        /*   IN-OR */ "Orissa|Orissa",
        /*   IN-GJ */ "Gujarat",
        /*   IN-WB */ "Zapadni Bengal",
        /*   IN-MP */ "Madhya Pradesh",
        /*   IN-TG */ "Telangana",
        /*   IN-AP */ "Andhra Pradesh",
        /*   IN-MH */ "Maharashtra",
        /*   IN-UP */ "Uttar Pradesh",
        /*   IN-PY */ "Puducherry",
        /*     NSW */ "Novi Južni Wales|New South Wales",
        /*     ACT */ "Australian Capital Territory|Australski Glavni Teritorij",
        /*     JBT */ "Jervis Bay teritorij",
        /*   AU-NT */ "Sjeverni teritorij|Northern Territory",
        /*   AU-SA */ "Južne Australije|South Australia",
        /*     TAS */ "Tasmanija",
        /*     VIC */ "Viktorija",
        /*   AU-WA */ "Zapadna Australija|Western Australia",
        /*     QLD */ "Queensland",
        /*   BR-DF */ "Savezna oblast",
        /*   BR-SE */ "Sergipe",
        /*   BR-AL */ "Alagoas",
        /*   BR-RJ */ "Rio de Janeiro",
        /*   BR-ES */ "Espirito Santo",
        /*   BR-RN */ "Rio Grande do Norte",
        /*   BR-PB */ "Paraiba",
        /*   BR-SC */ "Santa Catarina",
        /*   BR-PE */ "Pernambuco",
        /*   BR-AP */ "Amapa",
        /*   BR-CE */ "Ceara",
        /*   BR-AC */ "Acre",
        /*   BR-PR */ "Parana",
        /*   BR-RR */ "Roraima",
        /*   BR-RO */ "Rondonia",
        /*   BR-SP */ "Sao Paulo",
        /*   BR-PI */ "Piaui",
        /*   BR-TO */ "Tocantins",
        /*   BR-RS */ "Rio Grande do Sul",
        /*   BR-MA */ "Maranhao",
        /*   BR-GO */ "Goias",
        /*   BR-MS */ "Mato Grosso do Sul",
        /*   BR-BA */ "Bahia",
        /*   BR-MG */ "Minas Gerais",
        /*   BR-MT */ "Mato Grosso",
        /*   BR-PA */ "Para",
        /*   BR-AM */ "Amazonas",
        /*   US-DC */ "District of Columbia",
        /*   US-RI */ "Otok Rhode",
        /*   US-DE */ "Delaver",
        /*   US-CT */ "Connecticut",
        /*   US-NJ */ "New Jersey",
        /*   US-NH */ "New Hampshire",
        /*   US-VT */ "Vermont",
        /*   US-MA */ "Massachusetts",
        /*   US-HI */ "Havaji",
        /*   US-MD */ "Maryland",
        /*   US-WV */ "West Virginia",
        /*   US-SC */ "Južna Karolina",
        /*   US-ME */ "Maine",
        /*   US-IN */ "Indijana",
        /*   US-KY */ "Kentucky|Kentaki",
        /*   US-TN */ "Tennessee",
        /*   US-VA */ "Virdžinija",
        /*   US-OH */ "Ohio",
        /*   US-PA */ "Pensilvanija",
        /*   US-MS */ "Misisipi",
        /*   US-LA */ "Louisiana",
        /*   US-AL */ "Alabama",
        /*   US-AR */ "Arkanzas",
        /*   US-NC */ "Sjeverna Karolina",
        /*   US-NY */ "New York",
        /*   US-IA */ "Iowa",
        /*   US-IL */ "Ilinois",
        /*   US-GA */ "Gruzija",
        /*   US-WI */ "Wisconsin",
        /*   US-FL */ "Florida",
        /*   US-MO */ "Missouri",
        /*   US-OK */ "Oklahoma",
        /*   US-ND */ "Sjeverna Dakota",
        /*   US-WA */ "Vašington",
        /*   US-SD */ "Južna Dakota",
        /*   US-NE */ "Nebraska",
        /*   US-KS */ "Kanzas",
        /*   US-ID */ "Ajdaho",
        /*   US-UT */ "Utah",
        /*   US-MN */ "Minnesota",
        /*   US-MI */ "Michigan",
        /*   US-WY */ "Vajoming",
        /*   US-OR */ "Oregon",
        /*   US-CO */ "Kolorado",
        /*   US-NV */ "Nevada",
        /*   US-AZ */ "Arizona",
        /*   US-NM */ "Novi Meksiko",
        /*   US-MT */ "Montana",
        /*   US-CA */ "Kalifornija",
        /*   US-TX */ "Teksas",
        /*   US-AK */ "Aljaska",
        /*   CA-BC */ "Britanska Kolumbija",
        /*   CA-AB */ "Alberta",
        /*   CA-ON */ "Ontario",
        /*   CA-QC */ "Quebec",
        /*   CA-SK */ "Saskatchewan",
        /*   CA-MB */ "Manitoba",
        /*   CA-NL */ "Njufaundlend",
        /*   CA-NB */ "New Brunswick",
        /*   CA-NS */ "Nova Škotska",
        /*   CA-PE */ "Prince Edward Island",
        /*   CA-YT */ "Yukon",
        /*   CA-NT */ "Northwest Territories",
        /*   CA-NU */ "Nunavut",
        /*     IND */ "Indija",
        /*     AUS */ "Australija",
        /*     BRA */ "Brazil",
        /*     USA */ "SAD|Sjedinjene Američke Države|Amerika",
        /*     MEX */ "Meksiko",
        /*     MOW */ "Moskva",
        /*     SPE */ "Saint Petersburg",
        /*     KGD */ "Kalinjingrad oblast",
        /*   RU-IN */ "Ingušetije Republika",
        /*   RU-AD */ "Adigejska Republika",
        /*   RU-SE */ "Sjeverna Osetija-Alanija Republika",
        /*   RU-KB */ "Kabardino-balkar Republika",
        /*   RU-KC */ "Karachay-Čerkezi Republika",
        /*   RU-CE */ "Čečenija Republika",
        /*   RU-CU */ "čuvaški Republika",
        /*     IVA */ "Ivanovska oblast",
        /*     LIP */ "Lipecka oblast",
        /*     ORL */ "Orelska oblast",
        /*     TUL */ "Tula Oblast",
        /*   RU-BE */ "Belgorod oblast",
        /*     VLA */ "Vladimir oblast",
        /*     KRS */ "Kurska oblast",
        /*     KLU */ "Kaluga oblast",
        /*   RU-TT */ "Tambovska oblast",
        /*     BRY */ "Brjanska oblast",
        /*     YAR */ "Yaroslavl Oblast",
        /*     RYA */ "Rjazanjska oblast",
        /*     AST */ "Astrahan oblast",
        /*     MOS */ "Moskovska oblast",
        /*     SMO */ "Smolenska oblast",
        /*   RU-DA */ "Dagestan Republic",
        /*     VOR */ "Voronješka oblast",
        /*     NGR */ "Novgorod oblast",
        /*     PSK */ "Pskovska oblast",
        /*     KOS */ "Kostroma Oblast",
        /*     STA */ "Stavropoljski kraj",
        /*     KDA */ "Krasnodar",
        /*   RU-KL */ "Kalmikiji Republika",
        /*     TVE */ "Tver oblast",
        /*     LEN */ "Leningrad Oblast",
        /*     ROS */ "Rostov oblast",
        /*     VGG */ "Volgograd oblast",
        /*     VLG */ "Vologda Oblast",
        /*     MUR */ "Murmanska oblast",
        /*   RU-KR */ "Karelia Republika",
        /*     NEN */ "Nenečki autonomni okrug",
        /*   RU-KO */ "Komi Republika",
        /*     ARK */ "Arhangelska oblast",
        /*   RU-MO */ "Mordvinska Republika",
        /*     NIZ */ "Nižnjenovgorodska oblast",
        /*     PNZ */ "Penza oblast",
        /*   RU-KI */ "Kirov Oblast",
        /*   RU-ME */ "Mari El Republika",
        /*     ORE */ "Orenburg oblast",
        /*     ULY */ "Uljanovska oblast",
        /*   RU-PM */ "Perm Krai",
        /*   RU-BA */ "Bashkortostan Republika",
        /*   RU-UD */ "Udmurtska Republika",
        /*   RU-TA */ "Tatarstan Republika",
        /*     SAM */ "Samara oblast",
        /*     SAR */ "Saratov oblast",
        /*     YAN */ "Yamalo-Nenets",
        /*   RU-KM */ "Khanty-Mansi",
        /*     SVE */ "Sverdlovsk oblast",
        /*     TYU */ "Tyumen oblast",
        /*     KGN */ "Kurgan oblast",
        /*   RU-CH */ "Chelyabinsk Oblast",
        /*   RU-BU */ "Buryatia Republika",
        /*     ZAB */ "Zabajkalski kraj",
        /*     IRK */ "Irkutsk Oblast",
        /*     NVS */ "Novosibirska oblast",
        /*     TOM */ "Tomska oblast",
        /*     OMS */ "Omska oblast",
        /*   RU-KK */ "Khakassia Republika",
        /*     KEM */ "Kemerovo Oblast",
        /*   RU-AL */ "Altai Republic",
        /*     ALT */ "Altajski kraj",
        /*   RU-TY */ "Tuva Republika",
        /*     KYA */ "Krasnojarsk Krai",
        /*     MAG */ "Magadan oblast",
        /*     CHU */ "Chukotka Okrug",
        /*     KAM */ "Kamčatski kraj",
        /*     SAK */ "Sahalinska oblast",
        /*   RU-PO */ "Primorski kraj",
        /*     YEV */ "Židovska autonomna oblast",
        /*     KHA */ "Khabarovsk Krai",
        /*     AMU */ "Amur oblast",
        /*   RU-SA */ "Jakutska|Yakutia Republika",
        /*     CAN */ "Kanada",
        /*     RUS */ "Ruska Federacija",
        /*   CN-SH */ "Šangaj",
        /*   CN-TJ */ "Tianjin",
        /*   CN-BJ */ "Peking",
        /*   CN-HI */ "Hainan",
        /*   CN-NX */ "Ningxia Hui",
        /*   CN-CQ */ "Chongqing",
        /*   CN-ZJ */ "Zhejiang",
        /*   CN-JS */ "Jiangsu",
        /*   CN-FJ */ "Fujian",
        /*   CN-AH */ "Anhui",
        /*   CN-LN */ "Liaoning",
        /*   CN-SD */ "Shandong",
        /*   CN-SX */ "Shanxi",
        /*   CN-JX */ "Jiangxi",
        /*   CN-HA */ "Henan",
        /*   CN-GZ */ "Guizhou",
        /*   CN-GD */ "Guangdong",
        /*   CN-HB */ "Hubei",
        /*   CN-JL */ "Jilin",
        /*   CN-HE */ "Hebei",
        /*   CN-SN */ "Shaanxi",
        /*   CN-NM */ "Nei Mongol|Inner Mongolia",
        /*   CN-HL */ "Heilongjiang",
        /*   CN-HN */ "Hunan",
        /*   CN-GX */ "Guangxi Zhuang",
        /*   CN-SC */ "Sichuan",
        /*   CN-YN */ "Yunnan",
        /*   CN-XZ */ "Xizang|Tibet",
        /*   CN-GS */ "Gansu",
        /*   CN-QH */ "Qinghai",
        /*   CN-XJ */ "Xinjiang Ujgurski",
        /*     CHN */ "Kina",
        /*     UMI */ "Mali udaljeni otoci SAD-a",
        /*     CPT */ "Otok Clipperton",
        /*     ATA */ "Antarktika",
        /*     AAA */ "International|Svijet|Zemlja"
#else // MAPCODE_SUPPORT_LANGUAGE_HR
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_HR
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_HR_H__
