/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_NO_H__
#define __INTERNAL_TERRITORY_NAMES_NO_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_NO[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_NO // Norwegian
        /*     VAT */ "Vatikanstaten",
        /*     MCO */ "Monaco",
        /*     GIB */ "Gibraltar",
        /*     TKL */ "Tokelau",
        /*     CCK */ "Kokosøyene|Keeling Islands",
        /*     BLM */ "Saint-Barthélemy",
        /*     NRU */ "Nauru",
        /*     TUV */ "Tuvalu",
        /*     MAC */ "Macao",
        /*     SXM */ "Sint Maarten",
        /*     MAF */ "Saint-Martin",
        /*     NFK */ "Norfolkøya|Philip Island",
        /*     PCN */ "Pitcairnøyene",
        /*     BVT */ "Bouvetøya",
        /*     BMU */ "Bermuda",
        /*     IOT */ "Britiske Territoriet i Indiahavet",
        /*     SMR */ "San Marino",
        /*     GGY */ "Guernsey",
        /*     AIA */ "Anguilla",
        /*     MSR */ "Montserrat",
        /*     JEY */ "Jersey",
        /*     CXR */ "Christmasøya",
        /*     WLF */ "Wallis- og Futunaøyene|Futunaøyene",
        /*     VGB */ "Britiske Jomfruøyer|Jomfruøyer, Britiske",
        /*     LIE */ "Liechtenstein",
        /*     ABW */ "Aruba",
        /*     MHL */ "Marshalløyene",
        /*     ASM */ "Amerikansk Samoa|Samoa, Amerikansk",
        /*     COK */ "Cookøyene",
        /*     SPM */ "Saint-Pierre og Miquelon|Miquelon",
        /*     NIU */ "Niue",
        /*     KNA */ "Saint Kitts og Nevis|Nevis",
        /*     CYM */ "Caymanøyene",
        /*     BES */ "Bonaire, Sint Eustatius og Saba|Saba|Sint Eustatius",
        /*     MDV */ "Maldivene",
        /*     SHN */ "Saint Helena, Ascension og Tristan da Cunha|Ascension|Tristan da Cunha",
        /*     MLT */ "Malta",
        /*     GRD */ "Grenada",
        /*     VIR */ "Amerikanske Jomfruøyer|Jomfruøyer, Amerikanske",
        /*     MYT */ "Mayotte",
        /*     SJM */ "Svalbard og Jan Mayen|Jan Mayen",
        /*     VCT */ "Saint Vincent og Grenadinene|Grenadinene",
        /*     HMD */ "Heard- og McDonaldøyene|McDonaldøyene",
        /*     BRB */ "Barbados",
        /*     ATG */ "Antigua og Barbuda|Barbuda",
        /*     CUW */ "Curaçao",
        /*     SYC */ "Seychellene",
        /*     PLW */ "Palau",
        /*     MNP */ "Nord-Marianene",
        /*     AND */ "Andorra",
        /*     GUM */ "Guam",
        /*     IMN */ "Isle of Man",
        /*     LCA */ "Saint Lucia",
        /*     FSM */ "Mikronesiaføderasjonen",
        /*     SGP */ "Singapore",
        /*     TON */ "Tonga",
        /*     DMA */ "Dominica",
        /*     BHR */ "Bahrain",
        /*     KIR */ "Kiribati",
        /*     TCA */ "Turks- og Caicosøyene|Caicosøyene",
        /*     STP */ "São Tomé og Príncipe|Príncipe",
        /*     HKG */ "Hongkong",
        /*     MTQ */ "Martinique",
        /*     FRO */ "Færøyene",
        /*     GLP */ "Guadeloupe",
        /*     COM */ "Komorene",
        /*     MUS */ "Mauritius",
        /*     REU */ "Réunion",
        /*     LUX */ "Luxembourg",
        /*     WSM */ "Samoa",
        /*     SGS */ "Sør-Georgia og Sør-Sandwichøyene|Sør-Sandwichøyene",
        /*     PYF */ "Fransk Polynesia",
        /*     CPV */ "Kapp Verde",
        /*     TTO */ "Trinidad og Tobago|Tobago",
        /*     BRN */ "Brunei",
        /*     ATF */ "Franske Sørterritorier",
        /*     PRI */ "Puerto Rico",
        /*     CYP */ "Kypros",
        /*     LBN */ "Libanon",
        /*     JAM */ "Jamaica",
        /*     GMB */ "Gambia",
        /*     QAT */ "Qatar",
        /*     FLK */ "Falklandsøyene",
        /*     VUT */ "Vanuatu",
        /*     MNE */ "Montenegro",
        /*     BHS */ "Bahamas",
        /*     TLS */ "Øst-Timor",
        /*     SWZ */ "Swaziland",
        /*     KWT */ "Kuwait",
        /*     FJI */ "Fiji",
        /*     NCL */ "Ny-Caledonia",
        /*     SVN */ "Slovenia",
        /*     ISR */ "Israel",
        /*     PSE */ "Palestinske territoriene",
        /*     SLV */ "El Salvador",
        /*     BLZ */ "Belize",
        /*     DJI */ "Djibouti",
        /*     MKD */ "Makedonia",
        /*     RWA */ "Rwanda",
        /*     HTI */ "Haiti",
        /*     BDI */ "Burundi",
        /*     GNQ */ "Ekvatorial-Guinea",
        /*     ALB */ "Albania",
        /*     SLB */ "Salomonøyene",
        /*     ARM */ "Armenia",
        /*     LSO */ "Lesotho",
        /*     BEL */ "Belgia",
        /*     MDA */ "Moldova",
        /*     GNB */ "Guinea-Bissau",
        /*     TWN */ "Taiwan",
        /*     BTN */ "Bhutan",
        /*     CHE */ "Sveits",
        /*     NLD */ "Nederland",
        /*     DNK */ "Danmark",
        /*     EST */ "Estland",
        /*     DOM */ "Dominikanske Republikk",
        /*     SVK */ "Slovakia",
        /*     CRI */ "Costa Rica",
        /*     BIH */ "Bosnia-Hercegovina",
        /*     HRV */ "Kroatia",
        /*     TGO */ "Togo",
        /*     LVA */ "Latvia",
        /*     LTU */ "Litauen",
        /*     LKA */ "Sri Lanka",
        /*     GEO */ "Georgia",
        /*     IRL */ "Irland",
        /*     SLE */ "Sierra Leone",
        /*     PAN */ "Panama",
        /*     CZE */ "Tsjekkia",
        /*     GUF */ "Fransk Guyana",
        /*     ARE */ "Forente Arabiske Emirater",
        /*     AUT */ "Østerrike",
        /*     AZE */ "Aserbajdsjan",
        /*     SRB */ "Serbia",
        /*     JOR */ "Jordan",
        /*     PRT */ "Portugal",
        /*     HUN */ "Ungarn",
        /*     KOR */ "Sør-Korea",
        /*     ISL */ "Island",
        /*     GTM */ "Guatemala",
        /*     CUB */ "Cuba",
        /*     BGR */ "Bulgaria",
        /*     LBR */ "Liberia",
        /*     HND */ "Honduras",
        /*     BEN */ "Benin",
        /*     ERI */ "Eritrea",
        /*     MWI */ "Malawi",
        /*     PRK */ "Nord-Korea",
        /*     NIC */ "Nicaragua",
        /*     GRC */ "Hellas",
        /*     TJK */ "Tadsjikistan",
        /*     BGD */ "Bangladesh",
        /*     NPL */ "Nepal",
        /*     TUN */ "Tunisia",
        /*     SUR */ "Surinam",
        /*     URY */ "Uruguay",
        /*     KHM */ "Kambodsja",
        /*     SYR */ "Syria",
        /*     SEN */ "Senegal",
        /*     KGZ */ "Kirgisistan",
        /*     BLR */ "Hviterussland",
        /*     GUY */ "Guyana",
        /*     LAO */ "Laos",
        /*     ROU */ "Romania",
        /*     GHA */ "Ghana",
        /*     UGA */ "Uganda",
        /*     GBR */ "Storbritannia|Skottland|Nord-Irland|Irland, Nord",
        /*     GIN */ "Guinea",
        /*     ECU */ "Ecuador",
        /*     ESH */ "Vest-Sahara|Saharawiske",
        /*     GAB */ "Gabon",
        /*     NZL */ "Ny-Zealand",
        /*     BFA */ "Burkina Faso",
        /*     PHL */ "Filippinene",
        /*     ITA */ "Italia",
        /*     OMN */ "Oman",
        /*     POL */ "Polen",
        /*     CIV */ "Elfenbenskysten",
        /*     NOR */ "Norge",
        /*     MYS */ "Malaysia",
        /*     VNM */ "Vietnam",
        /*     FIN */ "Finland",
        /*     COG */ "Kongo-Brazzaville|Republikken Kongo",
        /*     DEU */ "Tyskland",
        /*     JPN */ "Japan",
        /*     ZWE */ "Zimbabwe",
        /*     PRY */ "Paraguay",
        /*     IRQ */ "Irak",
        /*     MAR */ "Marokko",
        /*     UZB */ "Usbekistan",
        /*     SWE */ "Sverige",
        /*     PNG */ "Papua Ny-Guinea",
        /*     CMR */ "Kamerun",
        /*     TKM */ "Turkmenistan",
        /*     ESP */ "Spania",
        /*     THA */ "Thailand",
        /*     YEM */ "Jemen",
        /*     FRA */ "Frankrike",
        /*     ALA */ "Åland",
        /*     KEN */ "Kenya",
        /*     BWA */ "Botswana",
        /*     MDG */ "Madagaskar",
        /*     UKR */ "Ukraina",
        /*     SSD */ "Sør-Sudan",
        /*     CAF */ "Den sentralafrikanske republikk",
        /*     SOM */ "Somalia",
        /*     AFG */ "Afghanistan",
        /*     MMR */ "Myanmar|Burma",
        /*     ZMB */ "Zambia",
        /*     CHL */ "Chile",
        /*     TUR */ "Tyrkia",
        /*     PAK */ "Pakistan",
        /*     MOZ */ "Mosambik",
        /*     NAM */ "Namibia",
        /*     VEN */ "Venezuela",
        /*     NGA */ "Nigeria",
        /*     TZA */ "Tanzania",
        /*     EGY */ "Egypt",
        /*     MRT */ "Mauritania",
        /*     BOL */ "Bolivia",
        /*     ETH */ "Etiopia",
        /*     COL */ "Colombia",
        /*     ZAF */ "Sør-Afrika",
        /*     MLI */ "Mali",
        /*     AGO */ "Angola",
        /*     NER */ "Niger",
        /*     TCD */ "Tsjad",
        /*     PER */ "Peru",
        /*     MNG */ "Mongolia",
        /*     IRN */ "Iran",
        /*     LBY */ "Libya",
        /*     SDN */ "Sudan",
        /*     IDN */ "Indonesia",
        /*     DIF */ "Federal District",
        /*     TLA */ "Tlaxcala",
        /*     MOR */ "Morelos",
        /*     AGU */ "Aguascalientes",
        /*   MX-CL */ "Colima",
        /*     QUE */ "Queretaro",
        /*     HID */ "Hidalgo",
        /*   MX-MX */ "Mexico State",
        /*     TAB */ "Tabasco",
        /*     NAY */ "Nayarit",
        /*     GUA */ "Guanajuato",
        /*     PUE */ "Puebla",
        /*     YUC */ "Yucatan",
        /*     ROO */ "Quintana Roo",
        /*     SIN */ "Sinaloa",
        /*     CAM */ "Campeche",
        /*     MIC */ "Michoacan",
        /*     SLP */ "San Luis Potosi",
        /*     GRO */ "Guerrero",
        /*     NLE */ "Nuevo Leon",
        /*     BCN */ "Baja California",
        /*     VER */ "Veracruz",
        /*     CHP */ "Chiapas",
        /*     BCS */ "Baja California Sur",
        /*     ZAC */ "Zacatecas",
        /*     JAL */ "Jalisco",
        /*     TAM */ "Tamaulipas",
        /*     OAX */ "Oaxaca",
        /*     DUR */ "Durango",
        /*     COA */ "Coahuila",
        /*     SON */ "Sonora",
        /*     CHH */ "Chihuahua",
        /*     GRL */ "Grønland",
        /*     SAU */ "Saudi-Arabia",
        /*     COD */ "Kongo-Kinshasa|Demokratiske Republikken Kongo",
        /*     DZA */ "Algerie",
        /*     KAZ */ "Kasakhstan",
        /*     ARG */ "Argentina",
        /*   IN-DD */ "Daman og Diu",
        /*   IN-DN */ "Dadra og Nagar Haveli",
        /*   IN-CH */ "Chandigarh",
        /*   IN-AN */ "Andaman og Nicobar",
        /*   IN-LD */ "Lakshadweep",
        /*   IN-DL */ "Delhi",
        /*   IN-ML */ "Meghalaya",
        /*   IN-NL */ "Nagaland",
        /*   IN-MN */ "Manipur",
        /*   IN-TR */ "Tripura",
        /*   IN-MZ */ "Mizoram",
        /*   IN-SK */ "Sikkim",
        /*   IN-PB */ "Punjab",
        /*   IN-HR */ "Haryana",
        /*   IN-AR */ "Arunachal Pradesh",
        /*   IN-AS */ "Assam",
        /*   IN-BR */ "Bihar",
        /*   IN-UT */ "Uttarakhand",
        /*   IN-GA */ "Goa",
        /*   IN-KL */ "Kerala",
        /*   IN-TN */ "Tamil Nadu",
        /*   IN-HP */ "Himachal Pradesh",
        /*   IN-JK */ "Jammu og Kashmir",
        /*   IN-CT */ "Chhattisgarh",
        /*   IN-JH */ "Jharkhand",
        /*   IN-KA */ "Karnataka",
        /*   IN-RJ */ "Rajasthan",
        /*   IN-OR */ "Odisha|Orissa",
        /*   IN-GJ */ "Gujarat",
        /*   IN-WB */ "Vest-Bengal",
        /*   IN-MP */ "Madhya Pradesh",
        /*   IN-TG */ "Telangana",
        /*   IN-AP */ "Andhra Pradesh",
        /*   IN-MH */ "Maharashtra",
        /*   IN-UP */ "Uttar Pradesh",
        /*   IN-PY */ "Puducherry",
        /*     NSW */ "New South Wales",
        /*     ACT */ "Australian Capital Territory",
        /*     JBT */ "Jervis Bay Territory",
        /*   AU-NT */ "Northern Territory",
        /*   AU-SA */ "South Australia",
        /*     TAS */ "Tasmania",
        /*     VIC */ "Victoria",
        /*   AU-WA */ "Western Australia",
        /*     QLD */ "Queensland",
        /*   BR-DF */ "Distrito Federal",
        /*   BR-SE */ "Sergipe",
        /*   BR-AL */ "Alagoas",
        /*   BR-RJ */ "Rio de Janeiro",
        /*   BR-ES */ "Espirito Santo",
        /*   BR-RN */ "Rio Grande do Norte",
        /*   BR-PB */ "Paraiba",
        /*   BR-SC */ "Santa Catarina",
        /*   BR-PE */ "Pernambuco",
        /*   BR-AP */ "Amapa",
        /*   BR-CE */ "Ceara",
        /*   BR-AC */ "Acre",
        /*   BR-PR */ "Parana",
        /*   BR-RR */ "Roraima",
        /*   BR-RO */ "Rondonia",
        /*   BR-SP */ "São Paulo",
        /*   BR-PI */ "Piaui",
        /*   BR-TO */ "Tocantins",
        /*   BR-RS */ "Rio Grande do Sul",
        /*   BR-MA */ "Maranhao",
        /*   BR-GO */ "Goias",
        /*   BR-MS */ "Mato Grosso do Sul",
        /*   BR-BA */ "Bahia",
        /*   BR-MG */ "Minas Gerais",
        /*   BR-MT */ "Mato Grosso",
        /*   BR-PA */ "Para",
        /*   BR-AM */ "Amazonas",
        /*   US-DC */ "District of Columbia",
        /*   US-RI */ "Rhode Island",
        /*   US-DE */ "Delaware",
        /*   US-CT */ "Connecticut",
        /*   US-NJ */ "New Jersey",
        /*   US-NH */ "New Hampshire",
        /*   US-VT */ "Vermont",
        /*   US-MA */ "Massachusetts",
        /*   US-HI */ "Hawaii",
        /*   US-MD */ "Maryland",
        /*   US-WV */ "Vest-Virginia",
        /*   US-SC */ "Sør-Carolina",
        /*   US-ME */ "Maine",
        /*   US-IN */ "Indiana",
        /*   US-KY */ "Kentucky",
        /*   US-TN */ "Tennessee",
        /*   US-VA */ "Virginia",
        /*   US-OH */ "Ohio",
        /*   US-PA */ "Pennsylvania",
        /*   US-MS */ "Mississippi",
        /*   US-LA */ "Louisiana",
        /*   US-AL */ "Alabama",
        /*   US-AR */ "Arkansas",
        /*   US-NC */ "Nord-Carolina",
        /*   US-NY */ "New York",
        /*   US-IA */ "Iowa",
        /*   US-IL */ "Illinois",
        /*   US-GA */ "Georgia",
        /*   US-WI */ "Wisconsin",
        /*   US-FL */ "Florida",
        /*   US-MO */ "Missouri",
        /*   US-OK */ "Oklahoma",
        /*   US-ND */ "Nord-Dakota",
        /*   US-WA */ "Washington",
        /*   US-SD */ "Sør-Dakota",
        /*   US-NE */ "Nebraska",
        /*   US-KS */ "Kansas",
        /*   US-ID */ "Idaho",
        /*   US-UT */ "Utah",
        /*   US-MN */ "Minnesota",
        /*   US-MI */ "Michigan",
        /*   US-WY */ "Wyoming",
        /*   US-OR */ "Oregon",
        /*   US-CO */ "Colorado",
        /*   US-NV */ "Nevada",
        /*   US-AZ */ "Arizona",
        /*   US-NM */ "New Mexico",
        /*   US-MT */ "Montana",
        /*   US-CA */ "California",
        /*   US-TX */ "Texas",
        /*   US-AK */ "Alaska",
        /*   CA-BC */ "British Columbia",
        /*   CA-AB */ "Alberta",
        /*   CA-ON */ "Ontario",
        /*   CA-QC */ "Quebec",
        /*   CA-SK */ "Saskatchewan",
        /*   CA-MB */ "Manitoba",
        /*   CA-NL */ "Newfoundland",
        /*   CA-NB */ "New Brunswick",
        /*   CA-NS */ "Nova Scotia",
        /*   CA-PE */ "Prince Edward Island",
        /*   CA-YT */ "Yukon",
        /*   CA-NT */ "Northwest Territories",
        /*   CA-NU */ "Nunavut",
        /*     IND */ "India",
        /*     AUS */ "Australia",
        /*     BRA */ "Brasil",
        /*     USA */ "USA|America",
        /*     MEX */ "Mexico",
        /*     MOW */ "Moskva",
        /*     SPE */ "Saint Petersburg",
        /*     KGD */ "Kaliningrad Oblast",
        /*   RU-IN */ "Ingusjetia republikk",
        /*   RU-AD */ "Adygia republikk",
        /*   RU-SE */ "Nord-Ossetia republikk",
        /*   RU-KB */ "Kabardino-Balkar Republic",
        /*   RU-KC */ "Karachay-Cherkess republikk",
        /*   RU-CE */ "Tsjetsjenia",
        /*   RU-CU */ "Chuvash Republic",
        /*     IVA */ "Ivanovo Oblast",
        /*     LIP */ "Lipetsk oblast",
        /*     ORL */ "Oryol Oblast",
        /*     TUL */ "Tula Oblast",
        /*   RU-BE */ "Belgorod Oblast",
        /*     VLA */ "Vladimir Oblast",
        /*     KRS */ "Kursk Oblast",
        /*     KLU */ "Kaluga oblast",
        /*   RU-TT */ "Tambov Oblast",
        /*     BRY */ "Bryansk Oblast",
        /*     YAR */ "Yaroslavl Oblast",
        /*     RYA */ "Ryazan Oblast",
        /*     AST */ "Astrakhan oblast",
        /*     MOS */ "Moscow Oblast",
        /*     SMO */ "Smolensk oblast",
        /*   RU-DA */ "Dagestan republikk",
        /*     VOR */ "Voronezh Oblast",
        /*     NGR */ "Novgorod Oblast",
        /*     PSK */ "Pskov oblast",
        /*     KOS */ "Kostroma oblast",
        /*     STA */ "Stavropol Krai",
        /*     KDA */ "Krasnodar Krai",
        /*   RU-KL */ "Kalmykia republikk",
        /*     TVE */ "Tver Oblast",
        /*     LEN */ "Leningrad Oblast",
        /*     ROS */ "Rostov Oblast",
        /*     VGG */ "Volgograd Oblast",
        /*     VLG */ "Vologda oblast",
        /*     MUR */ "Murmansk Oblast",
        /*   RU-KR */ "Karelia republikk",
        /*     NEN */ "Nenetsk",
        /*   RU-KO */ "Komi Republic",
        /*     ARK */ "Arkhangelsk Oblast",
        /*   RU-MO */ "Mordovia republikk",
        /*     NIZ */ "Nizhny Novgorod Oblast",
        /*     PNZ */ "Penza Oblast",
        /*   RU-KI */ "Kirov Oblast",
        /*   RU-ME */ "Mari El republikk",
        /*     ORE */ "Orenburg Oblast",
        /*     ULY */ "Ulyanovsk Oblast",
        /*   RU-PM */ "Perm Krai",
        /*   RU-BA */ "Bashkortostan republikk",
        /*   RU-UD */ "Udmurt Republic",
        /*   RU-TA */ "Tatarstan republikk",
        /*     SAM */ "Samara Oblast",
        /*     SAR */ "Saratov Oblast",
        /*     YAN */ "Yamalo-Nenets",
        /*   RU-KM */ "Khanty-Mansi",
        /*     SVE */ "Sverdlovsk Oblast",
        /*     TYU */ "Tyumen Oblast",
        /*     KGN */ "Kurgan oblast",
        /*   RU-CH */ "Tsjeljabinsk oblast",
        /*   RU-BU */ "Buryatia republikk",
        /*     ZAB */ "Zabaykalsky Krai",
        /*     IRK */ "Irkutsk Oblast",
        /*     NVS */ "Novosibirsk Oblast",
        /*     TOM */ "Tomsk oblast",
        /*     OMS */ "Omsk Oblast",
        /*   RU-KK */ "Khakassia republikk",
        /*     KEM */ "Kemerovo Oblast",
        /*   RU-AL */ "Altai Republic",
        /*     ALT */ "Altai Krai",
        /*   RU-TY */ "Tuva Republic",
        /*     KYA */ "Krasnoyarsk Krai",
        /*     MAG */ "Magadan Oblast",
        /*     CHU */ "Chukotka Okrug",
        /*     KAM */ "Kamchatka Krai",
        /*     SAK */ "Sakhalin Oblast",
        /*   RU-PO */ "Primorsky Krai",
        /*     YEV */ "Den jødiske autonome oblast",
        /*     KHA */ "Khabarovsk Krai",
        /*     AMU */ "Amur Oblast",
        /*   RU-SA */ "Sakha Republikk|Yakutia republikk",
        /*     CAN */ "Canada",
        /*     RUS */ "Russland",
        /*   CN-SH */ "Shanghai",
        /*   CN-TJ */ "Tianjin",
        /*   CN-BJ */ "Beijing",
        /*   CN-HI */ "Hainan",
        /*   CN-NX */ "Ningxia Hui",
        /*   CN-CQ */ "Chongqing",
        /*   CN-ZJ */ "Zhejiang",
        /*   CN-JS */ "Jiangsu",
        /*   CN-FJ */ "Fujian",
        /*   CN-AH */ "Anhui",
        /*   CN-LN */ "Liaoning",
        /*   CN-SD */ "Shandong",
        /*   CN-SX */ "Shanxi",
        /*   CN-JX */ "Jiangxi",
        /*   CN-HA */ "Henan",
        /*   CN-GZ */ "Guizhou",
        /*   CN-GD */ "Guangdong",
        /*   CN-HB */ "Hubei",
        /*   CN-JL */ "Jilin",
        /*   CN-HE */ "Hebei",
        /*   CN-SN */ "Shaanxi",
        /*   CN-NM */ "Nei Mongol|Indre Mongolia",
        /*   CN-HL */ "Heilongjiang",
        /*   CN-HN */ "Hunan",
        /*   CN-GX */ "Guangxi Zhuang",
        /*   CN-SC */ "Sichuan",
        /*   CN-YN */ "Yunnan",
        /*   CN-XZ */ "Xizang|Tibet",
        /*   CN-GS */ "Gansu",
        /*   CN-QH */ "Qinghai",
        /*   CN-XJ */ "Xinjiang Uyghur",
        /*     CHN */ "Kina",
        /*     UMI */ "USAs ytre småøyer",
        /*     CPT */ "Clippertonøya",
        /*     ATA */ "Antarktis",
        /*     AAA */ "Internasjonal|Verden|Jorden"
#else // MAPCODE_SUPPORT_LANGUAGE_NO
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_NO
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_NO_H__
