/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_UK_H__
#define __INTERNAL_TERRITORY_NAMES_UK_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_UK[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_UK // Ukrainian
        /*     VAT */ "Місто Ватикан|Святий Престол",
        /*     MCO */ "Монако",
        /*     GIB */ "Гібралтар",
        /*     TKL */ "Токелау",
        /*     CCK */ "Кокосові острови|Кілінг острова",
        /*     BLM */ "Сен-Бартельмі",
        /*     NRU */ "Науру",
        /*     TUV */ "Тувалу",
        /*     MAC */ "Макао",
        /*     SXM */ "Сінт-Маартен",
        /*     MAF */ "Сен-Мартен",
        /*     NFK */ "Норфолк і Філіп-Айленд|Філіп-Айленд",
        /*     PCN */ "Піткерн",
        /*     BVT */ "острів Буве",
        /*     BMU */ "Бермудські острови",
        /*     IOT */ "Британська територія в Індійському океані",
        /*     SMR */ "Сан - Маріно",
        /*     GGY */ "Гернсі",
        /*     AIA */ "Ангілья",
        /*     MSR */ "Монсеррат",
        /*     JEY */ "Джерсі",
        /*     CXR */ "острів різдва",
        /*     WLF */ "Уолліс і Футуна|Південна Африка",
        /*     VGB */ "Британські Віргінські острови|Віргінські острови, Британські",
        /*     LIE */ "Ліхтенштейн",
        /*     ABW */ "Аруба",
        /*     MHL */ "Маршаллові острови",
        /*     ASM */ "Американське Самоа|Самоа, Американське",
        /*     COK */ "острови Кука",
        /*     SPM */ "Сен-П`єр і Мікелон|Мікелон",
        /*     NIU */ "Ніуе",
        /*     KNA */ "Сент-Кітс і Невіс|Невіс",
        /*     CYM */ "Кайманові острови",
        /*     BES */ "Бонайре, Сент-Естатіус і Саба|Саба|Сент-Естатіус",
        /*     MDV */ "Мальдіви",
        /*     SHN */ "Святої Єлени, Вознесіння і Трістан-да-Кунья|Вознесіння|Трістан-да-Кунья",
        /*     MLT */ "Мальта",
        /*     GRD */ "Гренада",
        /*     VIR */ "Американські Віргінські острови|Віргінські острови, США",
        /*     MYT */ "Майотта",
        /*     SJM */ "Шпіцберген і Ян-Маєн|Ян-Маєн",
        /*     VCT */ "Сент-Вінсент і Гренадіни|Гренадіни",
        /*     HMD */ "Острів Херд і острови Макдональд|Макдональд",
        /*     BRB */ "Барбадос",
        /*     ATG */ "Антигуа і Барбуда|Барбуда",
        /*     CUW */ "лікер кюрасо",
        /*     SYC */ "Сейшельські острови",
        /*     PLW */ "Палау",
        /*     MNP */ "Північні Маріанські острови",
        /*     AND */ "андорра",
        /*     GUM */ "Гуам",
        /*     IMN */ "Острів Мен",
        /*     LCA */ "Сент-Люсія",
        /*     FSM */ "Мікронезія|Федеративні Штати Мікронезії",
        /*     SGP */ "Сінгапур",
        /*     TON */ "Тонга",
        /*     DMA */ "Домініка",
        /*     BHR */ "Бахрейн",
        /*     KIR */ "Кірібаті",
        /*     TCA */ "Острови Теркс і Кайкос|Кайкос",
        /*     STP */ "Сан-Томе і Прінсіпі|Прінсіпі",
        /*     HKG */ "Гонконг",
        /*     MTQ */ "Мартинюк",
        /*     FRO */ "Фарерські острови",
        /*     GLP */ "Гваделупа",
        /*     COM */ "Коморські острови",
        /*     MUS */ "Маврикій",
        /*     REU */ "возз`єднання",
        /*     LUX */ "Люксембург",
        /*     WSM */ "Самоа",
        /*     SGS */ "Південна Джорджія та Південні Сандвічеві острови|Південні Сандвічеві острови",
        /*     PYF */ "Французька Полінезія",
        /*     CPV */ "Кабо-Верде",
        /*     TTO */ "Тринідад і Тобаго|Тобаго",
        /*     BRN */ "Бруней",
        /*     ATF */ "Французькі Південні та Антарктичні землі",
        /*     PRI */ "Пуерто Ріко",
        /*     CYP */ "Кіпр",
        /*     LBN */ "Ліван",
        /*     JAM */ "Ямайка",
        /*     GMB */ "Гамбія",
        /*     QAT */ "Катар",
        /*     FLK */ "Фолклендські острови",
        /*     VUT */ "Вануату",
        /*     MNE */ "Чорногорія",
        /*     BHS */ "Багамські о-ви",
        /*     TLS */ "східний Тимор",
        /*     SWZ */ "Свазіленд",
        /*     KWT */ "Кувейт",
        /*     FJI */ "Фіджі",
        /*     NCL */ "Нова Каледонія",
        /*     SVN */ "Словенія",
        /*     ISR */ "Ізраїль",
        /*     PSE */ "палестинські території",
        /*     SLV */ "Сальвадор",
        /*     BLZ */ "Беліз",
        /*     DJI */ "Джібуті",
        /*     MKD */ "Македонія",
        /*     RWA */ "Руанда",
        /*     HTI */ "Гаїті",
        /*     BDI */ "Бурунді",
        /*     GNQ */ "Екваторіальна Гвінея",
        /*     ALB */ "Албанія",
        /*     SLB */ "Соломонові острови",
        /*     ARM */ "Вірменія",
        /*     LSO */ "Лесото",
        /*     BEL */ "Бельгія",
        /*     MDA */ "Молдова",
        /*     GNB */ "Гвінея-Бісау",
        /*     TWN */ "Тайвань",
        /*     BTN */ "Бутан",
        /*     CHE */ "Швейцарія",
        /*     NLD */ "Нідерланди",
        /*     DNK */ "Данія",
        /*     EST */ "Естонія",
        /*     DOM */ "Домініканська республіка",
        /*     SVK */ "Словаччина",
        /*     CRI */ "Коста-Ріка",
        /*     BIH */ "Боснія і Герцеговина",
        /*     HRV */ "Хорватія",
        /*     TGO */ "Того",
        /*     LVA */ "Латвія",
        /*     LTU */ "Литва",
        /*     LKA */ "Шрі Ланка",
        /*     GEO */ "Грузія",
        /*     IRL */ "Ірландія",
        /*     SLE */ "Сьєрра-Леоне",
        /*     PAN */ "Панама",
        /*     CZE */ "Чеська Республіка",
        /*     GUF */ "Французька Гвіана",
        /*     ARE */ "Об`єднані Арабські Емірати",
        /*     AUT */ "Австрія",
        /*     AZE */ "Азербайджан",
        /*     SRB */ "Сербія",
        /*     JOR */ "Йорданія",
        /*     PRT */ "Португалія",
        /*     HUN */ "Угорщина",
        /*     KOR */ "Південна Корея",
        /*     ISL */ "Ісландія",
        /*     GTM */ "Гватемала",
        /*     CUB */ "Куба",
        /*     BGR */ "Болгарія",
        /*     LBR */ "Ліберія",
        /*     HND */ "Гондурас",
        /*     BEN */ "Бенін",
        /*     ERI */ "Еритрея",
        /*     MWI */ "Малаві",
        /*     PRK */ "Північна Корея",
        /*     NIC */ "Нікарагуа",
        /*     GRC */ "Греція",
        /*     TJK */ "Таджикистан",
        /*     BGD */ "Бангладеш",
        /*     NPL */ "Непал",
        /*     TUN */ "Туніс",
        /*     SUR */ "Суринам",
        /*     URY */ "Уругвай",
        /*     KHM */ "Камбоджа",
        /*     SYR */ "Сирія",
        /*     SEN */ "Сенегал",
        /*     KGZ */ "Киргизія",
        /*     BLR */ "Білорусь",
        /*     GUY */ "Гайана",
        /*     LAO */ "Лаос",
        /*     ROU */ "Румунія",
        /*     GHA */ "Гана",
        /*     UGA */ "Уганда",
        /*     GBR */ "Сполучене Королівство|Шотландія|Великобританія|Північна Ірландія|Ірландія, Північна",
        /*     GIN */ "Гвінея",
        /*     ECU */ "Еквадор",
        /*     ESH */ "Західна Сахара|сахрави",
        /*     GAB */ "Габон",
        /*     NZL */ "Нова Зеландія",
        /*     BFA */ "Буркіна-Фасо",
        /*     PHL */ "Філіппіни",
        /*     ITA */ "Італія",
        /*     OMN */ "Оман",
        /*     POL */ "Польща",
        /*     CIV */ "Берег Слонової Кістки",
        /*     NOR */ "Норвегія",
        /*     MYS */ "Малайзія",
        /*     VNM */ "В`єтнам",
        /*     FIN */ "Фінляндія",
        /*     COG */ "Конго-Браззавіль",
        /*     DEU */ "Німеччина",
        /*     JPN */ "Японія",
        /*     ZWE */ "Зімбабве",
        /*     PRY */ "Парагвай",
        /*     IRQ */ "Ірак",
        /*     MAR */ "Марокко",
        /*     UZB */ "Узбекистан",
        /*     SWE */ "Швеція",
        /*     PNG */ "Папуа-Нова Гвінея",
        /*     CMR */ "Камерун",
        /*     TKM */ "Туркменістан",
        /*     ESP */ "Іспанія",
        /*     THA */ "Таїланд",
        /*     YEM */ "Ємен",
        /*     FRA */ "Франція",
        /*     ALA */ "Аландські острови",
        /*     KEN */ "Кенія",
        /*     BWA */ "Ботсвана",
        /*     MDG */ "Мадагаскар",
        /*     UKR */ "Україна",
        /*     SSD */ "південний Судан",
        /*     CAF */ "Центрально-Африканська Республіка",
        /*     SOM */ "Сомалі",
        /*     AFG */ "Афганістан",
        /*     MMR */ "М`янма|Бірма",
        /*     ZMB */ "Замбія",
        /*     CHL */ "Чилі",
        /*     TUR */ "Туреччина",
        /*     PAK */ "Пакистан",
        /*     MOZ */ "Мозамбік",
        /*     NAM */ "Намібія",
        /*     VEN */ "Венесуела",
        /*     NGA */ "Нігерія",
        /*     TZA */ "Танзанія",
        /*     EGY */ "Єгипет",
        /*     MRT */ "Мавританія",
        /*     BOL */ "Болівія",
        /*     ETH */ "Ефіопія",
        /*     COL */ "Колумбія",
        /*     ZAF */ "Південна Африка",
        /*     MLI */ "Малі",
        /*     AGO */ "Ангола",
        /*     NER */ "Нігер",
        /*     TCD */ "Чад",
        /*     PER */ "Перу",
        /*     MNG */ "Монголія",
        /*     IRN */ "Іран",
        /*     LBY */ "Лівія",
        /*     SDN */ "Судан",
        /*     IDN */ "Індонезія",
        /*     DIF */ "Федеральний округ",
        /*     TLA */ "Тлашкала",
        /*     MOR */ "Морелос",
        /*     AGU */ "Агуаскальентес",
        /*   MX-CL */ "Коліма",
        /*     QUE */ "Керетаро",
        /*     HID */ "ідальго",
        /*   MX-MX */ "Штат Мексика",
        /*     TAB */ "табаско",
        /*     NAY */ "Наяріт",
        /*     GUA */ "Гуанахуато",
        /*     PUE */ "Пуебла",
        /*     YUC */ "Юкатан",
        /*     ROO */ "Кінтана-Роо",
        /*     SIN */ "Сіналоа",
        /*     CAM */ "Кампече",
        /*     MIC */ "Мічоакан",
        /*     SLP */ "Сан - Луїс-Потосі",
        /*     GRO */ "Герреро",
        /*     NLE */ "Нуево-Леон",
        /*     BCN */ "Нижня Каліфорнія",
        /*     VER */ "Веракрус",
        /*     CHP */ "Чьяпас",
        /*     BCS */ "Південна Нижня Каліфорнія",
        /*     ZAC */ "Сакатекас",
        /*     JAL */ "Халіско",
        /*     TAM */ "Тамауліпас",
        /*     OAX */ "Оахака",
        /*     DUR */ "Дуранго",
        /*     COA */ "Коахуіла",
        /*     SON */ "Сонора",
        /*     CHH */ "чихуахуа",
        /*     GRL */ "Гренландія",
        /*     SAU */ "Саудівська Аравія",
        /*     COD */ "Конго-Кіншаса",
        /*     DZA */ "Алжир",
        /*     KAZ */ "Казахстан",
        /*     ARG */ "Аргентина",
        /*   IN-DD */ "Даман і Діу",
        /*   IN-DN */ "Дадра і Нагархавелі",
        /*   IN-CH */ "Чандігарх",
        /*   IN-AN */ "Андаманські і Нікобарські",
        /*   IN-LD */ "Лакшадвип",
        /*   IN-DL */ "Делі",
        /*   IN-ML */ "Мегхалая",
        /*   IN-NL */ "Нагаленд",
        /*   IN-MN */ "Маніпур",
        /*   IN-TR */ "Тріпура",
        /*   IN-MZ */ "Мізорам",
        /*   IN-SK */ "Сіккім",
        /*   IN-PB */ "Пенджаб",
        /*   IN-HR */ "Харьяна",
        /*   IN-AR */ "Аруначал-Прадеш",
        /*   IN-AS */ "Ассам",
        /*   IN-BR */ "Біхар",
        /*   IN-UT */ "Уттаракханд",
        /*   IN-GA */ "Гоа",
        /*   IN-KL */ "Керала",
        /*   IN-TN */ "Тамілнад",
        /*   IN-HP */ "Хімачал-Прадеш",
        /*   IN-JK */ "Джамму і Кашмір",
        /*   IN-CT */ "Чхаттісгарх",
        /*   IN-JH */ "Джаркханд",
        /*   IN-KA */ "Карнатака",
        /*   IN-RJ */ "Раджастхан",
        /*   IN-OR */ "Орісса",
        /*   IN-GJ */ "Гуджарат",
        /*   IN-WB */ "Західна Бенгалія",
        /*   IN-MP */ "Мадхья-Прадеш",
        /*   IN-TG */ "Телінгани",
        /*   IN-AP */ "Андхра-Прадеш",
        /*   IN-MH */ "Махараштра",
        /*   IN-UP */ "Уттар-Прадеш",
        /*   IN-PY */ "Пондічеррі",
        /*     NSW */ "Новий Південний Уельс",
        /*     ACT */ "Австралійська столична територія",
        /*     JBT */ "Територія Джервіс-Бей",
        /*   AU-NT */ "Північна територія",
        /*   AU-SA */ "Південна Австралія",
        /*     TAS */ "Тасманія",
        /*     VIC */ "Вікторія",
        /*   AU-WA */ "Західна Австралія",
        /*     QLD */ "Квінсленд",
        /*   BR-DF */ "Федеральний округ",
        /*   BR-SE */ "Сержіпі",
        /*   BR-AL */ "Алагоас",
        /*   BR-RJ */ "Ріо-де-Жанейро",
        /*   BR-ES */ "Еспіріту-Санту",
        /*   BR-RN */ "Ріо-Гранде-ду-Норті",
        /*   BR-PB */ "Параїба",
        /*   BR-SC */ "Санта-Катаріна",
        /*   BR-PE */ "Пернамбуку",
        /*   BR-AP */ "Амапа",
        /*   BR-CE */ "Сеара",
        /*   BR-AC */ "Акрі",
        /*   BR-PR */ "Парана",
        /*   BR-RR */ "Рорайма",
        /*   BR-RO */ "Рондонія",
        /*   BR-SP */ "Сан-Паулу",
        /*   BR-PI */ "Піауї",
        /*   BR-TO */ "Токантінс",
        /*   BR-RS */ "Ріо-Гранде-ду-Сул",
        /*   BR-MA */ "Мараньян",
        /*   BR-GO */ "Гояс",
        /*   BR-MS */ "Мату-Гросу-ду-Сул",
        /*   BR-BA */ "Баїя",
        /*   BR-MG */ "Мінас-Жерайс",
        /*   BR-MT */ "Мату-Гросу",
        /*   BR-PA */ "пара",
        /*   BR-AM */ "Амазонас",
        /*   US-DC */ "Федеральний округ Колумбія",
        /*   US-RI */ "Род-Айленд",
        /*   US-DE */ "Делавер",
        /*   US-CT */ "Коннектикут",
        /*   US-NJ */ "Нью Джерсі",
        /*   US-NH */ "Нью-Гемпшир",
        /*   US-VT */ "Вермонт",
        /*   US-MA */ "Массачусетс",
        /*   US-HI */ "Гаваї",
        /*   US-MD */ "Меріленд",
        /*   US-WV */ "Західна Віргінія",
        /*   US-SC */ "Південна Кароліна",
        /*   US-ME */ "Мен",
        /*   US-IN */ "Індіана",
        /*   US-KY */ "Кентуккі",
        /*   US-TN */ "Теннессі",
        /*   US-VA */ "Віргінія",
        /*   US-OH */ "Огайо",
        /*   US-PA */ "Пенсільванія",
        /*   US-MS */ "Міссісіпі",
        /*   US-LA */ "Луїзіана",
        /*   US-AL */ "Алабама",
        /*   US-AR */ "Арканзас",
        /*   US-NC */ "Північна Кароліна",
        /*   US-NY */ "Нью-Йорк",
        /*   US-IA */ "Айова",
        /*   US-IL */ "Іллінойс",
        /*   US-GA */ "Грузія",
        /*   US-WI */ "Вісконсін",
        /*   US-FL */ "Флорида",
        /*   US-MO */ "Міссурі",
        /*   US-OK */ "Оклахома",
        /*   US-ND */ "Північна Дакота",
        /*   US-WA */ "Вашингтон",
        /*   US-SD */ "Південна Дакота",
        /*   US-NE */ "Небраска",
        /*   US-KS */ "Канзас",
        /*   US-ID */ "Айдахо",
        /*   US-UT */ "Юта",
        /*   US-MN */ "Міннесота",
        /*   US-MI */ "Мічиган",
        /*   US-WY */ "Вайомінг",
        /*   US-OR */ "Орегон",
        /*   US-CO */ "Колорадо",
        /*   US-NV */ "Невада",
        /*   US-AZ */ "Арізона",
        /*   US-NM */ "Нью-Мексико",
        /*   US-MT */ "Монтана",
        /*   US-CA */ "Каліфорнія",
        /*   US-TX */ "Техас",
        /*   US-AK */ "Аляска",
        /*   CA-BC */ "Британська Колумбія",
        /*   CA-AB */ "альберта",
        /*   CA-ON */ "Онтаріо",
        /*   CA-QC */ "Квебек",
        /*   CA-SK */ "Саскачеван",
        /*   CA-MB */ "Манітоба",
        /*   CA-NL */ "ньюфаундленд",
        /*   CA-NB */ "Нью-Брансвік",
        /*   CA-NS */ "Нова Шотландія",
        /*   CA-PE */ "Острів Принца Едуарда",
        /*   CA-YT */ "Юкон",
        /*   CA-NT */ "північно-західні території",
        /*   CA-NU */ "Нунавут",
        /*     IND */ "Індія",
        /*     AUS */ "Австралія",
        /*     BRA */ "Бразилія",
        /*     USA */ "США|Сполучені Штати Америки|Америка",
        /*     MEX */ "Мексика",
        /*     MOW */ "Москва",
        /*     SPE */ "Санкт-Петербург",
        /*     KGD */ "Калінінградська область",
        /*   RU-IN */ "Республіка Інгушетія",
        /*   RU-AD */ "Республіка Адигея",
        /*   RU-SE */ "Північна Осетія-Аланія",
        /*   RU-KB */ "Кабардино-Балкарська Республіка",
        /*   RU-KC */ "Карачаєво-Черкеська Республіка",
        /*   RU-CE */ "Чеченська Республіка",
        /*   RU-CU */ "Чуваська Республіка",
        /*     IVA */ "Івановська область",
        /*     LIP */ "Липецька область",
        /*     ORL */ "Орловська область",
        /*     TUL */ "Тульська область",
        /*   RU-BE */ "Бєлгородська область",
        /*     VLA */ "Володимирська область",
        /*     KRS */ "Курська область",
        /*     KLU */ "Калузька область",
        /*   RU-TT */ "Тамбовська область",
        /*     BRY */ "Брянська область",
        /*     YAR */ "Ярославська область",
        /*     RYA */ "Рязанська область",
        /*     AST */ "Астраханська область",
        /*     MOS */ "Московська область",
        /*     SMO */ "Смоленська область",
        /*   RU-DA */ "Республіка Дагестан",
        /*     VOR */ "Воронежская область",
        /*     NGR */ "Новгородська область",
        /*     PSK */ "Псковська область",
        /*     KOS */ "Костромська область",
        /*     STA */ "Ставропольський край",
        /*     KDA */ "Краснодарський край",
        /*   RU-KL */ "Республіка Калмикія",
        /*     TVE */ "Тверська область",
        /*     LEN */ "Ленінградська область",
        /*     ROS */ "Ростовська область",
        /*     VGG */ "Волгоградська область",
        /*     VLG */ "Вологодська область",
        /*     MUR */ "Мурманська область",
        /*   RU-KR */ "Республіка Карелія",
        /*     NEN */ "Ненецький автономний округ",
        /*   RU-KO */ "Республіка Комі",
        /*     ARK */ "Архангельська область",
        /*   RU-MO */ "Республіка Мордовія",
        /*     NIZ */ "Нижегородська область",
        /*     PNZ */ "Пензенська область",
        /*   RU-KI */ "Кіровська область",
        /*   RU-ME */ "Республіка Марій Ел",
        /*     ORE */ "Оренбурзька область",
        /*     ULY */ "Ульяновська область",
        /*   RU-PM */ "Пермський край",
        /*   RU-BA */ "Республіка Башкортостан",
        /*   RU-UD */ "Удмуртська Республіка",
        /*   RU-TA */ "Республіка Татарстан",
        /*     SAM */ "Самарська область",
        /*     SAR */ "Саратовська область",
        /*     YAN */ "Ямало-Ненецький",
        /*   RU-KM */ "Ханти-Мансійський",
        /*     SVE */ "Свердловська область",
        /*     TYU */ "Тюменська область",
        /*     KGN */ "Курганська область",
        /*   RU-CH */ "Челябінська область",
        /*   RU-BU */ "Республіка Бурятія",
        /*     ZAB */ "Забайкальський край",
        /*     IRK */ "Іркутська область",
        /*     NVS */ "Новосибірська область",
        /*     TOM */ "Томська область",
        /*     OMS */ "Омська область",
        /*   RU-KK */ "Республіка Хакасія",
        /*     KEM */ "Кемеровська область",
        /*   RU-AL */ "Республіка Алтай",
        /*     ALT */ "Алтайський край",
        /*   RU-TY */ "Республіка Тива",
        /*     KYA */ "Красноярський край",
        /*     MAG */ "Магаданська область",
        /*     CHU */ "Чукотський округ",
        /*     KAM */ "Камчатський край",
        /*     SAK */ "Сахалінська область",
        /*   RU-PO */ "Приморський край",
        /*     YEV */ "Єврейська автономна область",
        /*     KHA */ "Хабаровський край",
        /*     AMU */ "Амурська область",
        /*   RU-SA */ "Республіка Саха|Якутія",
        /*     CAN */ "Канада",
        /*     RUS */ "Росія",
        /*   CN-SH */ "Шанхай",
        /*   CN-TJ */ "Тяньцзінь",
        /*   CN-BJ */ "Пекін",
        /*   CN-HI */ "Хайнань",
        /*   CN-NX */ "Нінся-Хуейський",
        /*   CN-CQ */ "Чунцин",
        /*   CN-ZJ */ "Чжецзян",
        /*   CN-JS */ "Цзянсу",
        /*   CN-FJ */ "Фуцзянь",
        /*   CN-AH */ "Аньхой",
        /*   CN-LN */ "Ляонін",
        /*   CN-SD */ "Шаньдун",
        /*   CN-SX */ "Шаньсі",
        /*   CN-JX */ "Цзянси",
        /*   CN-HA */ "Хенань",
        /*   CN-GZ */ "Гуйчжоу",
        /*   CN-GD */ "Гуандун",
        /*   CN-HB */ "Хубей",
        /*   CN-JL */ "Цзілінь",
        /*   CN-HE */ "Хебей",
        /*   CN-SN */ "Шеньсі",
        /*   CN-NM */ "Внутрішня Монголія",
        /*   CN-HL */ "Хейлунцзян",
        /*   CN-HN */ "Хунань",
        /*   CN-GX */ "Гуансі-Чжуанський",
        /*   CN-SC */ "Сичуань",
        /*   CN-YN */ "Юньнань",
        /*   CN-XZ */ "Тибетський автономний район|Тибет",
        /*   CN-GS */ "Ганьсу",
        /*   CN-QH */ "Цинхай",
        /*   CN-XJ */ "Синьцзян-Уйгурський",
        /*     CHN */ "Китай",
        /*     UMI */ "США Зовнішні малі острови",
        /*     CPT */ "острів Клиппертон",
        /*     ATA */ "Антарктида",
        /*     AAA */ "Міжнародний|Світ|Земля"
#else // MAPCODE_SUPPORT_LANGUAGE_UK
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_UK
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_UK_H__
