/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_FR_H__
#define __INTERNAL_TERRITORY_NAMES_FR_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_FR[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_FR // French
        /*     VAT */ "Vatican|Cité du Vatican|Saint-Siège",
        /*     MCO */ "Monaco",
        /*     GIB */ "Gibraltar",
        /*     TKL */ "Tokelau",
        /*     CCK */ "Îles Cocos|Îles Keeling",
        /*     BLM */ "Saint-Barthélemy",
        /*     NRU */ "Nauru",
        /*     TUV */ "Tuvalu",
        /*     MAC */ "Macao",
        /*     SXM */ "Saint-Martin|Royaume des Pays-Bas",
        /*     MAF */ "Saint-Martin",
        /*     NFK */ "Norfolk et Phillip Island|Phillip Island",
        /*     PCN */ "Îles Pitcairn",
        /*     BVT */ "Île Bouvet",
        /*     BMU */ "Bermudes",
        /*     IOT */ "Territoire britannique de l`océan Indien",
        /*     SMR */ "Saint-Marin",
        /*     GGY */ "Guernesey",
        /*     AIA */ "Anguilla",
        /*     MSR */ "Montserrat",
        /*     JEY */ "Jersey",
        /*     CXR */ "Île Christmas",
        /*     WLF */ "Wallis et Futuna|Futuna",
        /*     VGB */ "Îles Vierges britanniques",
        /*     LIE */ "Liechtenstein",
        /*     ABW */ "Aruba",
        /*     MHL */ "Îles Marshall",
        /*     ASM */ "Samoa américaines",
        /*     COK */ "Îles Cook",
        /*     SPM */ "Saint-Pierre-et-Miquelon|Miquelon",
        /*     NIU */ "Nioué",
        /*     KNA */ "Saint-Christophe-et-Niévès|Niévès",
        /*     CYM */ "Îles Caïmans",
        /*     BES */ "Bonaire, Saint-Eustache et Saba|Saba|St Eustache",
        /*     MDV */ "Maldives",
        /*     SHN */ "Sainte-Hélène, Ascension et Tristan da Cunha|Ascension|Tristan da Cunha",
        /*     MLT */ "Malte",
        /*     GRD */ "Grenade",
        /*     VIR */ "Îles Vierges américaines",
        /*     MYT */ "Mayotte",
        /*     SJM */ "Svalbard et Jan Mayen|Jan Mayen",
        /*     VCT */ "Saint-Vincent-et-les-Grenadines|Grenadines",
        /*     HMD */ "Île Heard-et-MacDonald|Îles MacDonald",
        /*     BRB */ "Barbade",
        /*     ATG */ "Antigua-et-Barbuda|Barbuda",
        /*     CUW */ "Curaçao",
        /*     SYC */ "Seychelles",
        /*     PLW */ "Palaos",
        /*     MNP */ "Îles Mariannes du Nord",
        /*     AND */ "Andorre",
        /*     GUM */ "Guam",
        /*     IMN */ "Île de Man",
        /*     LCA */ "Sainte-Lucie",
        /*     FSM */ "Micronésie|États fédérés de Micronésie",
        /*     SGP */ "Singapour",
        /*     TON */ "Tonga",
        /*     DMA */ "Dominique",
        /*     BHR */ "Bahreïn",
        /*     KIR */ "Kiribati",
        /*     TCA */ "Îles Turques-et-Caïques|Caïques",
        /*     STP */ "Sao Tomé-et-Principe|Principe",
        /*     HKG */ "Hong Kong",
        /*     MTQ */ "Martinique",
        /*     FRO */ "Îles Féroé",
        /*     GLP */ "Guadeloupe",
        /*     COM */ "Comores",
        /*     MUS */ "Île Maurice",
        /*     REU */ "Réunion",
        /*     LUX */ "Luxembourg",
        /*     WSM */ "Samoa",
        /*     SGS */ "Géorgie du Sud-et-les Îles Sandwich du Sud|Îles Sandwich du Sud",
        /*     PYF */ "Polynésie française",
        /*     CPV */ "Cap-Vert",
        /*     TTO */ "Trinité-et-Tobago|Tobago",
        /*     BRN */ "Brunei",
        /*     ATF */ "Terres australes et antarctiques françaises",
        /*     PRI */ "Puerto Rico",
        /*     CYP */ "Chypre",
        /*     LBN */ "Liban",
        /*     JAM */ "Jamaïque",
        /*     GMB */ "Gambie",
        /*     QAT */ "Qatar",
        /*     FLK */ "Îles Falkland",
        /*     VUT */ "Vanuatu",
        /*     MNE */ "Monténégro",
        /*     BHS */ "Bahamas",
        /*     TLS */ "Timor oriental",
        /*     SWZ */ "Swaziland",
        /*     KWT */ "Koweït",
        /*     FJI */ "Îles Fidji",
        /*     NCL */ "Nouvelle-Calédonie",
        /*     SVN */ "Slovénie",
        /*     ISR */ "Israël",
        /*     PSE */ "Territoires palestiniens",
        /*     SLV */ "Salvador",
        /*     BLZ */ "Belize",
        /*     DJI */ "Djibouti",
        /*     MKD */ "Macédoine",
        /*     RWA */ "Rwanda",
        /*     HTI */ "Haïti",
        /*     BDI */ "Burundi",
        /*     GNQ */ "Guinée équatoriale",
        /*     ALB */ "Albanie",
        /*     SLB */ "Îles Salomon",
        /*     ARM */ "Arménie",
        /*     LSO */ "Lesotho",
        /*     BEL */ "Belgique",
        /*     MDA */ "Moldavie",
        /*     GNB */ "Guinée-Bissau",
        /*     TWN */ "Taiwan",
        /*     BTN */ "Bhoutan",
        /*     CHE */ "Suisse",
        /*     NLD */ "Pays-Bas",
        /*     DNK */ "Danemark",
        /*     EST */ "Estonie",
        /*     DOM */ "République dominicaine",
        /*     SVK */ "Slovaquie",
        /*     CRI */ "Costa Rica",
        /*     BIH */ "Bosnie-Herzégovine",
        /*     HRV */ "Croatie",
        /*     TGO */ "Togo",
        /*     LVA */ "Lettonie",
        /*     LTU */ "Lituanie",
        /*     LKA */ "Sri Lanka",
        /*     GEO */ "Géorgie",
        /*     IRL */ "Irlande",
        /*     SLE */ "Sierra Leone",
        /*     PAN */ "Panama",
        /*     CZE */ "République tchèque",
        /*     GUF */ "Guyane française",
        /*     ARE */ "Émirats Arabes Unis",
        /*     AUT */ "Autriche",
        /*     AZE */ "Azerbaïdjan",
        /*     SRB */ "Serbie",
        /*     JOR */ "Jordanie",
        /*     PRT */ "Portugal",
        /*     HUN */ "Hongrie",
        /*     KOR */ "Corée du Sud",
        /*     ISL */ "Islande",
        /*     GTM */ "Guatemala",
        /*     CUB */ "Cuba",
        /*     BGR */ "Bulgarie",
        /*     LBR */ "Libéria",
        /*     HND */ "Honduras",
        /*     BEN */ "Bénin",
        /*     ERI */ "Érythrée",
        /*     MWI */ "Malawi",
        /*     PRK */ "Corée du Nord",
        /*     NIC */ "Nicaragua",
        /*     GRC */ "Grèce",
        /*     TJK */ "Tadjikistan",
        /*     BGD */ "Bangladesh",
        /*     NPL */ "Népal",
        /*     TUN */ "Tunisie",
        /*     SUR */ "Suriname",
        /*     URY */ "Uruguay",
        /*     KHM */ "Cambodge",
        /*     SYR */ "Syrie",
        /*     SEN */ "Sénégal",
        /*     KGZ */ "Kirghizistan",
        /*     BLR */ "Bélarus",
        /*     GUY */ "Guyana",
        /*     LAO */ "Laos",
        /*     ROU */ "Roumanie",
        /*     GHA */ "Ghana",
        /*     UGA */ "Ouganda",
        /*     GBR */ "Royaume-Uni",
        /*     GIN */ "Guinée",
        /*     ECU */ "Équateur",
        /*     ESH */ "Sahara occidental|Sahraoui",
        /*     GAB */ "Gabon",
        /*     NZL */ "Nouvelle-Zélande",
        /*     BFA */ "Burkina Faso",
        /*     PHL */ "Philippines",
        /*     ITA */ "Italie",
        /*     OMN */ "Oman",
        /*     POL */ "Pologne",
        /*     CIV */ "Côte-d`Ivoire",
        /*     NOR */ "Norvège",
        /*     MYS */ "Malaisie",
        /*     VNM */ "Vietnam",
        /*     FIN */ "Finlande",
        /*     COG */ "Congo-Brazzaville",
        /*     DEU */ "Allemagne",
        /*     JPN */ "Japon",
        /*     ZWE */ "Zimbabwe",
        /*     PRY */ "Paraguay",
        /*     IRQ */ "Irak",
        /*     MAR */ "Maroc",
        /*     UZB */ "Ouzbékistan",
        /*     SWE */ "Suède",
        /*     PNG */ "Papouasie-Nouvelle-Guinée",
        /*     CMR */ "Cameroun",
        /*     TKM */ "Turkménistan",
        /*     ESP */ "Espagne",
        /*     THA */ "Thaïlande",
        /*     YEM */ "Yémen",
        /*     FRA */ "France",
        /*     ALA */ "Åland Îles|Aaland",
        /*     KEN */ "Kenya",
        /*     BWA */ "Botswana",
        /*     MDG */ "Madagascar",
        /*     UKR */ "Ukraine",
        /*     SSD */ "Sud-Soudan",
        /*     CAF */ "République centrafricaine",
        /*     SOM */ "Somalie",
        /*     AFG */ "Afghanistan",
        /*     MMR */ "Myanmar|Birmanie",
        /*     ZMB */ "Zambie",
        /*     CHL */ "Chili",
        /*     TUR */ "Turquie",
        /*     PAK */ "Pakistan",
        /*     MOZ */ "Mozambique",
        /*     NAM */ "Namibie",
        /*     VEN */ "Venezuela",
        /*     NGA */ "Nigéria",
        /*     TZA */ "Tanzanie",
        /*     EGY */ "Égypte",
        /*     MRT */ "Mauritanie",
        /*     BOL */ "Bolivie",
        /*     ETH */ "Éthiopie",
        /*     COL */ "Colombie",
        /*     ZAF */ "Afrique du Sud",
        /*     MLI */ "Mali",
        /*     AGO */ "Angola",
        /*     NER */ "Niger",
        /*     TCD */ "Tchad",
        /*     PER */ "Pérou",
        /*     MNG */ "Mongolie",
        /*     IRN */ "Iran",
        /*     LBY */ "Libye",
        /*     SDN */ "Soudan",
        /*     IDN */ "Indonésie",
        /*     DIF */ "District fédéral",
        /*     TLA */ "Tlaxcala",
        /*     MOR */ "Morelos",
        /*     AGU */ "Aguascalientes",
        /*   MX-CL */ "Colima",
        /*     QUE */ "Querétaro",
        /*     HID */ "Hidalgo",
        /*   MX-MX */ "État de Mexico",
        /*     TAB */ "Tabasco",
        /*     NAY */ "Nayarit",
        /*     GUA */ "Guanajuato",
        /*     PUE */ "Puebla",
        /*     YUC */ "Yucatán",
        /*     ROO */ "Quintana Roo",
        /*     SIN */ "Sinaloa",
        /*     CAM */ "Campeche",
        /*     MIC */ "Michoacán",
        /*     SLP */ "San Luis Potosí",
        /*     GRO */ "Guerrero",
        /*     NLE */ "Nuevo León",
        /*     BCN */ "Basse-Californie",
        /*     VER */ "Veracruz",
        /*     CHP */ "Chiapas",
        /*     BCS */ "Basse-Californie du Sud",
        /*     ZAC */ "Zacatecas",
        /*     JAL */ "Jalisco",
        /*     TAM */ "Tamaulipas",
        /*     OAX */ "Oaxaca",
        /*     DUR */ "Durango",
        /*     COA */ "Coahuila",
        /*     SON */ "Sonora",
        /*     CHH */ "Chihuahua",
        /*     GRL */ "Groenland",
        /*     SAU */ "Arabie Saoudite",
        /*     COD */ "Congo-Kinshasa",
        /*     DZA */ "Algérie",
        /*     KAZ */ "Kazakhstan",
        /*     ARG */ "Argentine",
        /*   IN-DD */ "Daman et Diu",
        /*   IN-DN */ "Dadra et Nagar Haveli",
        /*   IN-CH */ "Chandigarh",
        /*   IN-AN */ "Andaman-et-Nicobar",
        /*   IN-LD */ "Lakshadweep",
        /*   IN-DL */ "Delhi",
        /*   IN-ML */ "Meghalaya",
        /*   IN-NL */ "Nagaland",
        /*   IN-MN */ "Manipur",
        /*   IN-TR */ "Tripura",
        /*   IN-MZ */ "Mizoram",
        /*   IN-SK */ "Sikkim",
        /*   IN-PB */ "Pendjab",
        /*   IN-HR */ "Haryana",
        /*   IN-AR */ "Arunachal Pradesh",
        /*   IN-AS */ "Assam",
        /*   IN-BR */ "Bihar",
        /*   IN-UT */ "Uttarakhand",
        /*   IN-GA */ "Goa",
        /*   IN-KL */ "Kerala",
        /*   IN-TN */ "Tamil Nadu",
        /*   IN-HP */ "Himachal Pradesh",
        /*   IN-JK */ "Jammu-et-Cachemire",
        /*   IN-CT */ "Chhattisgarh",
        /*   IN-JH */ "Jharkhand",
        /*   IN-KA */ "Karnataka",
        /*   IN-RJ */ "Rajasthan",
        /*   IN-OR */ "Odisha|Orissa",
        /*   IN-GJ */ "Gujarat",
        /*   IN-WB */ "Bengale-occidental",
        /*   IN-MP */ "Madhya Pradesh",
        /*   IN-TG */ "Telangana",
        /*   IN-AP */ "Andhra Pradesh",
        /*   IN-MH */ "Maharashtra",
        /*   IN-UP */ "Uttar Pradesh",
        /*   IN-PY */ "Pondichéry",
        /*     NSW */ "Nouvelle-Galles du Sud",
        /*     ACT */ "Territoire de la capitale australienne",
        /*     JBT */ "Territoire de la baie de Jervis",
        /*   AU-NT */ "Territoire du Nord",
        /*   AU-SA */ "Australie Méridionale",
        /*     TAS */ "Tasmanie",
        /*     VIC */ "Victoria",
        /*   AU-WA */ "Australie-Occidentale",
        /*     QLD */ "Queensland",
        /*   BR-DF */ "District fédéral",
        /*   BR-SE */ "Sergipe",
        /*   BR-AL */ "Alagoas",
        /*   BR-RJ */ "Rio de Janeiro",
        /*   BR-ES */ "Espírito Santo",
        /*   BR-RN */ "Rio Grande do Norte",
        /*   BR-PB */ "Paraíba",
        /*   BR-SC */ "Santa Catarina",
        /*   BR-PE */ "Pernambouc",
        /*   BR-AP */ "Amapá",
        /*   BR-CE */ "Ceará",
        /*   BR-AC */ "Acre",
        /*   BR-PR */ "Paraná",
        /*   BR-RR */ "Roraima",
        /*   BR-RO */ "Rondônia",
        /*   BR-SP */ "São Paulo",
        /*   BR-PI */ "Piauí",
        /*   BR-TO */ "Tocantins",
        /*   BR-RS */ "Rio Grande do Sul",
        /*   BR-MA */ "Maranhão",
        /*   BR-GO */ "Goiás",
        /*   BR-MS */ "Mato Grosso do Sul",
        /*   BR-BA */ "Bahia",
        /*   BR-MG */ "Minas Gerais",
        /*   BR-MT */ "Mato Grosso",
        /*   BR-PA */ "Para",
        /*   BR-AM */ "Amazonas",
        /*   US-DC */ "District de Columbia",
        /*   US-RI */ "Rhode Island",
        /*   US-DE */ "Delaware",
        /*   US-CT */ "Connecticut",
        /*   US-NJ */ "New Jersey",
        /*   US-NH */ "New Hampshire",
        /*   US-VT */ "Vermont",
        /*   US-MA */ "Massachusetts",
        /*   US-HI */ "Hawaï",
        /*   US-MD */ "Maryland",
        /*   US-WV */ "Virginie-Occidentale",
        /*   US-SC */ "Caroline du Sud",
        /*   US-ME */ "Maine",
        /*   US-IN */ "Indiana",
        /*   US-KY */ "Kentucky",
        /*   US-TN */ "Tennessee",
        /*   US-VA */ "Virginie",
        /*   US-OH */ "Ohio",
        /*   US-PA */ "Pennsylvanie",
        /*   US-MS */ "Mississippi",
        /*   US-LA */ "Louisiane",
        /*   US-AL */ "Alabama",
        /*   US-AR */ "Arkansas",
        /*   US-NC */ "Caroline du Nord",
        /*   US-NY */ "New York",
        /*   US-IA */ "Iowa",
        /*   US-IL */ "Illinois",
        /*   US-GA */ "Géorgie",
        /*   US-WI */ "Wisconsin",
        /*   US-FL */ "Floride",
        /*   US-MO */ "Missouri",
        /*   US-OK */ "Oklahoma",
        /*   US-ND */ "Dakota du Nord",
        /*   US-WA */ "Washington",
        /*   US-SD */ "Dakota du Sud",
        /*   US-NE */ "Nebraska",
        /*   US-KS */ "Kansas",
        /*   US-ID */ "Idaho",
        /*   US-UT */ "Utah",
        /*   US-MN */ "Minnesota",
        /*   US-MI */ "Michigan",
        /*   US-WY */ "Wyoming",
        /*   US-OR */ "Oregon",
        /*   US-CO */ "Colorado",
        /*   US-NV */ "Nevada",
        /*   US-AZ */ "Arizona",
        /*   US-NM */ "Nouveau-Mexique",
        /*   US-MT */ "Montana",
        /*   US-CA */ "Californie",
        /*   US-TX */ "Texas",
        /*   US-AK */ "Alaska",
        /*   CA-BC */ "Colombie-Britannique",
        /*   CA-AB */ "Alberta",
        /*   CA-ON */ "Ontario",
        /*   CA-QC */ "Québec",
        /*   CA-SK */ "Saskatchewan",
        /*   CA-MB */ "Manitoba",
        /*   CA-NL */ "Terre-Neuve",
        /*   CA-NB */ "Nouveau-Brunswick",
        /*   CA-NS */ "Nouvelle-Écosse",
        /*   CA-PE */ "Île-du-Prince-Edward",
        /*   CA-YT */ "Yukon",
        /*   CA-NT */ "Territoires du Nord-Ouest",
        /*   CA-NU */ "Nunavut",
        /*     IND */ "Inde",
        /*     AUS */ "Australie",
        /*     BRA */ "Brésil",
        /*     USA */ "USA|États-Unis d`Amérique|Amérique",
        /*     MEX */ "Mexique",
        /*     MOW */ "Moscou",
        /*     SPE */ "Saint-Pétersbourg",
        /*     KGD */ "Oblast de Kaliningrad",
        /*   RU-IN */ "Ingouchie",
        /*   RU-AD */ "République d’Adyguée",
        /*   RU-SE */ "République d’Ossétie du Nord-Alanie",
        /*   RU-KB */ "Kabardino-Balkarie",
        /*   RU-KC */ "République de Karatchaïévo-Tcherkessie",
        /*   RU-CE */ "République tchétchène",
        /*   RU-CU */ "République de Tchouvachie",
        /*     IVA */ "Oblast d’Ivanovo",
        /*     LIP */ "Oblast de Lipetsk",
        /*     ORL */ "Oblast d’Orel",
        /*     TUL */ "Oblast de Toula",
        /*   RU-BE */ "Oblast de Belgorod",
        /*     VLA */ "Oblast de Vladimir",
        /*     KRS */ "Oblast de Koursk",
        /*     KLU */ "Oblast de Kaluga",
        /*   RU-TT */ "Oblast de Tambov",
        /*     BRY */ "Oblast de Briansk",
        /*     YAR */ "Oblast de Iaroslavl",
        /*     RYA */ "Oblast de Riazan",
        /*     AST */ "Oblast d’Astrakhan",
        /*     MOS */ "Oblast de Moscou",
        /*     SMO */ "Oblast de Smolensk",
        /*   RU-DA */ "République du Daguestan",
        /*     VOR */ "Oblast de Voronej",
        /*     NGR */ "Oblast de Novgorod",
        /*     PSK */ "Oblast de Pskov",
        /*     KOS */ "Oblast de Kostroma",
        /*     STA */ "Kraï de Stavropol",
        /*     KDA */ "Kraï de Krasnodar",
        /*   RU-KL */ "République de Kalmoukie",
        /*     TVE */ "Oblast de Tver",
        /*     LEN */ "Oblast de Léningrad",
        /*     ROS */ "Oblast de Rostov",
        /*     VGG */ "Oblast de Volgograd",
        /*     VLG */ "Oblast de Vologda",
        /*     MUR */ "Oblast de Mourmansk",
        /*   RU-KR */ "République de Carélie",
        /*     NEN */ "District autonome de Nénétsie",
        /*   RU-KO */ "République des Komis",
        /*     ARK */ "Oblast d’Arkhangelsk",
        /*   RU-MO */ "République de Mordovie",
        /*     NIZ */ "Oblast de Nijni Novgorod",
        /*     PNZ */ "Oblast de Penza",
        /*   RU-KI */ "Oblast de Kirov",
        /*   RU-ME */ "République des Maris",
        /*     ORE */ "Oblast d’Orenbourg",
        /*     ULY */ "Oblast d’Oulianovsk",
        /*   RU-PM */ "Kraï de Perm",
        /*   RU-BA */ "République de Bachkirie",
        /*   RU-UD */ "Oudmourtie",
        /*   RU-TA */ "République du Tatarstan",
        /*     SAM */ "Oblast de Samara",
        /*     SAR */ "Oblast de Saratov",
        /*     YAN */ "Iamalo-Nénétsie",
        /*   RU-KM */ "Khantys-Mansis",
        /*     SVE */ "Oblast de Sverdlovsk",
        /*     TYU */ "Oblast de Tioumen",
        /*     KGN */ "Oblast de Kourgan",
        /*   RU-CH */ "Oblast de Tcheliabinsk",
        /*   RU-BU */ "République de Bouriatie",
        /*     ZAB */ "Kraï de Transbaïkalie",
        /*     IRK */ "Oblast d’Irkoutsk",
        /*     NVS */ "Oblast de Novossibirsk",
        /*     TOM */ "Oblast de Tomsk",
        /*     OMS */ "Oblast d’Omsk",
        /*   RU-KK */ "République de Khakassie",
        /*     KEM */ "Oblast de Kemerovo",
        /*   RU-AL */ "République de l’Altaï",
        /*     ALT */ "Kraï de l’Altaï",
        /*   RU-TY */ "République de Touva",
        /*     KYA */ "Kraï de Krasnoïarsk",
        /*     MAG */ "Oblast de Magadan",
        /*     CHU */ "Tchoukotka",
        /*     KAM */ "Kraï du Kamtchatka",
        /*     SAK */ "Oblast de Sakhaline",
        /*   RU-PO */ "Kraï du Krai",
        /*     YEV */ "Oblast autonome juif",
        /*     KHA */ "Kraï de Khabarovsk",
        /*     AMU */ "Oblast d’Amour",
        /*   RU-SA */ "République de Sakha|République de Yakoutie",
        /*     CAN */ "Canada",
        /*     RUS */ "Russie",
        /*   CN-SH */ "Shanghai",
        /*   CN-TJ */ "Tianjin",
        /*   CN-BJ */ "Pékin",
        /*   CN-HI */ "Hainan",
        /*   CN-NX */ "Hui du Ningxia",
        /*   CN-CQ */ "Chongqing",
        /*   CN-ZJ */ "Zhejiang",
        /*   CN-JS */ "Jiangsu",
        /*   CN-FJ */ "Fujian",
        /*   CN-AH */ "Anhui",
        /*   CN-LN */ "Liaoning",
        /*   CN-SD */ "Shandong",
        /*   CN-SX */ "Shanxi",
        /*   CN-JX */ "Jiangxi",
        /*   CN-HA */ "Henan",
        /*   CN-GZ */ "Guizhou",
        /*   CN-GD */ "Guangdong",
        /*   CN-HB */ "Hubei",
        /*   CN-JL */ "Jilin",
        /*   CN-HE */ "Hebei",
        /*   CN-SN */ "Shaanxi",
        /*   CN-NM */ "Mongolie-intérieure",
        /*   CN-HL */ "Heilongjiang",
        /*   CN-HN */ "Hunan",
        /*   CN-GX */ "Région autonome Zhuang du Guangxi",
        /*   CN-SC */ "Sichuan",
        /*   CN-YN */ "Yunnan",
        /*   CN-XZ */ "Xizang|Tibet",
        /*   CN-GS */ "Gansu",
        /*   CN-QH */ "Qinghai",
        /*   CN-XJ */ "Région autonome ouïghoure du Xinjiang",
        /*     CHN */ "Chine",
        /*     UMI */ "Îles mineures éloignées des États-Unis",
        /*     CPT */ "Île de Clipperton",
        /*     ATA */ "Antarctique",
        /*     AAA */ "International|Monde|Terre"
#else // MAPCODE_SUPPORT_LANGUAGE_FR
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_FR
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_FR_H__
