/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_HE_H__
#define __INTERNAL_TERRITORY_NAMES_HE_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_HE[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_HE // Hebrew
        /*     VAT */ "הוותיקן|הכס הקדוש",
        /*     MCO */ "מונקו",
        /*     GIB */ "גיברלטר",
        /*     TKL */ "טוקלאו",
        /*     CCK */ "איי קוקוס|קילינג איי",
        /*     BLM */ "סנט ברתלמי",
        /*     NRU */ "נאורו",
        /*     TUV */ "טובאלו",
        /*     MAC */ "מקאו",
        /*     SXM */ "סן מרטן",
        /*     MAF */ "סנט מרטין אין",
        /*     NFK */ "נורפולק ופיליפ איילנד|פיליפ איילנד",
        /*     PCN */ "איי פיטקרן",
        /*     BVT */ "איי בובה",
        /*     BMU */ "ברמודה",
        /*     IOT */ "טריטוריה בריטית באוקיינוס ​​ההודי",
        /*     SMR */ "סן מרינו",
        /*     GGY */ "גרנזי",
        /*     AIA */ "אנגווילה",
        /*     MSR */ "מונטסראט",
        /*     JEY */ "ג`רזי",
        /*     CXR */ "אי חג המולד",
        /*     WLF */ "ואליס ופוטונה|ופוטונה",
        /*     VGB */ "איי הבתולה הבריטיים|איי הבתולה, בריטניה",
        /*     LIE */ "ליכטנשטיין",
        /*     ABW */ "ארובה",
        /*     MHL */ "איי מרשל",
        /*     ASM */ "סמואה האמריקאית|סמואה, אמריקאי",
        /*     COK */ "איי קוק",
        /*     SPM */ "סנט פייר ומיקלון|ומיקלון",
        /*     NIU */ "ניואה",
        /*     KNA */ "סנט קיטס ונוויס",
        /*     CYM */ "איי קיימן",
        /*     BES */ "בונייר, סנט ואת סבא|סבא",
        /*     MDV */ "האיים המלדיביים",
        /*     SHN */ "סנט הלנה, אסנשן וטריסטן דה קונה|טריסטן דה קונה",
        /*     MLT */ "מלטה",
        /*     GRD */ "גרנדה",
        /*     VIR */ "איי הבתולה של ארצות הברית",
        /*     MYT */ "מיוט",
        /*     SJM */ "סבאלברד ויאן מאיין|יאן מאיין",
        /*     VCT */ "סנט וינסנט והגרנדינים|והגרנדינים",
        /*     HMD */ "שמעתי איילנד ואיי מקדונלד",
        /*     BRB */ "ברבדוס",
        /*     ATG */ "אנטיגואה וברבודה|וברבודה",
        /*     CUW */ "קורסאו",
        /*     SYC */ "סיישל",
        /*     PLW */ "פלאו",
        /*     MNP */ "איי מריאנה הצפוניים",
        /*     AND */ "אנדורה",
        /*     GUM */ "גואם",
        /*     IMN */ "האי מאן",
        /*     LCA */ "סנט לוסיה",
        /*     FSM */ "מיקרונזיה",
        /*     SGP */ "סינגפור",
        /*     TON */ "טונגה",
        /*     DMA */ "דומיניקה",
        /*     BHR */ "בחריין",
        /*     KIR */ "קיריבטי",
        /*     TCA */ "איי טורקס וקאיקוס|וקאיקוס איי",
        /*     STP */ "סאו טומה ופרינסיפה",
        /*     HKG */ "הונג קונג",
        /*     MTQ */ "מרטיניק",
        /*     FRO */ "איי פרו",
        /*     GLP */ "גוואדלופ",
        /*     COM */ "קומורו",
        /*     MUS */ "מאוריציוס",
        /*     REU */ "איחוד",
        /*     LUX */ "לוקסמבורג",
        /*     WSM */ "סמואה",
        /*     SGS */ "ג`ורג`יה הדרומית ואיי סנדוויץ `הדרומיים|ואיי סנדוויץ` הדרומיים",
        /*     PYF */ "פולינזיה הצרפתית",
        /*     CPV */ "קייפ ורדה",
        /*     TTO */ "טרינידד וטובגו|וטובגו",
        /*     BRN */ "ברוניי",
        /*     ATF */ "מקרקעי דרום צרפתים באנטארקטיקה",
        /*     PRI */ "פוארטו ריקו",
        /*     CYP */ "קַפרִיסִין",
        /*     LBN */ "לבנון",
        /*     JAM */ "ג`מייקה",
        /*     GMB */ "גמביה",
        /*     QAT */ "קטאר",
        /*     FLK */ "איי פוקלנד",
        /*     VUT */ "ונואטו",
        /*     MNE */ "מונטנגרו",
        /*     BHS */ "איי בהאמה",
        /*     TLS */ "מזרח טימור",
        /*     SWZ */ "סווזילנד",
        /*     KWT */ "כווית",
        /*     FJI */ "איי פיג`י|פיג`י",
        /*     NCL */ "קלדוניה החדשה",
        /*     SVN */ "סלובניה",
        /*     ISR */ "ישראל",
        /*     PSE */ "השטח הפלסטיני",
        /*     SLV */ "אל סלבדור",
        /*     BLZ */ "בליז",
        /*     DJI */ "ג`יבוטי",
        /*     MKD */ "מוּקדוֹן",
        /*     RWA */ "רואנדה",
        /*     HTI */ "איטי",
        /*     BDI */ "בורונדי",
        /*     GNQ */ "גיניאה המשוונית",
        /*     ALB */ "אלבניה",
        /*     SLB */ "אי שלם",
        /*     ARM */ "אַרְמֶנִיָה",
        /*     LSO */ "לסוטו",
        /*     BEL */ "בלגיה",
        /*     MDA */ "מולדובה",
        /*     GNB */ "גינאה ביסאו",
        /*     TWN */ "טייוואן",
        /*     BTN */ "בהוטן",
        /*     CHE */ "שווייץ",
        /*     NLD */ "הולנד",
        /*     DNK */ "דנמרק",
        /*     EST */ "אסטוניה",
        /*     DOM */ "הרפובליקה הדומיניקנית",
        /*     SVK */ "סלובקיה",
        /*     CRI */ "קוסטה ריקה",
        /*     BIH */ "בוסניה והרצגובינה",
        /*     HRV */ "קרואטיה",
        /*     TGO */ "רפובליקת טוגו",
        /*     LVA */ "לטביה",
        /*     LTU */ "ליטא",
        /*     LKA */ "סרי לנקה",
        /*     GEO */ "גאורגיה",
        /*     IRL */ "אירלנד",
        /*     SLE */ "סיירה לאונה",
        /*     PAN */ "פנמה",
        /*     CZE */ "הרפובליקה הצ`כית",
        /*     GUF */ "גיאנה הצרפתית",
        /*     ARE */ "איחוד האמירויות הערביות",
        /*     AUT */ "אוֹסְטְרֵיָה",
        /*     AZE */ "אזרבייג`ן",
        /*     SRB */ "סרביה",
        /*     JOR */ "יַרדֵן",
        /*     PRT */ "פּוֹרטוּגָל",
        /*     HUN */ "הונגריה",
        /*     KOR */ "דרום קוריאה",
        /*     ISL */ "אִיסלַנד",
        /*     GTM */ "גואטמלה",
        /*     CUB */ "קובה",
        /*     BGR */ "בולגריה",
        /*     LBR */ "ליבריה",
        /*     HND */ "הונדורס",
        /*     BEN */ "בנין",
        /*     ERI */ "אריתריאה",
        /*     MWI */ "מלאווי",
        /*     PRK */ "צפון קוריאה",
        /*     NIC */ "ניקרגואה",
        /*     GRC */ "יָוָן",
        /*     TJK */ "טג`יקיסטן",
        /*     BGD */ "בנגלדש",
        /*     NPL */ "נפאל",
        /*     TUN */ "תוניסיה",
        /*     SUR */ "סורינאם",
        /*     URY */ "אורוגוואי",
        /*     KHM */ "קמבודיה",
        /*     SYR */ "סוּריָה",
        /*     SEN */ "סנגל",
        /*     KGZ */ "קירגיזסטן",
        /*     BLR */ "בלארוס",
        /*     GUY */ "גיאנה",
        /*     LAO */ "לאוס",
        /*     ROU */ "רומני",
        /*     GHA */ "גאנה",
        /*     UGA */ "אוגנדה",
        /*     GBR */ "בריטניה|סקוטלנד|הממלכה המאוחדת|צפון אירלנד|אירלנד, צפון",
        /*     GIN */ "גינאה",
        /*     ECU */ "אקוודור",
        /*     ESH */ "הסהרה המערבית|סהרה טוענת לבעלות",
        /*     GAB */ "גבון",
        /*     NZL */ "ניו זילנד",
        /*     BFA */ "בורקינה פאסו",
        /*     PHL */ "פיליפיני",
        /*     ITA */ "אִיטַלִיָה",
        /*     OMN */ "עומאן",
        /*     POL */ "פּוֹלִין",
        /*     CIV */ "חוף שנהב",
        /*     NOR */ "נורווגיה",
        /*     MYS */ "מלזיה",
        /*     VNM */ "וייטנאם",
        /*     FIN */ "פינלנד",
        /*     COG */ "קונגו-ברזוויל",
        /*     DEU */ "גֶרמָנִיָה",
        /*     JPN */ "יפן",
        /*     ZWE */ "זימבבואה",
        /*     PRY */ "פרגוואי",
        /*     IRQ */ "עִירַאק",
        /*     MAR */ "מָרוֹקוֹ",
        /*     UZB */ "אוזבקיסטן",
        /*     SWE */ "שוודיה",
        /*     PNG */ "פפואה גינאה החדשה",
        /*     CMR */ "קמרון",
        /*     TKM */ "טורקמניסטן",
        /*     ESP */ "סְפָרַד",
        /*     THA */ "תאילנד",
        /*     YEM */ "תֵימָן",
        /*     FRA */ "צָרְפַת",
        /*     ALA */ "איי אולנד",
        /*     KEN */ "קנייה",
        /*     BWA */ "בוטסואנה",
        /*     MDG */ "מדגסקר",
        /*     UKR */ "אוקראינה",
        /*     SSD */ "דרום סודן",
        /*     CAF */ "הרפובליקה המרכז - אפריקאית",
        /*     SOM */ "סומליה",
        /*     AFG */ "אפגניסטן",
        /*     MMR */ "מיאנמר|בורמה",
        /*     ZMB */ "זמביה",
        /*     CHL */ "צ`ילה",
        /*     TUR */ "טורקיה",
        /*     PAK */ "פקיסטן",
        /*     MOZ */ "מוזמביק",
        /*     NAM */ "נמיביה",
        /*     VEN */ "ונצואלה",
        /*     NGA */ "ניגריה",
        /*     TZA */ "טנזניה",
        /*     EGY */ "מִצְרַיִם",
        /*     MRT */ "מאוריטניה",
        /*     BOL */ "בוליביה",
        /*     ETH */ "אֶתִיוֹפִּיָה",
        /*     COL */ "קולומביה",
        /*     ZAF */ "דרום אפריקה",
        /*     MLI */ "מאלי",
        /*     AGO */ "אנגולה",
        /*     NER */ "ניז`ר",
        /*     TCD */ "צ`אד",
        /*     PER */ "פרו",
        /*     MNG */ "מונגוליה",
        /*     IRN */ "אִירָן",
        /*     LBY */ "לוב",
        /*     SDN */ "סודן",
        /*     IDN */ "אִינדוֹנֵזִיָה",
        /*     DIF */ "מחוז פדרלי",
        /*     TLA */ "טלאקסקאלה",
        /*     MOR */ "מורלוס",
        /*     AGU */ "אגואסקליינטס",
        /*   MX-CL */ "קולימה",
        /*     QUE */ "קרטארו",
        /*     HID */ "הידאלגו",
        /*   MX-MX */ "מדינת מקסיקו",
        /*     TAB */ "טָבַּסקוֹ",
        /*     NAY */ "נאיאריט",
        /*     GUA */ "גואנחואטו",
        /*     PUE */ "פואבלה",
        /*     YUC */ "יוקטן",
        /*     ROO */ "קווינטנה רו",
        /*     SIN */ "סינאלואה",
        /*     CAM */ "קמפצ`ה",
        /*     MIC */ "במיצ`ואקאן",
        /*     SLP */ "סן לואיס פוטוסי",
        /*     GRO */ "גררתי",
        /*     NLE */ "נואבו לאון",
        /*     BCN */ "באחה קליפורניה",
        /*     VER */ "וראקרוז",
        /*     CHP */ "צ`יאפס",
        /*     BCS */ "באחה קליפורניה הדרומית",
        /*     ZAC */ "זאקאטקאס",
        /*     JAL */ "חליסקו",
        /*     TAM */ "טמאוליפס",
        /*     OAX */ "אואחאקה",
        /*     DUR */ "דורנגו",
        /*     COA */ "קואהווילה",
        /*     SON */ "סונורה",
        /*     CHH */ "צ`יוואווה",
        /*     GRL */ "גרינלנד",
        /*     SAU */ "ערב הסעודית",
        /*     COD */ "קונגו-קינשאסה",
        /*     DZA */ "אלג`יריה",
        /*     KAZ */ "קזחסטן",
        /*     ARG */ "ארגנטינה",
        /*   IN-DD */ "דמאן ודיו",
        /*   IN-DN */ "דדרה ונגר הבלי",
        /*   IN-CH */ "צ`אנדיגאר",
        /*   IN-AN */ "אנדמן וניקובר",
        /*   IN-LD */ "לקשאדוויפ",
        /*   IN-DL */ "דלהי",
        /*   IN-ML */ "מאגאליה",
        /*   IN-NL */ "נאגאלנד",
        /*   IN-MN */ "מניפור",
        /*   IN-TR */ "טריפורה",
        /*   IN-MZ */ "מיזוראם",
        /*   IN-SK */ "סיקים",
        /*   IN-PB */ "פונג`אב",
        /*   IN-HR */ "האריאנה",
        /*   IN-AR */ "ארונצ`אל פראדש",
        /*   IN-AS */ "אסאם",
        /*   IN-BR */ "ביהאר",
        /*   IN-UT */ "אוטראקהאנד",
        /*   IN-GA */ "גואה",
        /*   IN-KL */ "קראלה",
        /*   IN-TN */ "טאמיל נאדו",
        /*   IN-HP */ "הימאצ`אל פראדש",
        /*   IN-JK */ "ג`אמו וקשמיר",
        /*   IN-CT */ "צ`האטיסגאר",
        /*   IN-JH */ "ג`הרקאנד",
        /*   IN-KA */ "קרנטקה",
        /*   IN-RJ */ "רג`סטאן",
        /*   IN-OR */ "אודסה|אוריסה",
        /*   IN-GJ */ "גוג`אראט",
        /*   IN-WB */ "מערב בנגל",
        /*   IN-MP */ "מאדהיה פראדש",
        /*   IN-TG */ "טלנגאנה",
        /*   IN-AP */ "אנדרה פראדש",
        /*   IN-MH */ "מהרשטרה",
        /*   IN-UP */ "אוטר פראדש",
        /*   IN-PY */ "פונדיצ`רי",
        /*     NSW */ "ניו סאות` ויילס",
        /*     ACT */ "טריטוריית הבירה האוסטרלית",
        /*     JBT */ "טריטוריית מפרץ ג`רביס",
        /*   AU-NT */ "הטריטוריה הצפונית",
        /*   AU-SA */ "דרום אוסטרליה",
        /*     TAS */ "טסמניה",
        /*     VIC */ "ויקטוריה",
        /*   AU-WA */ "מערב אוסטרליה",
        /*     QLD */ "קווינסלנד",
        /*   BR-DF */ "מחוז פדרלי",
        /*   BR-SE */ "סרגיפה",
        /*   BR-AL */ "אלאגאוס",
        /*   BR-RJ */ "ריו דה ז`נרו",
        /*   BR-ES */ "אספיריטו סנטו",
        /*   BR-RN */ "ריו גרנדה דו נורטה",
        /*   BR-PB */ "פרייבה",
        /*   BR-SC */ "סנטה קטרינה",
        /*   BR-PE */ "פרנמבוקו",
        /*   BR-AP */ "אמאפה",
        /*   BR-CE */ "סיארה",
        /*   BR-AC */ "עכו",
        /*   BR-PR */ "פאראנה",
        /*   BR-RR */ "רוראימה",
        /*   BR-RO */ "רונדוניה",
        /*   BR-SP */ "סאו פאולו",
        /*   BR-PI */ "פיאאוי",
        /*   BR-TO */ "טוקנטינס",
        /*   BR-RS */ "ריו גרנדה דו סול",
        /*   BR-MA */ "מרנאו",
        /*   BR-GO */ "גויאש",
        /*   BR-MS */ "מאטו גרוסו דו סול",
        /*   BR-BA */ "באהיה",
        /*   BR-MG */ "מינאס גראיס",
        /*   BR-MT */ "מאטו גרוסו",
        /*   BR-PA */ "פארה",
        /*   BR-AM */ "אמזונס",
        /*   US-DC */ "מחוז קולומביה",
        /*   US-RI */ "רוד איילנד",
        /*   US-DE */ "דלאוור",
        /*   US-CT */ "קונטיקט",
        /*   US-NJ */ "ניו ג`רזי",
        /*   US-NH */ "ניו המפשייר",
        /*   US-VT */ "ורמונט",
        /*   US-MA */ "מסצ`וסטס",
        /*   US-HI */ "הוואי",
        /*   US-MD */ "מרילנד",
        /*   US-WV */ "מערב וירג`יניה",
        /*   US-SC */ "דרום קרוליינה",
        /*   US-ME */ "מיין",
        /*   US-IN */ "אינדיאנה",
        /*   US-KY */ "קנטאקי",
        /*   US-TN */ "טנסי",
        /*   US-VA */ "וירג`יניה",
        /*   US-OH */ "אוהיו",
        /*   US-PA */ "פנסילבניה",
        /*   US-MS */ "מיסיסיפי",
        /*   US-LA */ "לואיזיאנה",
        /*   US-AL */ "אלבמה",
        /*   US-AR */ "ארקנסו",
        /*   US-NC */ "צפון קרוליינה",
        /*   US-NY */ "ניו יורק",
        /*   US-IA */ "איווה",
        /*   US-IL */ "אילינוי",
        /*   US-GA */ "גאורגיה",
        /*   US-WI */ "ויסקונסין",
        /*   US-FL */ "פלורידה",
        /*   US-MO */ "מיזורי",
        /*   US-OK */ "אוקלהומה",
        /*   US-ND */ "צפון דקוטה",
        /*   US-WA */ "וושינגטון",
        /*   US-SD */ "דרום דקוטה",
        /*   US-NE */ "נברסקה",
        /*   US-KS */ "קנזס",
        /*   US-ID */ "איידהו",
        /*   US-UT */ "יוטה",
        /*   US-MN */ "מינסוטה",
        /*   US-MI */ "מישיגן",
        /*   US-WY */ "ויומינג",
        /*   US-OR */ "אורגון",
        /*   US-CO */ "קולורדו",
        /*   US-NV */ "נבדה",
        /*   US-AZ */ "אריזונה",
        /*   US-NM */ "ניו מקסיקו",
        /*   US-MT */ "מונטנה",
        /*   US-CA */ "קליפורניה",
        /*   US-TX */ "טקסס",
        /*   US-AK */ "אלסקה",
        /*   CA-BC */ "קולומביה הבריטית",
        /*   CA-AB */ "אלברטה",
        /*   CA-ON */ "אונטריו",
        /*   CA-QC */ "קוויבק",
        /*   CA-SK */ "בססקצ`ואן",
        /*   CA-MB */ "מניטובה",
        /*   CA-NL */ "ניופאונדלנד",
        /*   CA-NB */ "ניו - ברונסוויק",
        /*   CA-NS */ "נובה סקוטיה",
        /*   CA-PE */ "אי הנסיך אדוארד",
        /*   CA-YT */ "יוקון",
        /*   CA-NT */ "הטריטוריות הצפון מערביות",
        /*   CA-NU */ "נונאווט",
        /*     IND */ "הוֹדוּ",
        /*     AUS */ "אוֹסטְרַלִיָה",
        /*     BRA */ "בְּרָזִיל",
        /*     USA */ "אַרצוֹת הַבְּרִית",
        /*     MEX */ "מקסיקו",
        /*     MOW */ "מוסקבה",
        /*     SPE */ "סנט פטרסבורג",
        /*     KGD */ "מחוז קלינינגרד",
        /*   RU-IN */ "אינגושטיה הרפובליקה",
        /*   RU-AD */ "אדיגיה הרפובליקה",
        /*   RU-SE */ "צפון אוסטיה-אלניה הרפובליקה",
        /*   RU-KB */ "קברדינו-בלקריה",
        /*   RU-KC */ "קאראצ`אי-צ`רקסיה",
        /*   RU-CE */ "הצ`צ`נים רפובליקה",
        /*   RU-CU */ "חבוש רפובליקה",
        /*     IVA */ "מחוז איוואנובו",
        /*     LIP */ "מחוז ליפצק",
        /*     ORL */ "מחוז אוריול",
        /*     TUL */ "מחוז טולה",
        /*   RU-BE */ "מחוז בלגורוד",
        /*     VLA */ "מחוז ולדימיר",
        /*     KRS */ "מחוז קורסק",
        /*     KLU */ "מחוז קלוגה",
        /*   RU-TT */ "מחוז טמבוב",
        /*     BRY */ "מחוז בריאנסק",
        /*     YAR */ "מחוז ירוסלבל",
        /*     RYA */ "מחוז ריאזאן",
        /*     AST */ "מחוז אסטרחן",
        /*     MOS */ "מחוז מוסקבה",
        /*     SMO */ "מחוז סמולנסק",
        /*   RU-DA */ "דאגסטן הרפובליקה",
        /*     VOR */ "מחוז וורונז `",
        /*     NGR */ "מחוז נובגורוד",
        /*     PSK */ "מחוז פסקוב",
        /*     KOS */ "מחוז קוסטרומה",
        /*     STA */ "מחוז סטברופול",
        /*     KDA */ "קרסנודר Krai",
        /*   RU-KL */ "קלמיקיה הרפובליקה",
        /*     TVE */ "מחוז טבר",
        /*     LEN */ "מחוז לנינגרד",
        /*     ROS */ "מחוז רוסטוב",
        /*     VGG */ "מחוז וולגוגרד",
        /*     VLG */ "מחוז וולוגדה",
        /*     MUR */ "מחוז מורמנסק",
        /*   RU-KR */ "קרליה הרפובליקה",
        /*     NEN */ "המחוז האוטונומי של הניינץ",
        /*   RU-KO */ "רפובליקה קומית",
        /*     ARK */ "מחוז ארכנגלסק",
        /*   RU-MO */ "מורדוביה הרפובליקה",
        /*     NIZ */ "מחוז ניז`ני נובגורוד",
        /*     PNZ */ "מחוז פנזה",
        /*   RU-KI */ "מחוז קירוב",
        /*   RU-ME */ "מארי אל הרפובליקה",
        /*     ORE */ "מחוז אורנבורג",
        /*     ULY */ "מחוז אולייאנובסק",
        /*   RU-PM */ "מחוז פרם",
        /*   RU-BA */ "הרפובליקה של בשקיריה",
        /*   RU-UD */ "אודמורט הרפובליקה",
        /*   RU-TA */ "טטרסטן הרפובליקה",
        /*     SAM */ "מחוז סמרה",
        /*     SAR */ "מחוז סראטוב",
        /*     YAN */ "ימלו-Nenets",
        /*   RU-KM */ "חאנטי-מנסי",
        /*     SVE */ "מחוז סברדלובסק",
        /*     TYU */ "מחוז טיומן",
        /*     KGN */ "מחוז קורגן",
        /*   RU-CH */ "מחוז צ`ליאבינסק",
        /*   RU-BU */ "בוריאטיה הרפובליקה",
        /*     ZAB */ "מחוז עבר הבאיקל",
        /*     IRK */ "מחוז אירקוטסק",
        /*     NVS */ "מחוז נובוסיבירסק",
        /*     TOM */ "מחוז טומסק",
        /*     OMS */ "מחוז אומסק",
        /*   RU-KK */ "חקסיה הרפובליקה",
        /*     KEM */ "מחוז קמרובו",
        /*   RU-AL */ "אלטאי",
        /*     ALT */ "מחוז אלטאי",
        /*   RU-TY */ "הרפובליקה של טובה",
        /*     KYA */ "מחוז קרסנויארסק",
        /*     MAG */ "מחוז מגדן",
        /*     CHU */ "צ`וקוטקה אוקרוג",
        /*     KAM */ "מחוז קמצ`טקה",
        /*     SAK */ "מחוז סחלין",
        /*   RU-PO */ "מחוז פרימוריה",
        /*     YEV */ "מחוז יהודי אוטונומי",
        /*     KHA */ "מחוז חברובסק",
        /*     AMU */ "מחוז אמור",
        /*   RU-SA */ "רפובליקת סאחה-יקוטיה|רפובליקה יאקוטיה",
        /*     CAN */ "קנדה",
        /*     RUS */ "רוּסִיָה",
        /*   CN-SH */ "שנחאי",
        /*   CN-TJ */ "טיאנג`ין",
        /*   CN-BJ */ "בייג`ינג",
        /*   CN-HI */ "האינאן",
        /*   CN-NX */ "נינגשיה הואי",
        /*   CN-CQ */ "צ`ונגצ`ינג",
        /*   CN-ZJ */ "ג`ה|ג`ג`יאנג",
        /*   CN-JS */ "ג`יאנגסו",
        /*   CN-FJ */ "פוג`יאן",
        /*   CN-AH */ "אנהוי",
        /*   CN-LN */ "ליאונינג",
        /*   CN-SD */ "שאנדונג",
        /*   CN-SX */ "שאנשי",
        /*   CN-JX */ "ג`יאנג",
        /*   CN-HA */ "הנאן",
        /*   CN-GZ */ "גוויג",
        /*   CN-GD */ "גואנגדונג",
        /*   CN-HB */ "הוביי",
        /*   CN-JL */ "ג`ילין",
        /*   CN-HE */ "הביי",
        /*   CN-SN */ "שאאנשי",
        /*   CN-NM */ "אינר מונגוליה",
        /*   CN-HL */ "היילונג",
        /*   CN-HN */ "הונאן",
        /*   CN-GX */ "גואנגשי ג`ואנג",
        /*   CN-SC */ "סצ`ואן",
        /*   CN-YN */ "יונאן",
        /*   CN-XZ */ "טיבט",
        /*   CN-GS */ "גאנסו",
        /*   CN-QH */ "צ`ינגהאי",
        /*   CN-XJ */ "אויגורים שינג`יאנג",
        /*     CHN */ "סין",
        /*     UMI */ "ארצות הברית האיים המרוחקים הקטנים",
        /*     CPT */ "קליפרטון",
        /*     ATA */ "אנטארקטיקה",
        /*     AAA */ "הבינלאומי|כדור הארץ"
#else // MAPCODE_SUPPORT_LANGUAGE_HE
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_HE
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_HE_H__
