/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_TR_H__
#define __INTERNAL_TERRITORY_NAMES_TR_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_TR[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_TR // Turkish
        /*     VAT */ "Vatikan|Holy See",
        /*     MCO */ "Monako",
        /*     GIB */ "Cebelitarık",
        /*     TKL */ "Tokelau",
        /*     CCK */ "Cocos Adaları|Keeling Adaları",
        /*     BLM */ "Saint-Barthelemy",
        /*     NRU */ "Nauru",
        /*     TUV */ "Tuvalu",
        /*     MAC */ "Makao",
        /*     SXM */ "Sint Maarten",
        /*     MAF */ "Saint-Martin",
        /*     NFK */ "Norfolk ve Philip Island|Philip Island",
        /*     PCN */ "Pitcairn Adaları",
        /*     BVT */ "Bouvet Adası",
        /*     BMU */ "Bermuda",
        /*     IOT */ "İngiliz Hint Okyanusu Toprakları",
        /*     SMR */ "San Marino",
        /*     GGY */ "Guernsey",
        /*     AIA */ "Anguilla",
        /*     MSR */ "Montserrat",
        /*     JEY */ "Jersey",
        /*     CXR */ "Noel Adası",
        /*     WLF */ "Wallis ve Futuna|Futuna",
        /*     VGB */ "Britanya Virjin Adaları",
        /*     LIE */ "Lihtenştayn",
        /*     ABW */ "Aruba",
        /*     MHL */ "Marşal Adaları",
        /*     ASM */ "Amerikan Samoası",
        /*     COK */ "Cook Adaları",
        /*     SPM */ "Aziz Pierre ve Miquelon|Miquelon",
        /*     NIU */ "Niue",
        /*     KNA */ "Saint Kitts ve Nevis|Nevis",
        /*     CYM */ "Cayman Adaları",
        /*     BES */ "Bonaire, St. Eustatuis ve Saba|Saba|St Eustatius",
        /*     MDV */ "Maldivler",
        /*     SHN */ "Saint Helena, Ascension ve Tristan da Cunha|Yükseliş|Tristan da Cunha",
        /*     MLT */ "Malta",
        /*     GRD */ "Grenada",
        /*     VIR */ "ABD Virjin Adaları",
        /*     MYT */ "Mayotte",
        /*     SJM */ "Svalbard ve Jan Mayen|Jan Mayen",
        /*     VCT */ "Saint Vincent ve Grenadines|Grenadinler",
        /*     HMD */ "Adası ve McDonald Adaları Heard|McDonald Adaları",
        /*     BRB */ "Barbados",
        /*     ATG */ "Antigua ve Barbuda|Barbuda",
        /*     CUW */ "Curacao",
        /*     SYC */ "Seyşeller",
        /*     PLW */ "Palau",
        /*     MNP */ "Kuzey Mariana Adaları",
        /*     AND */ "Andorra",
        /*     GUM */ "Guam",
        /*     IMN */ "Man Adası",
        /*     LCA */ "Saint Lucia",
        /*     FSM */ "Mikronezya Federal Devletleri",
        /*     SGP */ "Singapur",
        /*     TON */ "Tonga",
        /*     DMA */ "Dominika",
        /*     BHR */ "Bahreyn",
        /*     KIR */ "Kiribati",
        /*     TCA */ "Turks ve Caicos Adaları|Caicos Adaları",
        /*     STP */ "São Tomé ve Príncipe|Príncipe",
        /*     HKG */ "Hong Kong",
        /*     MTQ */ "Martinik",
        /*     FRO */ "Faroe Adaları",
        /*     GLP */ "Guadeloupe",
        /*     COM */ "Komorlar",
        /*     MUS */ "Mauritius",
        /*     REU */ "Reunion",
        /*     LUX */ "Lüksemburg",
        /*     WSM */ "Samoa",
        /*     SGS */ "Güney Georgia ve Güney Sandwich Adaları|Güney Sandwich Adaları",
        /*     PYF */ "Fransız Polinezyası",
        /*     CPV */ "Yeşil Burun Adaları|Cape Verde",
        /*     TTO */ "Trinidad ve Tobago|Tobago",
        /*     BRN */ "Brunei",
        /*     ATF */ "Fransız Güney ve Antarktik",
        /*     PRI */ "Porto Riko",
        /*     CYP */ "Kıbrıs Cumhuriyeti",
        /*     LBN */ "Lübnan",
        /*     JAM */ "Jamaika",
        /*     GMB */ "Gambiya",
        /*     QAT */ "Katar",
        /*     FLK */ "Falkland adaları",
        /*     VUT */ "Vanuatu",
        /*     MNE */ "Karadağ",
        /*     BHS */ "Bahamalar",
        /*     TLS */ "Doğu Timor",
        /*     SWZ */ "Svaziland",
        /*     KWT */ "Kuveyt",
        /*     FJI */ "Fiji",
        /*     NCL */ "Yeni Kaledonya",
        /*     SVN */ "Slovenya",
        /*     ISR */ "İsrail",
        /*     PSE */ "Filistin Bölgesi",
        /*     SLV */ "El Salvador",
        /*     BLZ */ "Belize",
        /*     DJI */ "Cibuti",
        /*     MKD */ "Makedonya",
        /*     RWA */ "Ruanda",
        /*     HTI */ "Haiti",
        /*     BDI */ "Burundi",
        /*     GNQ */ "Ekvator Ginesi",
        /*     ALB */ "Arnavutluk",
        /*     SLB */ "Solomon Adaları",
        /*     ARM */ "Ermenistan",
        /*     LSO */ "Lesotho",
        /*     BEL */ "Belçika",
        /*     MDA */ "Moldova",
        /*     GNB */ "Gine-Bissau",
        /*     TWN */ "Tayvan",
        /*     BTN */ "Bhutan",
        /*     CHE */ "İsviçre",
        /*     NLD */ "Hollanda",
        /*     DNK */ "Danimarka",
        /*     EST */ "Estonya",
        /*     DOM */ "Dominik Cumhuriyeti",
        /*     SVK */ "Slovakya",
        /*     CRI */ "Kosta Rika",
        /*     BIH */ "Bosna-Hersek",
        /*     HRV */ "Hırvatistan",
        /*     TGO */ "Togo",
        /*     LVA */ "Letonya",
        /*     LTU */ "Litvanya",
        /*     LKA */ "Sri Lanka",
        /*     GEO */ "Gürcistan",
        /*     IRL */ "İrlanda",
        /*     SLE */ "Sierra Leone",
        /*     PAN */ "Panama",
        /*     CZE */ "Çek Cumhuriyeti",
        /*     GUF */ "Fransız Guyanası",
        /*     ARE */ "Birleşik Arap Emirlikleri",
        /*     AUT */ "Avusturya",
        /*     AZE */ "Azerbaycan",
        /*     SRB */ "Sırbistan",
        /*     JOR */ "Ürdün",
        /*     PRT */ "Portekiz",
        /*     HUN */ "Macaristan",
        /*     KOR */ "Güney Kore",
        /*     ISL */ "İzlanda",
        /*     GTM */ "Guatemala",
        /*     CUB */ "Küba",
        /*     BGR */ "Bulgaristan",
        /*     LBR */ "Liberya",
        /*     HND */ "Honduras",
        /*     BEN */ "Benin",
        /*     ERI */ "Eritre",
        /*     MWI */ "Malavi",
        /*     PRK */ "Kuzey Kore",
        /*     NIC */ "Nikaragua",
        /*     GRC */ "Yunanistan",
        /*     TJK */ "Tacikistan",
        /*     BGD */ "Bangladeş",
        /*     NPL */ "Nepal",
        /*     TUN */ "Tunus",
        /*     SUR */ "Surinam",
        /*     URY */ "Uruguay",
        /*     KHM */ "Kamboçya",
        /*     SYR */ "Suriye",
        /*     SEN */ "Senegal",
        /*     KGZ */ "Kırgızistan",
        /*     BLR */ "Beyaz Rusya",
        /*     GUY */ "Guyana",
        /*     LAO */ "Laos",
        /*     ROU */ "Romanya",
        /*     GHA */ "Gana",
        /*     UGA */ "Uganda",
        /*     GBR */ "Birleşik Krallık|İskoçya|Büyük Britanya|Kuzey İrlanda|İrlanda, Kuzey",
        /*     GIN */ "Gine",
        /*     ECU */ "Ekvador",
        /*     ESH */ "Batı Sahra",
        /*     GAB */ "Gabon",
        /*     NZL */ "Yeni Zelanda",
        /*     BFA */ "Burkina Faso",
        /*     PHL */ "Filipinler",
        /*     ITA */ "İtalya",
        /*     OMN */ "Umman",
        /*     POL */ "Polonya",
        /*     CIV */ "Fildişi Sahili",
        /*     NOR */ "Norveç",
        /*     MYS */ "Malezya",
        /*     VNM */ "Vietnam",
        /*     FIN */ "Finlandiya",
        /*     COG */ "Kongo-Brazzaville",
        /*     DEU */ "Almanya",
        /*     JPN */ "Japonya",
        /*     ZWE */ "Zimbabve",
        /*     PRY */ "Paraguay",
        /*     IRQ */ "Irak",
        /*     MAR */ "Fas",
        /*     UZB */ "Özbekistan",
        /*     SWE */ "İsveç",
        /*     PNG */ "Papua Yeni Gine",
        /*     CMR */ "Kamerun",
        /*     TKM */ "Türkmenistan",
        /*     ESP */ "İspanya",
        /*     THA */ "Tayland",
        /*     YEM */ "Yemen",
        /*     FRA */ "Fransa",
        /*     ALA */ "Aaland Adaları",
        /*     KEN */ "Kenya",
        /*     BWA */ "Botsvana",
        /*     MDG */ "Madagaskar",
        /*     UKR */ "Ukrayna",
        /*     SSD */ "Güney Sudan",
        /*     CAF */ "Orta Afrika Cumhuriyeti",
        /*     SOM */ "Somali",
        /*     AFG */ "Afganistan",
        /*     MMR */ "Myanmar|Burma",
        /*     ZMB */ "Zambiya",
        /*     CHL */ "Şili",
        /*     TUR */ "Türkiye",
        /*     PAK */ "Pakistan",
        /*     MOZ */ "Mozambik",
        /*     NAM */ "Namibya",
        /*     VEN */ "Venezuela",
        /*     NGA */ "Nijerya",
        /*     TZA */ "Tanzanya",
        /*     EGY */ "Mısır",
        /*     MRT */ "Moritanya",
        /*     BOL */ "Bolivya",
        /*     ETH */ "Etiyopya",
        /*     COL */ "Kolombiya",
        /*     ZAF */ "Güney Afrika",
        /*     MLI */ "Mali",
        /*     AGO */ "Angola",
        /*     NER */ "Nijer",
        /*     TCD */ "Çad",
        /*     PER */ "Peru",
        /*     MNG */ "Moğolistan",
        /*     IRN */ "İran",
        /*     LBY */ "Libya",
        /*     SDN */ "Sudan",
        /*     IDN */ "Endonezya",
        /*     DIF */ "Federal Bölge",
        /*     TLA */ "Tlaxcala",
        /*     MOR */ "Morelos",
        /*     AGU */ "Aguascalientes",
        /*   MX-CL */ "Colima",
        /*     QUE */ "Queretaro",
        /*     HID */ "Hidalgo",
        /*   MX-MX */ "Meksika Devlet",
        /*     TAB */ "Tabasko",
        /*     NAY */ "Nayarit",
        /*     GUA */ "Guanajuato",
        /*     PUE */ "Puebla",
        /*     YUC */ "Yucatan",
        /*     ROO */ "Quintana Roo",
        /*     SIN */ "Sinaloa",
        /*     CAM */ "Campeche",
        /*     MIC */ "Michoacan",
        /*     SLP */ "San Luis Potosi",
        /*     GRO */ "Guerrero",
        /*     NLE */ "Nuevo Leon",
        /*     BCN */ "Baja California",
        /*     VER */ "Veracruz",
        /*     CHP */ "Chiapas",
        /*     BCS */ "Baja California Sur",
        /*     ZAC */ "Zacatecas",
        /*     JAL */ "Jalisco",
        /*     TAM */ "Tamaulipas",
        /*     OAX */ "Oaxaca",
        /*     DUR */ "Colorado eyaletinde bir şehir",
        /*     COA */ "Coahuila",
        /*     SON */ "Sonora",
        /*     CHH */ "Chihuahua",
        /*     GRL */ "Grönland",
        /*     SAU */ "Suudi Arabistan",
        /*     COD */ "Kongo Kinşasa",
        /*     DZA */ "Cezayir",
        /*     KAZ */ "Kazakistan",
        /*     ARG */ "Arjantin",
        /*   IN-DD */ "Daman and Diu",
        /*   IN-DN */ "Dadra and Nagar Haveli",
        /*   IN-CH */ "Chandigarh",
        /*   IN-AN */ "Andaman ve Nikobar",
        /*   IN-LD */ "Lakshadweep",
        /*   IN-DL */ "Delhi",
        /*   IN-ML */ "Meghalaya",
        /*   IN-NL */ "Nagaland",
        /*   IN-MN */ "Manipur",
        /*   IN-TR */ "Tripura",
        /*   IN-MZ */ "Mizoram",
        /*   IN-SK */ "Sikkim",
        /*   IN-PB */ "Pencap",
        /*   IN-HR */ "Haryana",
        /*   IN-AR */ "Arunaçal Pradeş",
        /*   IN-AS */ "Assam",
        /*   IN-BR */ "Bihar",
        /*   IN-UT */ "Uttarkand",
        /*   IN-GA */ "Goa",
        /*   IN-KL */ "Kerala",
        /*   IN-TN */ "Tamil Nadu",
        /*   IN-HP */ "Himachal Pradesh",
        /*   IN-JK */ "Jammu ve Keşmir",
        /*   IN-CT */ "Chhattisgarh",
        /*   IN-JH */ "Jharkhand",
        /*   IN-KA */ "Karnataka",
        /*   IN-RJ */ "Rajasthan",
        /*   IN-OR */ "Odisha|Orissa",
        /*   IN-GJ */ "Gujarat",
        /*   IN-WB */ "Batı Bengal",
        /*   IN-MP */ "Madya Pradeş",
        /*   IN-TG */ "Telangana",
        /*   IN-AP */ "Andra Pradeş",
        /*   IN-MH */ "Maharashtra",
        /*   IN-UP */ "Uttar Pradesh",
        /*   IN-PY */ "Puducherry",
        /*     NSW */ "Yeni Güney Galler",
        /*     ACT */ "Avustralya Başkent Bölgesi",
        /*     JBT */ "Jervis Bay Bölge",
        /*   AU-NT */ "Northern Territory",
        /*   AU-SA */ "Güney Avustralya",
        /*     TAS */ "Tazmanya",
        /*     VIC */ "Victoria",
        /*   AU-WA */ "Batı Avustralya",
        /*     QLD */ "Queensland",
        /*   BR-DF */ "Distrito Federal",
        /*   BR-SE */ "Sergipe",
        /*   BR-AL */ "Alagoas",
        /*   BR-RJ */ "Rio de Janeiro",
        /*   BR-ES */ "Espirito Santo",
        /*   BR-RN */ "Rio Grande do Norte",
        /*   BR-PB */ "Paraiba",
        /*   BR-SC */ "Santa Catarina",
        /*   BR-PE */ "Pernambuco",
        /*   BR-AP */ "Amapa",
        /*   BR-CE */ "Ceara",
        /*   BR-AC */ "Acre",
        /*   BR-PR */ "Parana",
        /*   BR-RR */ "Roraima",
        /*   BR-RO */ "Rondonia",
        /*   BR-SP */ "Sao Paulo",
        /*   BR-PI */ "Piaui",
        /*   BR-TO */ "Tocantins",
        /*   BR-RS */ "Rio Grande do Sul",
        /*   BR-MA */ "Maranhao",
        /*   BR-GO */ "Goias",
        /*   BR-MS */ "Mato Grosso do Sul",
        /*   BR-BA */ "Bahia",
        /*   BR-MG */ "Minas Gerais",
        /*   BR-MT */ "Mato Grosso do",
        /*   BR-PA */ "Pará",
        /*   BR-AM */ "Amazonas",
        /*   US-DC */ "Kolumbiya Bölgesi",
        /*   US-RI */ "Rhode Island",
        /*   US-DE */ "Delaware",
        /*   US-CT */ "Connecticut",
        /*   US-NJ */ "New Jersey",
        /*   US-NH */ "New Hampshire",
        /*   US-VT */ "Vermont",
        /*   US-MA */ "Massachusetts",
        /*   US-HI */ "Hawaii",
        /*   US-MD */ "Maryland",
        /*   US-WV */ "West Virginia",
        /*   US-SC */ "South Carolina",
        /*   US-ME */ "Maine",
        /*   US-IN */ "Indiana",
        /*   US-KY */ "Kentucky",
        /*   US-TN */ "Tennessee",
        /*   US-VA */ "Virginia",
        /*   US-OH */ "Ohio",
        /*   US-PA */ "Pennsylvania",
        /*   US-MS */ "Mississippi",
        /*   US-LA */ "Louisiana",
        /*   US-AL */ "Alabama",
        /*   US-AR */ "Arkansas",
        /*   US-NC */ "North Carolina",
        /*   US-NY */ "New York",
        /*   US-IA */ "Iowa",
        /*   US-IL */ "Illinois",
        /*   US-GA */ "Gürcistan",
        /*   US-WI */ "Wisconsin",
        /*   US-FL */ "Florida",
        /*   US-MO */ "Missouri",
        /*   US-OK */ "Oklahoma",
        /*   US-ND */ "North Dakota",
        /*   US-WA */ "Washington",
        /*   US-SD */ "South Dakota",
        /*   US-NE */ "Nebraska",
        /*   US-KS */ "Kansas",
        /*   US-ID */ "Idaho",
        /*   US-UT */ "Utah",
        /*   US-MN */ "Minnesota",
        /*   US-MI */ "Michigan",
        /*   US-WY */ "Wyoming",
        /*   US-OR */ "Oregon",
        /*   US-CO */ "Colorado",
        /*   US-NV */ "Nevada",
        /*   US-AZ */ "Arizona",
        /*   US-NM */ "New Mexico",
        /*   US-MT */ "Montana",
        /*   US-CA */ "California",
        /*   US-TX */ "Texas",
        /*   US-AK */ "Alaska",
        /*   CA-BC */ "British Columbia",
        /*   CA-AB */ "Alberta",
        /*   CA-ON */ "Ontario",
        /*   CA-QC */ "Quebec",
        /*   CA-SK */ "Saskatchewan",
        /*   CA-MB */ "Manitoba",
        /*   CA-NL */ "Newfoundland",
        /*   CA-NB */ "Yeni brunswick",
        /*   CA-NS */ "Nova Scotia",
        /*   CA-PE */ "Prens Edward Adası",
        /*   CA-YT */ "Yukon",
        /*   CA-NT */ "Kuzeybatı bölgesi",
        /*   CA-NU */ "Nunavut",
        /*     IND */ "Hindistan",
        /*     AUS */ "Avustralya",
        /*     BRA */ "Brezilya",
        /*     USA */ "ABD|Amerika Birleşik Devletleri|Amerika",
        /*     MEX */ "Meksika",
        /*     MOW */ "Moskova",
        /*     SPE */ "Petersburg",
        /*     KGD */ "Kaliningrad Oblast",
        /*   RU-IN */ "İnguşetya Cumhuriyeti",
        /*   RU-AD */ "Adigey Cumhuriyeti",
        /*   RU-SE */ "Kuzey Osetya-Alania Cumhuriyeti",
        /*   RU-KB */ "Kabardey-Balkar Cumhuriyeti",
        /*   RU-KC */ "Karaçay-Çerkes Cumhuriyeti",
        /*   RU-CE */ "Çeçen Cumhuriyeti",
        /*   RU-CU */ "Çuvaş Cumhuriyeti",
        /*     IVA */ "Ivanovo Oblast",
        /*     LIP */ "Lipetsk Oblast",
        /*     ORL */ "Oryol Oblast",
        /*     TUL */ "Tula Oblast",
        /*   RU-BE */ "Belgorod Oblastı",
        /*     VLA */ "Vladimir Oblast",
        /*     KRS */ "Kursk Oblast",
        /*     KLU */ "Kaluga Oblastı",
        /*   RU-TT */ "Tambov Oblastı",
        /*     BRY */ "Bryansk Oblast",
        /*     YAR */ "Yaroslavl Oblast",
        /*     RYA */ "Ryazan Oblastı",
        /*     AST */ "Astrakhan Oblast",
        /*     MOS */ "Moscow Oblast",
        /*     SMO */ "Smolensk Oblast",
        /*   RU-DA */ "Dağıstan Cumhuriyeti",
        /*     VOR */ "Voronezh Oblast",
        /*     NGR */ "Novgorod Oblast",
        /*     PSK */ "Pskov Oblast",
        /*     KOS */ "Kostroma Oblast",
        /*     STA */ "Stavropol Krai",
        /*     KDA */ "Krasnodar Krai",
        /*   RU-KL */ "Kalmykia Cumhuriyeti",
        /*     TVE */ "Tver Oblast",
        /*     LEN */ "Leningrad Oblast",
        /*     ROS */ "Rostov Oblast",
        /*     VGG */ "Volgograd",
        /*     VLG */ "Vologda Oblast",
        /*     MUR */ "Murmansk Oblast",
        /*   RU-KR */ "Karelya Cumhuriyeti",
        /*     NEN */ "Nenets Özerk Okrugu",
        /*   RU-KO */ "Komi Republic",
        /*     ARK */ "Arkhangelsk Oblast",
        /*   RU-MO */ "Mordovya Cumhuriyeti",
        /*     NIZ */ "Nijniy Novgorod Oblastı",
        /*     PNZ */ "Penza Oblast",
        /*   RU-KI */ "Kirov Oblast",
        /*   RU-ME */ "Mari El Cumhuriyeti",
        /*     ORE */ "Orenburg Oblast",
        /*     ULY */ "Ulyanovsk Oblast",
        /*   RU-PM */ "Perm Krai",
        /*   RU-BA */ "Başkortostan Cumhuriyeti",
        /*   RU-UD */ "Udmurt Republic",
        /*   RU-TA */ "Tataristan Cumhuriyeti",
        /*     SAM */ "Samara Oblast",
        /*     SAR */ "Saratov Oblast",
        /*     YAN */ "Yamalo-Nenets",
        /*   RU-KM */ "Hanti-Mansi",
        /*     SVE */ "Sverdlovsk Oblast",
        /*     TYU */ "Tyumen Oblast",
        /*     KGN */ "Kurgan Oblast",
        /*   RU-CH */ "Chelyabinsk",
        /*   RU-BU */ "Buryatia Cumhuriyeti",
        /*     ZAB */ "Zabaykalsky Krai",
        /*     IRK */ "Irkutsk Oblast",
        /*     NVS */ "Novosibirsk Oblast",
        /*     TOM */ "Tomsk Oblast",
        /*     OMS */ "Omsk Oblast",
        /*   RU-KK */ "Hakasya Cumhuriyeti",
        /*     KEM */ "Kemerovo Oblastı",
        /*   RU-AL */ "Altay Cumhuriyeti",
        /*     ALT */ "Altai Krai",
        /*   RU-TY */ "Tuva Cumhuriyeti",
        /*     KYA */ "Krasnoyarsk Krai",
        /*     MAG */ "Magadan Oblastı",
        /*     CHU */ "Chukotka Okrug",
        /*     KAM */ "Kamchatka Krai",
        /*     SAK */ "Sakhalin Oblast",
        /*   RU-PO */ "Primorsky Krai",
        /*     YEV */ "Yahudi Özerk Oblastı",
        /*     KHA */ "Khabarovsk Krai",
        /*     AMU */ "Amur Oblast",
        /*   RU-SA */ "Yakutistan|Yakutia Cumhuriyeti",
        /*     CAN */ "Kanada",
        /*     RUS */ "Rusya",
        /*   CN-SH */ "Şangay",
        /*   CN-TJ */ "Tianjin",
        /*   CN-BJ */ "Pekin",
        /*   CN-HI */ "Hainan",
        /*   CN-NX */ "Ningxia Hui",
        /*   CN-CQ */ "Chongqing",
        /*   CN-ZJ */ "Zhejiang",
        /*   CN-JS */ "Jiangsu",
        /*   CN-FJ */ "Fujian",
        /*   CN-AH */ "Anhui",
        /*   CN-LN */ "Liaoning",
        /*   CN-SD */ "Shandong",
        /*   CN-SX */ "Shanxi",
        /*   CN-JX */ "Jiangxi",
        /*   CN-HA */ "Henan",
        /*   CN-GZ */ "Guizhou",
        /*   CN-GD */ "Guangdong",
        /*   CN-HB */ "Hubei",
        /*   CN-JL */ "Jilin",
        /*   CN-HE */ "Hebei",
        /*   CN-SN */ "Shaanxi",
        /*   CN-NM */ "Nei Mongol|Inner Mongolia",
        /*   CN-HL */ "Heilongjiang",
        /*   CN-HN */ "Hunan",
        /*   CN-GX */ "Guangksi",
        /*   CN-SC */ "Sichuan",
        /*   CN-YN */ "Yunnan",
        /*   CN-XZ */ "Xizang|Tibet",
        /*   CN-GS */ "Gansu",
        /*   CN-QH */ "Qinghai",
        /*   CN-XJ */ "Sincan Uygur",
        /*     CHN */ "Çin Halk Cumhuriyeti",
        /*     UMI */ "Amerika Birleşik Devletleri Küçük Dış Adaları",
        /*     CPT */ "Clipperton Adası",
        /*     ATA */ "Antarktika",
        /*     AAA */ "Uluslararası|Dünya"
#else // MAPCODE_SUPPORT_LANGUAGE_TR
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_TR
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_TR_H__
