/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_JA_H__
#define __INTERNAL_TERRITORY_NAMES_JA_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_JA[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_JA // Japanese
        /*     VAT */ "バチカン市国|教皇庁",
        /*     MCO */ "モナコ",
        /*     GIB */ "ジブラルタル",
        /*     TKL */ "トケラウ諸島",
        /*     CCK */ "ココス諸島|キーリング諸島",
        /*     BLM */ "サン・バルテルミー島",
        /*     NRU */ "ナウル",
        /*     TUV */ "ツバル",
        /*     MAC */ "マカオ",
        /*     SXM */ "シントマールテン島",
        /*     MAF */ "サン・マルタン",
        /*     NFK */ "ノーフォークとフィリップ島|フィリップアイランド",
        /*     PCN */ "ピトケアン諸島",
        /*     BVT */ "ブーヴェ島",
        /*     BMU */ "バミューダ",
        /*     IOT */ "イギリス領インド洋地域",
        /*     SMR */ "サン・マリノ",
        /*     GGY */ "ガーンジー島",
        /*     AIA */ "アングィラ",
        /*     MSR */ "モントセラト",
        /*     JEY */ "ジャージー",
        /*     CXR */ "クリスマス島",
        /*     WLF */ "ウォリス・フツナ|フツナ",
        /*     VGB */ "英領バージン諸島|イギリス領バージン諸島",
        /*     LIE */ "リヒテンシュタイン",
        /*     ABW */ "アルバ",
        /*     MHL */ "マーシャル諸島",
        /*     ASM */ "アメリカ領サモア|サモア、アメリカ",
        /*     COK */ "クック諸島",
        /*     SPM */ "サンピエール島・ミクロン島|ミクロン島",
        /*     NIU */ "ニウエ",
        /*     KNA */ "セントクリストファー・ネイビス|ネビス島",
        /*     CYM */ "ケイマン諸島",
        /*     BES */ "ボネール、セントEustatuisとサバ|サバ|セントユースタティウス",
        /*     MDV */ "モルディブ",
        /*     SHN */ "セントヘレナ、アセンションおよびトリスタン・ダ・クーニャ|アセンション|トリスタン・ダ・クーニャ",
        /*     MLT */ "マルタ",
        /*     GRD */ "グレナダ",
        /*     VIR */ "米領バージン諸島|米領バージン諸島",
        /*     MYT */ "マヨット島",
        /*     SJM */ "スバールバル諸島とヤンマイエン島|ヤンマイエン島",
        /*     VCT */ "セントビンセント・グレナディーン|グレナディーン諸島",
        /*     HMD */ "ハード島とマクドナルド諸島|マクドナルド諸島",
        /*     BRB */ "バルバドス",
        /*     ATG */ "アンティグアバーブーダ|バーブーダ",
        /*     CUW */ "キュラソー",
        /*     SYC */ "セイシェル",
        /*     PLW */ "パラオ",
        /*     MNP */ "北マリアナ諸島",
        /*     AND */ "アンドラ",
        /*     GUM */ "グアム",
        /*     IMN */ "マン島",
        /*     LCA */ "セントルシア",
        /*     FSM */ "ミクロネシア|ミクロネシア連邦",
        /*     SGP */ "シンガポール",
        /*     TON */ "トンガ",
        /*     DMA */ "ドミニカ",
        /*     BHR */ "バーレーン",
        /*     KIR */ "キリバス",
        /*     TCA */ "タークス・カイコス諸島|カイコス諸島",
        /*     STP */ "サントメ・プリンシペ|プリンシペ",
        /*     HKG */ "香港",
        /*     MTQ */ "マルティニーク島",
        /*     FRO */ "フェロー諸島",
        /*     GLP */ "グアドループ島",
        /*     COM */ "コモロ",
        /*     MUS */ "モーリシャス",
        /*     REU */ "再会",
        /*     LUX */ "ルクセンブルク",
        /*     WSM */ "サモア",
        /*     SGS */ "サウスジョージア・サウスサンドウィッチ諸島|サウスサンドウィッチ諸島",
        /*     PYF */ "フランス領ポリネシア",
        /*     CPV */ "カーボベルデ",
        /*     TTO */ "トリニダード・トバゴ|トバゴ",
        /*     BRN */ "ブルネイ",
        /*     ATF */ "フランス領南方・南極地域",
        /*     PRI */ "プエルトリコ",
        /*     CYP */ "キプロス",
        /*     LBN */ "レバノン",
        /*     JAM */ "ジャマイカ",
        /*     GMB */ "ガンビア",
        /*     QAT */ "カタール",
        /*     FLK */ "フォークランド諸島",
        /*     VUT */ "バヌアツ",
        /*     MNE */ "モンテネグロ",
        /*     BHS */ "バハマ",
        /*     TLS */ "東ティモール",
        /*     SWZ */ "スワジランド",
        /*     KWT */ "クウェート",
        /*     FJI */ "フィジー",
        /*     NCL */ "ニューカレドニア",
        /*     SVN */ "スロベニア",
        /*     ISR */ "イスラエル",
        /*     PSE */ "パレスチナ領土",
        /*     SLV */ "エルサルバドル",
        /*     BLZ */ "ベリーズ",
        /*     DJI */ "ジブチ",
        /*     MKD */ "マケドニア",
        /*     RWA */ "ルワンダ",
        /*     HTI */ "ハイチ",
        /*     BDI */ "ブルンジ",
        /*     GNQ */ "赤道ギニア",
        /*     ALB */ "アルバニア",
        /*     SLB */ "ソロモン諸島",
        /*     ARM */ "アルメニア",
        /*     LSO */ "レソト",
        /*     BEL */ "ベルギー",
        /*     MDA */ "モルドバ",
        /*     GNB */ "ギニアビサウ",
        /*     TWN */ "台湾",
        /*     BTN */ "ブータン",
        /*     CHE */ "スイス",
        /*     NLD */ "オランダ",
        /*     DNK */ "デンマーク",
        /*     EST */ "エストニア",
        /*     DOM */ "ドミニカ共和国",
        /*     SVK */ "スロバキア",
        /*     CRI */ "コスタリカ",
        /*     BIH */ "ボスニア・ヘルツェゴビナ",
        /*     HRV */ "クロアチア",
        /*     TGO */ "トーゴ",
        /*     LVA */ "ラトビア",
        /*     LTU */ "リトアニア",
        /*     LKA */ "スリランカ",
        /*     GEO */ "ジョージア",
        /*     IRL */ "アイルランド",
        /*     SLE */ "シエラレオネ",
        /*     PAN */ "パナマ",
        /*     CZE */ "チェコ共和国",
        /*     GUF */ "仏領ギアナ",
        /*     ARE */ "アラブ首長国連邦",
        /*     AUT */ "オーストリア",
        /*     AZE */ "アゼルバイジャン",
        /*     SRB */ "セルビア",
        /*     JOR */ "ヨルダン",
        /*     PRT */ "ポルトガル",
        /*     HUN */ "ハンガリー",
        /*     KOR */ "韓国",
        /*     ISL */ "アイスランド",
        /*     GTM */ "グアテマラ",
        /*     CUB */ "キューバ",
        /*     BGR */ "ブルガリア",
        /*     LBR */ "リベリア",
        /*     HND */ "ホンジュラス",
        /*     BEN */ "ベニン",
        /*     ERI */ "エリトリア",
        /*     MWI */ "マラウイ",
        /*     PRK */ "北朝鮮",
        /*     NIC */ "ニカラグア",
        /*     GRC */ "ギリシャ",
        /*     TJK */ "タジキスタン",
        /*     BGD */ "バングラデシュ",
        /*     NPL */ "ネパール",
        /*     TUN */ "チュニジア",
        /*     SUR */ "スリナム",
        /*     URY */ "ウルグアイ",
        /*     KHM */ "カンボジア",
        /*     SYR */ "シリア",
        /*     SEN */ "セネガル",
        /*     KGZ */ "キルギスタン",
        /*     BLR */ "ベラルーシ",
        /*     GUY */ "ガイアナ",
        /*     LAO */ "ラオス",
        /*     ROU */ "ルーマニア",
        /*     GHA */ "ガーナ",
        /*     UGA */ "ウガンダ",
        /*     GBR */ "イギリス|スコットランド|イギリス|北アイルランド|アイルランド、北",
        /*     GIN */ "ギニア",
        /*     ECU */ "エクアドル",
        /*     ESH */ "西サハラ|サハラ",
        /*     GAB */ "ガボン",
        /*     NZL */ "ニュージーランド",
        /*     BFA */ "ブルキナファソ",
        /*     PHL */ "フィリピン",
        /*     ITA */ "イタリア",
        /*     OMN */ "オマーン",
        /*     POL */ "ポーランド",
        /*     CIV */ "コートジボワール",
        /*     NOR */ "ノルウェー",
        /*     MYS */ "マレーシア",
        /*     VNM */ "ベトナム",
        /*     FIN */ "フィンランド",
        /*     COG */ "コンゴ - ブラザビル",
        /*     DEU */ "ドイツ",
        /*     JPN */ "日本",
        /*     ZWE */ "ジンバブエ",
        /*     PRY */ "パラグアイ",
        /*     IRQ */ "イラク",
        /*     MAR */ "モロッコ",
        /*     UZB */ "ウズベキスタン",
        /*     SWE */ "スウェーデン",
        /*     PNG */ "パプアニューギニア",
        /*     CMR */ "カメルーン",
        /*     TKM */ "トルクメニスタン",
        /*     ESP */ "スペイン",
        /*     THA */ "タイ",
        /*     YEM */ "イエメン",
        /*     FRA */ "フランス",
        /*     ALA */ "オーランド諸島",
        /*     KEN */ "ケニア",
        /*     BWA */ "ボツワナ",
        /*     MDG */ "マダガスカル",
        /*     UKR */ "ウクライナ",
        /*     SSD */ "南スーダン",
        /*     CAF */ "中央アフリカ共和国",
        /*     SOM */ "ソマリア",
        /*     AFG */ "アフガニスタン",
        /*     MMR */ "ミャンマー|ビルマ",
        /*     ZMB */ "ザンビア",
        /*     CHL */ "チリ",
        /*     TUR */ "トルコ",
        /*     PAK */ "パキスタン",
        /*     MOZ */ "モザンビーク",
        /*     NAM */ "ナミビア",
        /*     VEN */ "ベネズエラ",
        /*     NGA */ "ナイジェリア",
        /*     TZA */ "タンザニア",
        /*     EGY */ "エジプト",
        /*     MRT */ "モーリタニア",
        /*     BOL */ "ボリビア",
        /*     ETH */ "エチオピア",
        /*     COL */ "コロンビア",
        /*     ZAF */ "南アフリカ",
        /*     MLI */ "マリ",
        /*     AGO */ "アンゴラ",
        /*     NER */ "ニジェール",
        /*     TCD */ "チャド",
        /*     PER */ "ペルー",
        /*     MNG */ "モンゴル",
        /*     IRN */ "イラン",
        /*     LBY */ "リビア",
        /*     SDN */ "スーダン",
        /*     IDN */ "インドネシア",
        /*     DIF */ "連邦区",
        /*     TLA */ "トラスカラ",
        /*     MOR */ "モレロス州",
        /*     AGU */ "アグアスカリエンテス",
        /*   MX-CL */ "コリマ",
        /*     QUE */ "ケレタロ",
        /*     HID */ "イダルゴ",
        /*   MX-MX */ "メキシコ州",
        /*     TAB */ "タバスコ",
        /*     NAY */ "ナヤリット",
        /*     GUA */ "グアナファト",
        /*     PUE */ "プエブラ",
        /*     YUC */ "ユカタン州",
        /*     ROO */ "キンタナロー州",
        /*     SIN */ "シナロア州",
        /*     CAM */ "カンペチェ",
        /*     MIC */ "ミチョアカン州",
        /*     SLP */ "サンルイスポトシ",
        /*     GRO */ "ゲレロ",
        /*     NLE */ "ヌエボレオン州",
        /*     BCN */ "バハカリフォルニア",
        /*     VER */ "ベラクルス州",
        /*     CHP */ "チアパス州",
        /*     BCS */ "バハ・カリフォルニア・スル州",
        /*     ZAC */ "サカテカス",
        /*     JAL */ "ハリスコ州",
        /*     TAM */ "タマウリパス州",
        /*     OAX */ "オアハカ",
        /*     DUR */ "ドゥランゴ",
        /*     COA */ "コアウイラ州",
        /*     SON */ "ソノラ州",
        /*     CHH */ "チワワ",
        /*     GRL */ "グリーンランド",
        /*     SAU */ "サウジアラビア",
        /*     COD */ "コンゴ - キンシャサ",
        /*     DZA */ "アルジェリア",
        /*     KAZ */ "カザフスタン",
        /*     ARG */ "アルゼンチン",
        /*   IN-DD */ "ダマンディウ",
        /*   IN-DN */ "ダードラーとナガルハベリ",
        /*   IN-CH */ "チャンディーガル",
        /*   IN-AN */ "アンダマン・ニコバル",
        /*   IN-LD */ "ラクシャドウィープ",
        /*   IN-DL */ "デリー",
        /*   IN-ML */ "メガラヤ州",
        /*   IN-NL */ "ナガランド",
        /*   IN-MN */ "マニプール",
        /*   IN-TR */ "トリプラ",
        /*   IN-MZ */ "ミゾラム",
        /*   IN-SK */ "シッキム",
        /*   IN-PB */ "パンジャブ",
        /*   IN-HR */ "ハリヤナ州",
        /*   IN-AR */ "アルナチャル・パラデシュ",
        /*   IN-AS */ "アッサム",
        /*   IN-BR */ "ビハール州",
        /*   IN-UT */ "ウッタラーカンド州",
        /*   IN-GA */ "ゴア",
        /*   IN-KL */ "ケララ",
        /*   IN-TN */ "タミル・ナードゥ州",
        /*   IN-HP */ "ヒマチャル・プラデシュ",
        /*   IN-JK */ "ジャム・カシミール",
        /*   IN-CT */ "チャッティースガル州",
        /*   IN-JH */ "ジャールカンド州",
        /*   IN-KA */ "カルナタカ",
        /*   IN-RJ */ "ラジャスタン",
        /*   IN-OR */ "オリッサ州|オリッサ",
        /*   IN-GJ */ "グジャラート",
        /*   IN-WB */ "西ベンガル",
        /*   IN-MP */ "マディヤプラデシュ州",
        /*   IN-TG */ "テランガーナ州",
        /*   IN-AP */ "アンドラプラデシ",
        /*   IN-MH */ "マハラシュトラ",
        /*   IN-UP */ "ウッタルプラデシ州",
        /*   IN-PY */ "ポンディシェリ",
        /*     NSW */ "ニューサウスウェールズ州",
        /*     ACT */ "オーストラリア首都特別地域",
        /*     JBT */ "ジャービス湾特別地域",
        /*   AU-NT */ "ノーザン・テリトリー",
        /*   AU-SA */ "南オーストラリア州",
        /*     TAS */ "タスマニア州",
        /*     VIC */ "ビクトリア",
        /*   AU-WA */ "西オーストラリア州",
        /*     QLD */ "クイーンズランド州",
        /*   BR-DF */ "連邦区",
        /*   BR-SE */ "セルジペ州",
        /*   BR-AL */ "アラゴアス州",
        /*   BR-RJ */ "リオデジャネイロ",
        /*   BR-ES */ "エスピリトサント州",
        /*   BR-RN */ "リオ・グランデ・ド・ノルテ",
        /*   BR-PB */ "パライバ州",
        /*   BR-SC */ "サンタカタリナ州",
        /*   BR-PE */ "ペルナンブコ州",
        /*   BR-AP */ "アマパ",
        /*   BR-CE */ "セアラ州",
        /*   BR-AC */ "アクレ州",
        /*   BR-PR */ "パラナ",
        /*   BR-RR */ "ロライマ",
        /*   BR-RO */ "ロンドニア",
        /*   BR-SP */ "サンパウロ",
        /*   BR-PI */ "ピアウイ",
        /*   BR-TO */ "トカンチンス",
        /*   BR-RS */ "リオグランデ・ド・スル",
        /*   BR-MA */ "マラニャン州",
        /*   BR-GO */ "ゴイアス州",
        /*   BR-MS */ "マット・グロッソ・ド・スル",
        /*   BR-BA */ "バイア州",
        /*   BR-MG */ "ミナスジェライス州",
        /*   BR-MT */ "マトグロッソ州",
        /*   BR-PA */ "パラ",
        /*   BR-AM */ "アマゾナス",
        /*   US-DC */ "アラスカ州",
        /*   US-RI */ "ロードアイランド州",
        /*   US-DE */ "デラウェア州",
        /*   US-CT */ "コネティカット州",
        /*   US-NJ */ "ニュージャージー州",
        /*   US-NH */ "ニューハンプシャー州",
        /*   US-VT */ "バーモント州",
        /*   US-MA */ "マサチューセッツ州",
        /*   US-HI */ "ハワイ州",
        /*   US-MD */ "メリーランド州",
        /*   US-WV */ "ウェストバージニア州",
        /*   US-SC */ "サウスカロライナ州",
        /*   US-ME */ "メイン州",
        /*   US-IN */ "インディアナ州",
        /*   US-KY */ "ケンタッキー州",
        /*   US-TN */ "テネシー州",
        /*   US-VA */ "バージニア州",
        /*   US-OH */ "オハイオ州",
        /*   US-PA */ "ペンシルベニア州",
        /*   US-MS */ "ミシシッピ州",
        /*   US-LA */ "ルイジアナ州",
        /*   US-AL */ "アラバマ州",
        /*   US-AR */ "アーカンソー州",
        /*   US-NC */ "ノースカロライナ州",
        /*   US-NY */ "ニューヨーク州",
        /*   US-IA */ "アイオワ州",
        /*   US-IL */ "イリノイ州",
        /*   US-GA */ "ジョージア",
        /*   US-WI */ "ウィスコンシン州",
        /*   US-FL */ "フロリダ州",
        /*   US-MO */ "ミズーリ州",
        /*   US-OK */ "オクラホマ州",
        /*   US-ND */ "ノースダコタ州",
        /*   US-WA */ "ワシントン州",
        /*   US-SD */ "サウスダコタ州",
        /*   US-NE */ "ネブラスカ州",
        /*   US-KS */ "カンザス州",
        /*   US-ID */ "アイダホ州",
        /*   US-UT */ "ユタ州",
        /*   US-MN */ "ミネソタ州",
        /*   US-MI */ "ミシガン州",
        /*   US-WY */ "ワイオミング州",
        /*   US-OR */ "オレゴン州",
        /*   US-CO */ "コロラド州",
        /*   US-NV */ "ネバダ州",
        /*   US-AZ */ "アリゾナ州",
        /*   US-NM */ "ニューメキシコ州",
        /*   US-MT */ "モンタナ州",
        /*   US-CA */ "カリフォルニア州",
        /*   US-TX */ "テキサス州",
        /*   US-AK */ "アラスカ州",
        /*   CA-BC */ "ブリティッシュコロンビア",
        /*   CA-AB */ "アルバータ州",
        /*   CA-ON */ "オンタリオ",
        /*   CA-QC */ "ケベック",
        /*   CA-SK */ "サスカチュワン州",
        /*   CA-MB */ "マニトバ州",
        /*   CA-NL */ "ニューファンドランド島",
        /*   CA-NB */ "ニューブランズウィック",
        /*   CA-NS */ "ノバスコシア州",
        /*   CA-PE */ "プリンスエドワードアイランド",
        /*   CA-YT */ "ユーコン州",
        /*   CA-NT */ "ノースウェスト準州",
        /*   CA-NU */ "ヌナブト",
        /*     IND */ "インド",
        /*     AUS */ "オーストラリア",
        /*     BRA */ "ブラジル",
        /*     USA */ "アメリカ|米国|アメリカ合衆国",
        /*     MEX */ "メキシコ",
        /*     MOW */ "モスクワ",
        /*     SPE */ "セントピーターズバーグ",
        /*     KGD */ "カリーニングラード州",
        /*   RU-IN */ "イングーシ共和国",
        /*   RU-AD */ "アディゲ共和国共和国",
        /*   RU-SE */ "北オセチア共和国共和国",
        /*   RU-KB */ "カバルダ・バルカル共和国",
        /*   RU-KC */ "カラチャイ-Cherkess共和国",
        /*   RU-CE */ "チェチェン共和国",
        /*   RU-CU */ "チュヴァシュ共和国",
        /*     IVA */ "イヴァノヴォ州",
        /*     LIP */ "リペツク州",
        /*     ORL */ "オリョール州",
        /*     TUL */ "トゥーラ州",
        /*   RU-BE */ "ベルゴロド州",
        /*     VLA */ "ヴラジーミル州",
        /*     KRS */ "クルスク州",
        /*     KLU */ "カルーガ州",
        /*   RU-TT */ "タンボフ州",
        /*     BRY */ "ブリャンスク州",
        /*     YAR */ "ヤロスラヴリ州",
        /*     RYA */ "リャザン州",
        /*     AST */ "アストラハン州",
        /*     MOS */ "モスクワ州",
        /*     SMO */ "スモレンスク州",
        /*   RU-DA */ "ダゲスタン共和国",
        /*     VOR */ "ヴォロネジ州",
        /*     NGR */ "ノヴゴロド州",
        /*     PSK */ "プスコフ州",
        /*     KOS */ "コストロマ州",
        /*     STA */ "スタヴロポリ地方",
        /*     KDA */ "クラスノダール地方",
        /*   RU-KL */ "カルムイク共和国",
        /*     TVE */ "トヴェリ州",
        /*     LEN */ "レニングラード州",
        /*     ROS */ "ロストフ州",
        /*     VGG */ "ヴォルゴグラード州",
        /*     VLG */ "ヴォログダ州",
        /*     MUR */ "ムルマンスク州",
        /*   RU-KR */ "カレリア共和国",
        /*     NEN */ "ネネツ自治管区",
        /*   RU-KO */ "コミ共和国",
        /*     ARK */ "アルハンゲリスク州",
        /*   RU-MO */ "モルドヴィア共和国",
        /*     NIZ */ "ニジニ・ノヴゴロド州",
        /*     PNZ */ "ペンザ州",
        /*   RU-KI */ "キーロフ州",
        /*   RU-ME */ "マリ・エル共和国共和国",
        /*     ORE */ "オレンブルク州",
        /*     ULY */ "ウリヤノフスク州",
        /*   RU-PM */ "ペルミ地方",
        /*   RU-BA */ "バシコルトスタン共和国",
        /*   RU-UD */ "ウドムルト共和国",
        /*   RU-TA */ "タタルスタン共和国",
        /*     SAM */ "サマラ州",
        /*     SAR */ "サラトフ州",
        /*     YAN */ "ヤマロ・ネネツ自治管区",
        /*   RU-KM */ "ハンティ・マンシ",
        /*     SVE */ "スヴェルドロフスク州",
        /*     TYU */ "チュメニ州",
        /*     KGN */ "クルガン州",
        /*   RU-CH */ "チェリャビンスク州",
        /*   RU-BU */ "ブリヤート共和国",
        /*     ZAB */ "ザバイカリエ地方",
        /*     IRK */ "イルクーツク州",
        /*     NVS */ "ノヴォシビルスク州",
        /*     TOM */ "トムスク州",
        /*     OMS */ "オムスク州",
        /*   RU-KK */ "ハカス共和国共和国",
        /*     KEM */ "ケメロヴォ州",
        /*   RU-AL */ "アルタイ共和国",
        /*     ALT */ "アルタイ地方",
        /*   RU-TY */ "トゥヴァ共和国",
        /*     KYA */ "クラスノヤルスク地方",
        /*     MAG */ "マガダン州",
        /*     CHU */ "チュクチ管区",
        /*     KAM */ "カムチャツカ地方",
        /*     SAK */ "サハリン州",
        /*   RU-PO */ "沿海州",
        /*     YEV */ "ユダヤ自治州",
        /*     KHA */ "ハバロフスク地方",
        /*     AMU */ "アムール州",
        /*   RU-SA */ "サハ共和国|ヤクート共和国",
        /*     CAN */ "カナダ",
        /*     RUS */ "ロシア",
        /*   CN-SH */ "上海",
        /*   CN-TJ */ "天津",
        /*   CN-BJ */ "北京",
        /*   CN-HI */ "海南",
        /*   CN-NX */ "寧夏ホイ",
        /*   CN-CQ */ "重慶市",
        /*   CN-ZJ */ "浙江省",
        /*   CN-JS */ "江蘇省",
        /*   CN-FJ */ "福建省",
        /*   CN-AH */ "安徽省",
        /*   CN-LN */ "遼寧",
        /*   CN-SD */ "山東省",
        /*   CN-SX */ "山西",
        /*   CN-JX */ "江西省",
        /*   CN-HA */ "河南省",
        /*   CN-GZ */ "貴州省",
        /*   CN-GD */ "広東",
        /*   CN-HB */ "湖北省",
        /*   CN-JL */ "吉林",
        /*   CN-HE */ "河北省",
        /*   CN-SN */ "陝西",
        /*   CN-NM */ "内モンゴル|内蒙古",
        /*   CN-HL */ "黒竜江省",
        /*   CN-HN */ "湖南省",
        /*   CN-GX */ "広西チワン族自治区",
        /*   CN-SC */ "四川省",
        /*   CN-YN */ "雲南",
        /*   CN-XZ */ "西蔵|チベット",
        /*   CN-GS */ "甘粛省",
        /*   CN-QH */ "青海",
        /*   CN-XJ */ "新疆ウイグル",
        /*     CHN */ "中国",
        /*     UMI */ "アメリカ合衆国外諸島",
        /*     CPT */ "クリッパートン島",
        /*     ATA */ "南極大陸",
        /*     AAA */ "インターナショナル|世界|地球"
#else // MAPCODE_SUPPORT_LANGUAGE_JA
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_JA
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_JA_H__
