/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_BE_H__
#define __INTERNAL_TERRITORY_NAMES_BE_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_BE[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_BE // Belarussian
        /*     VAT */ "Горад Ватыкан|Святы Пасад",
        /*     MCO */ "Манака",
        /*     GIB */ "Гібралтар",
        /*     TKL */ "Такелаў",
        /*     CCK */ "Какосавыя астравы|Кілінг выспы",
        /*     BLM */ "Сен-Бартэльмі",
        /*     NRU */ "Науру",
        /*     TUV */ "Тувалу",
        /*     MAC */ "Макао",
        /*     SXM */ "Сінт-Маартен",
        /*     MAF */ "Сен-Мартэн",
        /*     NFK */ "Норфолк і Філіп-Айлэнд|Філіп-Айлэнд",
        /*     PCN */ "Піткэрн",
        /*     BVT */ "востраў Буве",
        /*     BMU */ "Бэрмудзкія выспы",
        /*     IOT */ "Брытанская тэрыторыя ў Індыйскім акіяне",
        /*     SMR */ "Сан - Марына",
        /*     GGY */ "Гернсі",
        /*     AIA */ "Ангілья",
        /*     MSR */ "Мансерат",
        /*     JEY */ "Джэрсі",
        /*     CXR */ "востраў каляд",
        /*     WLF */ "Уоліс і Футуна|Паўднёвая Афрыка",
        /*     VGB */ "Брытанскія Віргінскія астравы|Віргінскія выспы, брытанскія",
        /*     LIE */ "Ліхтэнштэйн",
        /*     ABW */ "Аруба",
        /*     MHL */ "Маршалавы выспы",
        /*     ASM */ "Амерыканскае Самоа|Самоа, амерыканскае",
        /*     COK */ "выспы Кука",
        /*     SPM */ "Сен-П`ер і Міквэлон|Міквэлон",
        /*     NIU */ "Ніуе",
        /*     KNA */ "Сэнт-Кітс і Нэвіс|Нэвіс",
        /*     CYM */ "Кайманавы выспы",
        /*     BES */ "Бонайре, Сэнт-Эстатиус і Саба|Саба|Сэнт-Эстатиус",
        /*     MDV */ "Мальдывы",
        /*     SHN */ "Святой Алены, Ушэсця і Трыстан-да-Кунья|Ушэсце|Трыстан-да-Кунья",
        /*     MLT */ "Мальта",
        /*     GRD */ "Грэнада",
        /*     VIR */ "Амерыканскія Віргінскія астравы|Віргінскія выспы, ЗША",
        /*     MYT */ "Маёта",
        /*     SJM */ "Шпіцбэрген і Ян-Майен|Ян-Майен",
        /*     VCT */ "Сэнт-Вінсэнт і Грэнадыны|Грэнадыны",
        /*     HMD */ "Востраў Херд і выспы Макдональд|Макдональд",
        /*     BRB */ "Барбадас",
        /*     ATG */ "Антыгуа і Барбуда|Барбуда",
        /*     CUW */ "лікёр Кюрасо",
        /*     SYC */ "Сейшэльскія выспы",
        /*     PLW */ "Палаў",
        /*     MNP */ "Паўночныя Марыянскія астравы",
        /*     AND */ "Андора",
        /*     GUM */ "Гуам",
        /*     IMN */ "востраў Мэн",
        /*     LCA */ "Сэнт-Люсія",
        /*     FSM */ "Мікранезія|Фэдэратыўныя Штаты Мікранэзіі",
        /*     SGP */ "Сінгапур",
        /*     TON */ "Тангійская",
        /*     DMA */ "Дамініка",
        /*     BHR */ "Бахрэйн",
        /*     KIR */ "Кірыбаці",
        /*     TCA */ "Астравы Тэркс і Кайкас|Кайкас",
        /*     STP */ "Сан-Томе і Прынсэп|Прынсэп",
        /*     HKG */ "Ганконг",
        /*     MTQ */ "Марцініка",
        /*     FRO */ "Фарэрскія выспы",
        /*     GLP */ "Гвадэлупа",
        /*     COM */ "Каморскія выспы",
        /*     MUS */ "Маўрыкій",
        /*     REU */ "ўз`яднанне",
        /*     LUX */ "Люксембург",
        /*     WSM */ "Самоа",
        /*     SGS */ "Паўднёвая Джорджыя і Паўднёвыя Сандвічавы астравы|Паўднёвыя Сэндвічавыя выспы",
        /*     PYF */ "Французская Палінезія",
        /*     CPV */ "Каба-Вэрдэ",
        /*     TTO */ "Трынідад і Табага|Табага",
        /*     BRN */ "Бруней",
        /*     ATF */ "Французскія Паўднёвыя і антарктычных зямлі",
        /*     PRI */ "Пуэрта-Рыка",
        /*     CYP */ "Кіпр",
        /*     LBN */ "Ліван",
        /*     JAM */ "Ямайка",
        /*     GMB */ "Гамбія",
        /*     QAT */ "Катар",
        /*     FLK */ "Фалклендскія астравы",
        /*     VUT */ "Вануату",
        /*     MNE */ "Чарнагорыя",
        /*     BHS */ "Багамскія а-вы",
        /*     TLS */ "усходні Тымор",
        /*     SWZ */ "Свазіленд",
        /*     KWT */ "Кувейт",
        /*     FJI */ "Фіджы|выспы Фіджы",
        /*     NCL */ "Новая Каледонія",
        /*     SVN */ "Славенія",
        /*     ISR */ "Ізраіль",
        /*     PSE */ "палестынскія тэрыторыі",
        /*     SLV */ "Сальвадор",
        /*     BLZ */ "Беліз",
        /*     DJI */ "Джыбуці",
        /*     MKD */ "Македонія",
        /*     RWA */ "Руанда",
        /*     HTI */ "Гаіці",
        /*     BDI */ "Бурундзі",
        /*     GNQ */ "экватарыяльная Гвінея",
        /*     ALB */ "Албанія",
        /*     SLB */ "Саламонавы выспы",
        /*     ARM */ "Арменія",
        /*     LSO */ "Лесота",
        /*     BEL */ "Бельгія",
        /*     MDA */ "Малдова",
        /*     GNB */ "Гвінея-Бісау",
        /*     TWN */ "Тайвань",
        /*     BTN */ "Бутан",
        /*     CHE */ "Швейцарыя",
        /*     NLD */ "Нідэрланды",
        /*     DNK */ "Данія",
        /*     EST */ "Эстонія",
        /*     DOM */ "Дамініканская Рэспубліка",
        /*     SVK */ "Славакія",
        /*     CRI */ "Коста-Рыка",
        /*     BIH */ "Боснія і Герцагавіна",
        /*     HRV */ "Харватыя",
        /*     TGO */ "Таго",
        /*     LVA */ "Латвія",
        /*     LTU */ "Літва",
        /*     LKA */ "Шры Ланка",
        /*     GEO */ "Грузія",
        /*     IRL */ "Ірландыя",
        /*     SLE */ "Сьера-Леонэ",
        /*     PAN */ "панама",
        /*     CZE */ "Чэская Рэспубліка",
        /*     GUF */ "Французская Гвіяна",
        /*     ARE */ "Аб`яднаныя Арабскія Эміраты",
        /*     AUT */ "Аўстрыя",
        /*     AZE */ "Азербайджан",
        /*     SRB */ "Сербія",
        /*     JOR */ "Іарданія",
        /*     PRT */ "Партугалія",
        /*     HUN */ "Венгрыя",
        /*     KOR */ "Паўднёвая Карэя",
        /*     ISL */ "Ісландыя",
        /*     GTM */ "Гватэмала",
        /*     CUB */ "куба",
        /*     BGR */ "Балгарыя",
        /*     LBR */ "Ліберыя",
        /*     HND */ "Гандурас",
        /*     BEN */ "Бенін",
        /*     ERI */ "Эрытрэя",
        /*     MWI */ "Малаві",
        /*     PRK */ "Паўночная Карэя",
        /*     NIC */ "Нікарагуа",
        /*     GRC */ "Грэцыя",
        /*     TJK */ "Таджыкістан",
        /*     BGD */ "Бангладэш",
        /*     NPL */ "Непал",
        /*     TUN */ "Туніс",
        /*     SUR */ "Сурынам",
        /*     URY */ "Уругвай",
        /*     KHM */ "Камбоджа",
        /*     SYR */ "Сірыя",
        /*     SEN */ "Сенегал",
        /*     KGZ */ "Кіргізія",
        /*     BLR */ "Беларусь",
        /*     GUY */ "Гаяна",
        /*     LAO */ "Лаос",
        /*     ROU */ "Румынія",
        /*     GHA */ "Гана",
        /*     UGA */ "Уганда",
        /*     GBR */ "Злучанае Каралеўства|Шатландыя|Вялікабрытанія|Паўночная Ірландыя|Ірландыя, Паўночная",
        /*     GIN */ "Гвінея",
        /*     ECU */ "Эквадор",
        /*     ESH */ "Заходняя Сахара|сахрави",
        /*     GAB */ "Габон",
        /*     NZL */ "Новая Зеландыя",
        /*     BFA */ "Буркіна-Фасо",
        /*     PHL */ "Філіпіны",
        /*     ITA */ "Італія",
        /*     OMN */ "Аман",
        /*     POL */ "Польшча",
        /*     CIV */ "Бераг Слановай Косці",
        /*     NOR */ "Нарвегія",
        /*     MYS */ "Малайзія",
        /*     VNM */ "В`етнам",
        /*     FIN */ "Фінляндыя",
        /*     COG */ "Конга-Бразавіль",
        /*     DEU */ "Германія",
        /*     JPN */ "Японія",
        /*     ZWE */ "Зімбабвэ",
        /*     PRY */ "Парагвай",
        /*     IRQ */ "Ірак",
        /*     MAR */ "Марока",
        /*     UZB */ "Узбекістан",
        /*     SWE */ "Швецыя",
        /*     PNG */ "Папуа-Новая Гвінея",
        /*     CMR */ "Камерун",
        /*     TKM */ "Туркменістан",
        /*     ESP */ "Іспанія",
        /*     THA */ "Тайланд",
        /*     YEM */ "Емен",
        /*     FRA */ "Францыя",
        /*     ALA */ "Аландскія астравы",
        /*     KEN */ "Кенія",
        /*     BWA */ "Батсвана",
        /*     MDG */ "Мадагаскар",
        /*     UKR */ "Украіна",
        /*     SSD */ "паўднёвы Судан",
        /*     CAF */ "Цэнтральна-Афрыканская Рэспубліка",
        /*     SOM */ "Самалі",
        /*     AFG */ "Афганістан",
        /*     MMR */ "М`янма|Бірма",
        /*     ZMB */ "Замбія",
        /*     CHL */ "чылі",
        /*     TUR */ "Турцыя",
        /*     PAK */ "Пакістан",
        /*     MOZ */ "Мазамбік",
        /*     NAM */ "Намібія",
        /*     VEN */ "Венесуэла",
        /*     NGA */ "Нігерыя",
        /*     TZA */ "Танзанія",
        /*     EGY */ "Егіпет",
        /*     MRT */ "Маўрытанія",
        /*     BOL */ "Балівія",
        /*     ETH */ "Эфіопія",
        /*     COL */ "Калумбія",
        /*     ZAF */ "Паўднёвая Афрыка",
        /*     MLI */ "Малі",
        /*     AGO */ "Ангола",
        /*     NER */ "Нігер",
        /*     TCD */ "Чад",
        /*     PER */ "Перу",
        /*     MNG */ "Манголія",
        /*     IRN */ "Іран",
        /*     LBY */ "Лівія",
        /*     SDN */ "Судан",
        /*     IDN */ "Інданезія",
        /*     DIF */ "федэральная акруга",
        /*     TLA */ "Тлашкала",
        /*     MOR */ "Морелос",
        /*     AGU */ "Агуаскальентес",
        /*   MX-CL */ "Колима",
        /*     QUE */ "Керетаро",
        /*     HID */ "Ідальга",
        /*   MX-MX */ "штат Мексіка",
        /*     TAB */ "табаско",
        /*     NAY */ "Наярит",
        /*     GUA */ "Гуанахуато",
        /*     PUE */ "Пуэбла",
        /*     YUC */ "Юкатан",
        /*     ROO */ "Кінта-РГА",
        /*     SIN */ "Сіналоа",
        /*     CAM */ "Кампече",
        /*     MIC */ "Мічаакан",
        /*     SLP */ "Сан - Луіс-Потоси",
        /*     GRO */ "Герэра",
        /*     NLE */ "Нуэво-Леон",
        /*     BCN */ "ніжняя Каліфорнія",
        /*     VER */ "Веракрус",
        /*     CHP */ "Ч`япас",
        /*     BCS */ "Паўднёвая Ніжняя Каліфорнія",
        /*     ZAC */ "Сакатекас",
        /*     JAL */ "Халиско",
        /*     TAM */ "Тамаулипас",
        /*     OAX */ "Оахака",
        /*     DUR */ "Дуранго",
        /*     COA */ "Коахуила",
        /*     SON */ "Санора",
        /*     CHH */ "чыхуахуа",
        /*     GRL */ "Грэнландыя",
        /*     SAU */ "Саўдаўская Аравія",
        /*     COD */ "Конга-Кіншаса",
        /*     DZA */ "Алжыр",
        /*     KAZ */ "Казахстан",
        /*     ARG */ "Аргенціна",
        /*   IN-DD */ "Даман і дзі",
        /*   IN-DN */ "Дадра і Нагархавели",
        /*   IN-CH */ "Чандыгарх",
        /*   IN-AN */ "Андаманскія і Никобарские",
        /*   IN-LD */ "Лакшадвип",
        /*   IN-DL */ "Дэлі",
        /*   IN-ML */ "Мегхалая",
        /*   IN-NL */ "Нагаленд",
        /*   IN-MN */ "Маніпур",
        /*   IN-TR */ "Трипура",
        /*   IN-MZ */ "Мизорам",
        /*   IN-SK */ "Сикким",
        /*   IN-PB */ "Пенджаб",
        /*   IN-HR */ "Хар`яна",
        /*   IN-AR */ "Аруначал-Прадэш",
        /*   IN-AS */ "Асам",
        /*   IN-BR */ "Біхар",
        /*   IN-UT */ "Уттаракханд",
        /*   IN-GA */ "гоа",
        /*   IN-KL */ "Керала",
        /*   IN-TN */ "Тамілнад",
        /*   IN-HP */ "Хімачал-Прадэш",
        /*   IN-JK */ "Джаму і Кашмір",
        /*   IN-CT */ "Чхаттысгарха",
        /*   IN-JH */ "Джаркханд",
        /*   IN-KA */ "Карнатака",
        /*   IN-RJ */ "Раджастхан",
        /*   IN-OR */ "Арыса",
        /*   IN-GJ */ "Гуджарат",
        /*   IN-WB */ "Заходняя Бенгалія",
        /*   IN-MP */ "Мадх`я-Прадэш",
        /*   IN-TG */ "Телингана",
        /*   IN-AP */ "Андхра-Прадэш",
        /*   IN-MH */ "Махараштра",
        /*   IN-UP */ "Утар-Прадэш",
        /*   IN-PY */ "Пондичерри",
        /*     NSW */ "Новы Паўднёвы Уэльс",
        /*     ACT */ "Аўстралійская сталічная тэрыторыя",
        /*     JBT */ "Тэрыторыя Джэрвіс-Бі",
        /*   AU-NT */ "Паўночная тэрыторыя",
        /*   AU-SA */ "Паўднёвая Аўстралія",
        /*     TAS */ "Тасманія",
        /*     VIC */ "Вікторыя",
        /*   AU-WA */ "Заходняя Аўстралія",
        /*     QLD */ "Квінсленд",
        /*   BR-DF */ "федэральная акруга",
        /*   BR-SE */ "Сержипи",
        /*   BR-AL */ "Алагоас",
        /*   BR-RJ */ "Рыа-дэ-Жанейра",
        /*   BR-ES */ "Эсьпірыту-Санта",
        /*   BR-RN */ "Рыа-Грандэ-ду-Норте",
        /*   BR-PB */ "Параибы",
        /*   BR-SC */ "Санта-Катарына",
        /*   BR-PE */ "Пернамбуку",
        /*   BR-AP */ "Амапа",
        /*   BR-CE */ "Сеара",
        /*   BR-AC */ "Акры",
        /*   BR-PR */ "Парана",
        /*   BR-RR */ "Рорайма",
        /*   BR-RO */ "Рондония",
        /*   BR-SP */ "Сан-Паўлу",
        /*   BR-PI */ "Пиауи",
        /*   BR-TO */ "Токантинс",
        /*   BR-RS */ "Рыа-Грандэ-ду-Сул",
        /*   BR-MA */ "Мараньян",
        /*   BR-GO */ "Гаяс",
        /*   BR-MS */ "Мату-Гросу-ду-Сул",
        /*   BR-BA */ "Баия",
        /*   BR-MG */ "Мінас-Жерайс",
        /*   BR-MT */ "Мату-Гросу",
        /*   BR-PA */ "пара",
        /*   BR-AM */ "Амазонас",
        /*   US-DC */ "Федэральная акруга Калумбія",
        /*   US-RI */ "Род-Айлэнд",
        /*   US-DE */ "Дэлавэр",
        /*   US-CT */ "Канэктыкут",
        /*   US-NJ */ "Нью-Джэрсі",
        /*   US-NH */ "Нью-Гэмпшыр",
        /*   US-VT */ "Вермонт",
        /*   US-MA */ "Масачусэтс",
        /*   US-HI */ "Гаваі",
        /*   US-MD */ "Мэрыленд",
        /*   US-WV */ "Заходняя Вірджынія",
        /*   US-SC */ "Паўднёвая Караліна",
        /*   US-ME */ "мэн",
        /*   US-IN */ "Індыяна",
        /*   US-KY */ "Кентукі",
        /*   US-TN */ "Тэнэсі",
        /*   US-VA */ "Віргінія",
        /*   US-OH */ "Агаё",
        /*   US-PA */ "Пэнсыльванія",
        /*   US-MS */ "Місісіпі",
        /*   US-LA */ "Луізіяна",
        /*   US-AL */ "Алабама",
        /*   US-AR */ "Арканзас",
        /*   US-NC */ "Паўночная Караліна",
        /*   US-NY */ "Нью-Ёрк",
        /*   US-IA */ "Аёва",
        /*   US-IL */ "Ілінойс",
        /*   US-GA */ "Грузія",
        /*   US-WI */ "Вісконсін",
        /*   US-FL */ "Фларыда",
        /*   US-MO */ "Місуры",
        /*   US-OK */ "Аклахома",
        /*   US-ND */ "Паўночная Дакота",
        /*   US-WA */ "Вашынгтон",
        /*   US-SD */ "Паўднёвая Дакота",
        /*   US-NE */ "Небраска",
        /*   US-KS */ "Канзас",
        /*   US-ID */ "Айдаха",
        /*   US-UT */ "Юта",
        /*   US-MN */ "Мінесота",
        /*   US-MI */ "Мічыган",
        /*   US-WY */ "Ваёмінг",
        /*   US-OR */ "Арэгон",
        /*   US-CO */ "Каларада",
        /*   US-NV */ "Невада",
        /*   US-AZ */ "Арызона",
        /*   US-NM */ "Нью-Мексіка",
        /*   US-MT */ "Мантана",
        /*   US-CA */ "Каліфорнія",
        /*   US-TX */ "Тэхас",
        /*   US-AK */ "Аляска",
        /*   CA-BC */ "брытанская Калумбія",
        /*   CA-AB */ "Альберта",
        /*   CA-ON */ "Антарыё",
        /*   CA-QC */ "Квебек",
        /*   CA-SK */ "Саскачеван",
        /*   CA-MB */ "Манітобы",
        /*   CA-NL */ "ньюфаўндленд",
        /*   CA-NB */ "Нью-Брансўік",
        /*   CA-NS */ "Новая Шатландыя",
        /*   CA-PE */ "Востраў Прынца Эдуарда",
        /*   CA-YT */ "Юкон",
        /*   CA-NT */ "паўночна-заходнія тэрыторыі",
        /*   CA-NU */ "Нунавут",
        /*     IND */ "Індыя",
        /*     AUS */ "Аўстралія",
        /*     BRA */ "Бразілія",
        /*     USA */ "ЗША|Злучаныя Штаты Амерыкі|Амерыка",
        /*     MEX */ "Мексіка",
        /*     MOW */ "Масква",
        /*     SPE */ "Санкт-Пецярбург",
        /*     KGD */ "Калінінградская вобласць",
        /*   RU-IN */ "Рэспубліка Інгушэція",
        /*   RU-AD */ "Рэспубліка Адыгея",
        /*   RU-SE */ "Паўночная Асеція-Аланія",
        /*   RU-KB */ "Кабардзіна-Балкарыя Рэспубліка",
        /*   RU-KC */ "Карачаева-Чаркеская Рэспубліка",
        /*   RU-CE */ "чачэнская Рэспубліка",
        /*   RU-CU */ "Чувашская Рэспубліка",
        /*     IVA */ "Іванаўская вобласць",
        /*     LIP */ "Ліпецкая вобласць",
        /*     ORL */ "Арлоўская вобласць",
        /*     TUL */ "Тульская вобласць",
        /*   RU-BE */ "Белгародская вобласць",
        /*     VLA */ "Уладзімірская вобласьць",
        /*     KRS */ "Курская вобласць",
        /*     KLU */ "Калужская вобласць",
        /*   RU-TT */ "Тамбоўская вобласць",
        /*     BRY */ "Бранская вобласць",
        /*     YAR */ "Яраслаўская вобласць",
        /*     RYA */ "Разанская вобласьць",
        /*     AST */ "Астраханская вобласць",
        /*     MOS */ "маскоўская вобласць",
        /*     SMO */ "Смаленская вобласць",
        /*   RU-DA */ "Рэспубліка Дагестан",
        /*     VOR */ "Варонежская вобласць",
        /*     NGR */ "Наўгародская вобласць",
        /*     PSK */ "Пскоўская вобласць",
        /*     KOS */ "Кастрамская вобласць",
        /*     STA */ "Стаўрапольскі край",
        /*     KDA */ "Краснадарскі край",
        /*   RU-KL */ "Рэспубліка Калмыкія",
        /*     TVE */ "Цвярская вобласць",
        /*     LEN */ "Ленінградская вобласць",
        /*     ROS */ "Растоўская вобласць",
        /*     VGG */ "Валгаградская вобласць",
        /*     VLG */ "Валагодская вобласць",
        /*     MUR */ "Мурманская вобласць",
        /*   RU-KR */ "Рэспубліка Карэлія",
        /*     NEN */ "Ненецкая аўтаномная акруга",
        /*   RU-KO */ "Рэспубліка Комі",
        /*     ARK */ "Архангельская вобласць",
        /*   RU-MO */ "Рэспубліка Мардовія",
        /*     NIZ */ "Ніжагародская вобласць",
        /*     PNZ */ "Пензенская вобласць",
        /*   RU-KI */ "Кіраўская вобласць",
        /*   RU-ME */ "Рэспубліка Марый Эл",
        /*     ORE */ "Арэнбургская вобласць",
        /*     ULY */ "Ульянаўская вобласць",
        /*   RU-PM */ "Пермскі край",
        /*   RU-BA */ "Рэспубліка Башкартастан",
        /*   RU-UD */ "Удмурцкая Рэспубліка",
        /*   RU-TA */ "Рэспубліка Татарстан",
        /*     SAM */ "Самарская вобласць",
        /*     SAR */ "Саратаўская вобласць",
        /*     YAN */ "Ямала-Ненецкая",
        /*   RU-KM */ "Ханты-Мансійская",
        /*     SVE */ "Свярдлоўская вобласць",
        /*     TYU */ "Цюменская вобласць",
        /*     KGN */ "Курганская вобласць",
        /*   RU-CH */ "Чэлябінская вобласць",
        /*   RU-BU */ "Рэспубліка Бурація",
        /*     ZAB */ "Забайкальскі край",
        /*     IRK */ "Іркуцкая вобласць",
        /*     NVS */ "новасібірская вобласць",
        /*     TOM */ "Томская вобласць",
        /*     OMS */ "Омская вобласць",
        /*   RU-KK */ "Рэспубліка Хакасія",
        /*     KEM */ "Кемераўская вобласць",
        /*   RU-AL */ "Рэспубліка Алтай",
        /*     ALT */ "Алтайскі край",
        /*   RU-TY */ "Рэспубліка Тыва",
        /*     KYA */ "Краснаярскі край",
        /*     MAG */ "Магаданская вобласць",
        /*     CHU */ "Чукоцкая акруга",
        /*     KAM */ "Камчацкі край",
        /*     SAK */ "Сахалінская вобласць",
        /*   RU-PO */ "прыморскі край",
        /*     YEV */ "Яўрэйская аўтаномная вобласць",
        /*     KHA */ "Хабараўскі край",
        /*     AMU */ "Амурская вобласць",
        /*   RU-SA */ "Рэспубліка Саха|Якуція",
        /*     CAN */ "Канада",
        /*     RUS */ "Расія",
        /*   CN-SH */ "Шанхай",
        /*   CN-TJ */ "Цяньцзінь",
        /*   CN-BJ */ "Пекін",
        /*   CN-HI */ "Хайнань",
        /*   CN-NX */ "Нінся-Хуэйский",
        /*   CN-CQ */ "Чунцын",
        /*   CN-ZJ */ "Чжэцзян",
        /*   CN-JS */ "Цзянсу",
        /*   CN-FJ */ "Фуцзянь",
        /*   CN-AH */ "Аньхой",
        /*   CN-LN */ "Ляанін",
        /*   CN-SD */ "Шаньдун",
        /*   CN-SX */ "Шаньсі",
        /*   CN-JX */ "Цзянсу",
        /*   CN-HA */ "Хэнань",
        /*   CN-GZ */ "Гуйчжоу",
        /*   CN-GD */ "Гуандун",
        /*   CN-HB */ "Хубэй",
        /*   CN-JL */ "Цзілінь",
        /*   CN-HE */ "Хэбэй",
        /*   CN-SN */ "Шэньсі",
        /*   CN-NM */ "унутраная Манголія",
        /*   CN-HL */ "Хэйлунцзян",
        /*   CN-HN */ "Хунань",
        /*   CN-GX */ "Гуансі-Чжуанскі",
        /*   CN-SC */ "Сычуань",
        /*   CN-YN */ "Юньнань",
        /*   CN-XZ */ "Тыбецкі аўтаномны раён|Тыбет",
        /*   CN-GS */ "Ганьсу",
        /*   CN-QH */ "Цынхай",
        /*   CN-XJ */ "Сіньцзян-Уйгурскі",
        /*     CHN */ "Кітай",
        /*     UMI */ "ЗША Знешнія малыя выспы",
        /*     CPT */ "востраў Кліпертан",
        /*     ATA */ "Антарктыда",
        /*     AAA */ "Міжнародны|Свет|Зямля"
#else // MAPCODE_SUPPORT_LANGUAGE_BE
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_BE
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_BE_H__
