/*
 * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __INTERNAL_TERRITORY_NAMES_AR_H__
#define __INTERNAL_TERRITORY_NAMES_AR_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_AR[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_AR // Arabic
        /*     VAT */ "الفاتيكان|مدينة الفاتيكان|الكرسي الرسولي",
        /*     MCO */ "موناكو",
        /*     GIB */ "جبل طارق",
        /*     TKL */ "توكلو",
        /*     CCK */ "جزر كوكوس",
        /*     BLM */ "سان بارتليمي",
        /*     NRU */ "ناورو",
        /*     TUV */ "توفالو",
        /*     MAC */ "ماكاو",
        /*     SXM */ "سينت مارتن",
        /*     MAF */ "سانت مارتن الفرنسية",
        /*     NFK */ "جزيرة نورفولك|فيليب ايلاند",
        /*     PCN */ "جزر بيتكيرن",
        /*     BVT */ "جزيرة بوفيه",
        /*     BMU */ "برمودا",
        /*     IOT */ "إقليم المحيط الهندي البريطاني",
        /*     SMR */ "سان مارينو",
        /*     GGY */ "غيرنزي",
        /*     AIA */ "أنغويلا",
        /*     MSR */ "مونتسرات",
        /*     JEY */ "جيرزي|جيرسي",
        /*     CXR */ "جزيرة الكريسماس",
        /*     WLF */ "الس وفوتونا|فوتونا",
        /*     VGB */ "الجزر العذراء البريطانية",
        /*     LIE */ "ليختنشتاين",
        /*     ABW */ "أروبا",
        /*     MHL */ "جزر مارشال",
        /*     ASM */ "ساموا الأمريكية",
        /*     COK */ "جزر كوك",
        /*     SPM */ "سان بيير وميكلون|ميكلون",
        /*     NIU */ "نييوي",
        /*     KNA */ "سانت كيتس ونيفيس",
        /*     CYM */ "جزر كايمان",
        /*     BES */ "الجزر الكاريبية الهولندية",
        /*     MDV */ "جزر المالديف",
        /*     SHN */ "سانت هيلينا وأسينشين وتريستان دا كونا|أسينشين|تريستان دا كونا",
        /*     MLT */ "مالطا",
        /*     GRD */ "غرناطة",
        /*     VIR */ "جزر العذراء الأمريكية",
        /*     MYT */ "مايوت",
        /*     SJM */ "سفالبارد وجان ماين|جان ماين",
        /*     VCT */ "سانت فنسنت والجرينادين|لجرينادين",
        /*     HMD */ "جزيرة هيرد وجزر ماكدونالد",
        /*     BRB */ "باربادوس",
        /*     ATG */ "أنتيغوا وباربودا|باربودا",
        /*     CUW */ "كوراساو",
        /*     SYC */ "سيشل",
        /*     PLW */ "بالاو",
        /*     MNP */ "جزر ماريانا الشمالية",
        /*     AND */ "أندورا",
        /*     GUM */ "غوام",
        /*     IMN */ "جزيرة مان",
        /*     LCA */ "سانت لوسيا",
        /*     FSM */ "ميكرونيزيا|ولايات ميكرونيسيا المتحدة",
        /*     SGP */ "سنغافورة",
        /*     TON */ "تونغا",
        /*     DMA */ "دومينيكا",
        /*     BHR */ "البحرين",
        /*     KIR */ "كيريباتي",
        /*     TCA */ "جزر توركس وكايكوس",
        /*     STP */ "ساو تومي وبرينسيب|برينسيب",
        /*     HKG */ "هونغ كونغ",
        /*     MTQ */ "مارتينيك",
        /*     FRO */ "جزر فارو",
        /*     GLP */ "غوادلوب",
        /*     COM */ "جزر القمر",
        /*     MUS */ "موريشيوس",
        /*     REU */ "لا ريونيون",
        /*     LUX */ "لوكسمبورغ",
        /*     WSM */ "ساموا",
        /*     SGS */ "جورجيا الجنوبية وجزر ساندويتش الجنوبية|جنوب جزر ساندويتش",
        /*     PYF */ "بولينزيا الفرنسية",
        /*     CPV */ "الرأس الأخضر",
        /*     TTO */ "ترينيداد وتوباغو|توباغو",
        /*     BRN */ "بروناي",
        /*     ATF */ "أراض فرنسية جنوبية وأنتارتيكية",
        /*     PRI */ "بورتوريكو",
        /*     CYP */ "قبرص",
        /*     LBN */ "لبنان",
        /*     JAM */ "جامايكا",
        /*     GMB */ "غامبيا",
        /*     QAT */ "قطر",
        /*     FLK */ "جزر فوكلاند",
        /*     VUT */ "فانواتو",
        /*     MNE */ "الجبل الأسود",
        /*     BHS */ "باهاماس",
        /*     TLS */ "تيمور الشرقية",
        /*     SWZ */ "سوازيلاند",
        /*     KWT */ "الكويت",
        /*     FJI */ "فيجي",
        /*     NCL */ "كاليدونيا الجديدة",
        /*     SVN */ "سلوفينيا",
        /*     ISR */ "إسرائيل",
        /*     PSE */ "فلسطين",
        /*     SLV */ "السلفادور",
        /*     BLZ */ "بليز",
        /*     DJI */ "جيبوتي",
        /*     MKD */ "مقدونيا",
        /*     RWA */ "رواندا",
        /*     HTI */ "هايتي",
        /*     BDI */ "بوروندي",
        /*     GNQ */ "غينيا الاستوائية",
        /*     ALB */ "ألبانيا",
        /*     SLB */ "جزر سليمان",
        /*     ARM */ "أرمينيا",
        /*     LSO */ "ليسوتو",
        /*     BEL */ "بلجيكا",
        /*     MDA */ "مولدافيا",
        /*     GNB */ "غينيا بيساو",
        /*     TWN */ "تايوان",
        /*     BTN */ "بوتان",
        /*     CHE */ "سويسرا",
        /*     NLD */ "هولندا",
        /*     DNK */ "الدنمارك",
        /*     EST */ "إستونيا",
        /*     DOM */ "جمهورية الدومينيكان",
        /*     SVK */ "سلوفاكيا",
        /*     CRI */ "كوستاريكا",
        /*     BIH */ "البوسنة والهرسك",
        /*     HRV */ "كرواتيا",
        /*     TGO */ "توغو",
        /*     LVA */ "لاتفيا",
        /*     LTU */ "ليتوانيا",
        /*     LKA */ "سريلانكا",
        /*     GEO */ "جورجيا",
        /*     IRL */ "جمهورية أيرلندا|أيرلندا",
        /*     SLE */ "سيراليون",
        /*     PAN */ "بنما",
        /*     CZE */ "جمهورية التشيك",
        /*     GUF */ "غويانا الفرنسية",
        /*     ARE */ "الإمارات العربية المتحدة",
        /*     AUT */ "النمسا",
        /*     AZE */ "أذربيجان",
        /*     SRB */ "صربيا",
        /*     JOR */ "الأردن",
        /*     PRT */ "البرتغال",
        /*     HUN */ "المجر",
        /*     KOR */ "كوريا الجنوبية",
        /*     ISL */ "آيسلندا",
        /*     GTM */ "غواتيمالا",
        /*     CUB */ "كوبا",
        /*     BGR */ "بلغاريا",
        /*     LBR */ "ليبيريا",
        /*     HND */ "هندوراس",
        /*     BEN */ "بنين",
        /*     ERI */ "إريتريا",
        /*     MWI */ "مالاوي",
        /*     PRK */ "كوريا الشمالية",
        /*     NIC */ "نيكاراغوا",
        /*     GRC */ "اليونان",
        /*     TJK */ "طاجيكستان",
        /*     BGD */ "بنغلاديش",
        /*     NPL */ "نيبال",
        /*     TUN */ "تونس",
        /*     SUR */ "سورينام",
        /*     URY */ "الأوروغواي",
        /*     KHM */ "كمبوديا",
        /*     SYR */ "سوريا",
        /*     SEN */ "السنغال",
        /*     KGZ */ "قيرغيزستان",
        /*     BLR */ "بيلاروسيا",
        /*     GUY */ "غيانا",
        /*     LAO */ "لاوس",
        /*     ROU */ "رومانيا",
        /*     GHA */ "غانا",
        /*     UGA */ "أوغندا",
        /*     GBR */ "المملكة المتحدة|اسكتلندا|بريطانيا العظمى|ايرلندا الشمالية",
        /*     GIN */ "غينيا",
        /*     ECU */ "الإكوادور",
        /*     ESH */ "الصحراء الغربية",
        /*     GAB */ "الغابون",
        /*     NZL */ "نيوزيلندا",
        /*     BFA */ "بوركينا فاسو",
        /*     PHL */ "الفلبين",
        /*     ITA */ "إيطاليا",
        /*     OMN */ "سلطنة عمان",
        /*     POL */ "بولندا",
        /*     CIV */ "ساحل العاج",
        /*     NOR */ "النرويج",
        /*     MYS */ "ماليزيا",
        /*     VNM */ "فيتنام",
        /*     FIN */ "فنلندا",
        /*     COG */ "جمهورية الكونغو",
        /*     DEU */ "ألمانيا",
        /*     JPN */ "اليابان",
        /*     ZWE */ "زيمبابوي",
        /*     PRY */ "باراغواي",
        /*     IRQ */ "العراق",
        /*     MAR */ "المغرب",
        /*     UZB */ "أوزبكستان",
        /*     SWE */ "السويد",
        /*     PNG */ "بابوا غينيا الجديدة",
        /*     CMR */ "الكاميرون",
        /*     TKM */ "تركمانستان",
        /*     ESP */ "إسبانيا",
        /*     THA */ "تايلاند",
        /*     YEM */ "اليمن",
        /*     FRA */ "فرنسا",
        /*     ALA */ "أولند|جزر آلاند",
        /*     KEN */ "كينيا",
        /*     BWA */ "بوتسوانا",
        /*     MDG */ "مدغشقر",
        /*     UKR */ "أوكرانيا",
        /*     SSD */ "جنوب السودان",
        /*     CAF */ "جمهورية أفريقيا الوسطى",
        /*     SOM */ "الصومال",
        /*     AFG */ "أفغانستان",
        /*     MMR */ "ميانمار|بورما",
        /*     ZMB */ "زامبيا",
        /*     CHL */ "تشيلي",
        /*     TUR */ "تركيا",
        /*     PAK */ "باكستان",
        /*     MOZ */ "موزمبيق",
        /*     NAM */ "ناميبيا",
        /*     VEN */ "فنزويلا",
        /*     NGA */ "نيجيريا",
        /*     TZA */ "تنزانيا",
        /*     EGY */ "مصر",
        /*     MRT */ "موريتانيا",
        /*     BOL */ "بوليفيا",
        /*     ETH */ "إثيوبيا",
        /*     COL */ "كولومبيا",
        /*     ZAF */ "جنوب أفريقيا",
        /*     MLI */ "مالي",
        /*     AGO */ "أنغولا",
        /*     NER */ "النيجر",
        /*     TCD */ "تشاد",
        /*     PER */ "بيرو",
        /*     MNG */ "منغوليا",
        /*     IRN */ "إيران",
        /*     LBY */ "ليبيا",
        /*     SDN */ "السودان",
        /*     IDN */ "إندونيسيا",
        /*     DIF */ "المقاطعة الاتحادية",
        /*     TLA */ "تلاكسكالا",
        /*     MOR */ "موريلوس",
        /*     AGU */ "اغواسكالينتيس",
        /*   MX-CL */ "كوليما",
        /*     QUE */ "كوينتانا رو",
        /*     HID */ "الهيدلج من نبلاء الأسبان",
        /*   MX-MX */ "الدولة المكسيك",
        /*     TAB */ "تاباسكو",
        /*     NAY */ "ناياريت",
        /*     GUA */ "غواناخواتو",
        /*     PUE */ "بويبلا",
        /*     YUC */ "يوكاتان",
        /*     ROO */ "كويريتارو",
        /*     SIN */ "سينالوا",
        /*     CAM */ "كامبيتشي",
        /*     MIC */ "ميتشواكان",
        /*     SLP */ "سان لويس بوتوسي",
        /*     GRO */ "غيريرو",
        /*     NLE */ "نويفو ليون",
        /*     BCN */ "باجا كاليفورنيا",
        /*     VER */ "فيراكروز",
        /*     CHP */ "تشياباس",
        /*     BCS */ "باجا كاليفورنيا سور",
        /*     ZAC */ "زاكاتيكاس",
        /*     JAL */ "خاليسكو",
        /*     TAM */ "تاماوليباس",
        /*     OAX */ "أواكساكا",
        /*     DUR */ "دورانجو",
        /*     COA */ "كواهويلا",
        /*     SON */ "سونورا",
        /*     CHH */ "تشيهواهوا",
        /*     GRL */ "غرينلاند",
        /*     SAU */ "السعودية",
        /*     COD */ "جمهورية الكونغو الديمقراطية",
        /*     DZA */ "الجزائر",
        /*     KAZ */ "كازاخستان",
        /*     ARG */ "الأرجنتين",
        /*   IN-DD */ "دامان وديو",
        /*   IN-DN */ "دادرا وناغار هافيلي",
        /*   IN-CH */ "شانديغار",
        /*   IN-AN */ "اندامان ونيكوبار",
        /*   IN-LD */ "اكشادويب",
        /*   IN-DL */ "دلهي",
        /*   IN-ML */ "ميغالايا",
        /*   IN-NL */ "ناجالاند",
        /*   IN-MN */ "مانيبور",
        /*   IN-TR */ "تريبورا",
        /*   IN-MZ */ "ميزورام",
        /*   IN-SK */ "سيكيم",
        /*   IN-PB */ "البنجاب",
        /*   IN-HR */ "هاريانا",
        /*   IN-AR */ "اروناتشال براديش",
        /*   IN-AS */ "أسام",
        /*   IN-BR */ "بيهار",
        /*   IN-UT */ "أوتارانتشال",
        /*   IN-GA */ "غوا",
        /*   IN-KL */ "ولاية كيرالا",
        /*   IN-TN */ "تاميل نادو",
        /*   IN-HP */ "هيماشال براديش",
        /*   IN-JK */ "جامو وكشمير",
        /*   IN-CT */ "تشهاتيسجاره",
        /*   IN-JH */ "جهارخاند",
        /*   IN-KA */ "كارناتاكا",
        /*   IN-RJ */ "راجستان",
        /*   IN-OR */ "أوديشا|أوريسا",
        /*   IN-GJ */ "غوجارات",
        /*   IN-WB */ "بنغال الغربية",
        /*   IN-MP */ "ماديا براديش",
        /*   IN-TG */ "تيلانجانا",
        /*   IN-AP */ "ولاية اندرا براديش",
        /*   IN-MH */ "ماهاراشترا",
        /*   IN-UP */ "ولاية اوتار براديش",
        /*   IN-PY */ "بودوتشيري",
        /*     NSW */ "نيو ساوث ويلز",
        /*     ACT */ "إقليم العاصمة الأسترالية",
        /*     JBT */ "جيرفيس خليج الأرض",
        /*   AU-NT */ "المقاطعة الشمالية",
        /*   AU-SA */ "جنوب استراليا",
        /*     TAS */ "تسمانيا",
        /*     VIC */ "فيكتوريا",
        /*   AU-WA */ "أستراليا الغربية",
        /*     QLD */ "كوينزلاند",
        /*   BR-DF */ "ديستريتو فيديرال",
        /*   BR-SE */ "سيرجيبي",
        /*   BR-AL */ "ألاغواس",
        /*   BR-RJ */ "ريو دي جانيرو",
        /*   BR-ES */ "إسبيريتو سانتو",
        /*   BR-RN */ "ريو غراندي دو نورتي",
        /*   BR-PB */ "بارايبا",
        /*   BR-SC */ "سانتا كاتارينا",
        /*   BR-PE */ "بيرنامبوكو",
        /*   BR-AP */ "أمابا",
        /*   BR-CE */ "سيارا",
        /*   BR-AC */ "أكري",
        /*   BR-PR */ "بارانا",
        /*   BR-RR */ "رورايما",
        /*   BR-RO */ "روندونيا",
        /*   BR-SP */ "ساو باولو",
        /*   BR-PI */ "بياوي",
        /*   BR-TO */ "توكانتينس",
        /*   BR-RS */ "ريو غراندي دو سول",
        /*   BR-MA */ "مارانهاو",
        /*   BR-GO */ "غوياس",
        /*   BR-MS */ "ماتو غروسو دو سول",
        /*   BR-BA */ "باهيا",
        /*   BR-MG */ "ميناس جيرايس",
        /*   BR-MT */ "ماتو غروسو",
        /*   BR-PA */ "بارا",
        /*   BR-AM */ "الأمازون",
        /*   US-DC */ "مقاطعة كولومبيا",
        /*   US-RI */ "جزيرة رود",
        /*   US-DE */ "ولاية ديلاوير",
        /*   US-CT */ "كونيتيكت",
        /*   US-NJ */ "نيو جيرسي",
        /*   US-NH */ "نيو هامبشاير",
        /*   US-VT */ "فيرمونت",
        /*   US-MA */ "ماساتشوستس",
        /*   US-HI */ "هاواي",
        /*   US-MD */ "ماريلاند",
        /*   US-WV */ "فرجينيا الغربية",
        /*   US-SC */ "كارولينا الجنوبية",
        /*   US-ME */ "مين",
        /*   US-IN */ "إنديانا",
        /*   US-KY */ "كنتاكي",
        /*   US-TN */ "تينيسي",
        /*   US-VA */ "فرجينيا",
        /*   US-OH */ "أوهايو",
        /*   US-PA */ "ولاية بنسلفانيا",
        /*   US-MS */ "ميسيسيبي",
        /*   US-LA */ "لويزيانا",
        /*   US-AL */ "ألاباما",
        /*   US-AR */ "أركنساس",
        /*   US-NC */ "شمال كارولينا",
        /*   US-NY */ "نيويورك",
        /*   US-IA */ "أيوا",
        /*   US-IL */ "إلينوي",
        /*   US-GA */ "جورجيا",
        /*   US-WI */ "ولاية ويسكونسن",
        /*   US-FL */ "فلوريدا",
        /*   US-MO */ "ميسوري",
        /*   US-OK */ "أوكلاهوما",
        /*   US-ND */ "شمال داكوتا",
        /*   US-WA */ "واشنطن",
        /*   US-SD */ "جنوب داكوتا",
        /*   US-NE */ "نبراسكا",
        /*   US-KS */ "كانساس",
        /*   US-ID */ "ايداهو",
        /*   US-UT */ "يوتا",
        /*   US-MN */ "مينيسوتا",
        /*   US-MI */ "ميشيغان",
        /*   US-WY */ "وايومنغ",
        /*   US-OR */ "ولاية أوريغون",
        /*   US-CO */ "كولورادو",
        /*   US-NV */ "نيفادا",
        /*   US-AZ */ "أريزونا",
        /*   US-NM */ "المكسيك جديدة",
        /*   US-MT */ "مونتانا",
        /*   US-CA */ "كاليفورنيا",
        /*   US-TX */ "تكساس",
        /*   US-AK */ "ألاسكا",
        /*   CA-BC */ "كولومبيا البريطانية",
        /*   CA-AB */ "ألبرتا",
        /*   CA-ON */ "أونتاريو",
        /*   CA-QC */ "كيبيك",
        /*   CA-SK */ "ساسكاتشوان",
        /*   CA-MB */ "مانيتوبا",
        /*   CA-NL */ "نيوفاوندلاند",
        /*   CA-NB */ "برونزيك جديد",
        /*   CA-NS */ "مقاطعة نفوفا سكوشيا",
        /*   CA-PE */ "جزيرة الأمير إدوارد",
        /*   CA-YT */ "يوكون",
        /*   CA-NT */ "الاقاليم الشمالية الغربية",
        /*   CA-NU */ "نونافوت",
        /*     IND */ "الهند",
        /*     AUS */ "أستراليا",
        /*     BRA */ "البرازيل",
        /*     USA */ "الولايات المتحدة الأمريكية|أمريكا",
        /*     MEX */ "المكسيك",
        /*     MOW */ "موسكو",
        /*     SPE */ "سان بطرسبورج",
        /*     KGD */ "كالينينغراد أوبلاست",
        /*   RU-IN */ "جمهورية إنغوشيا",
        /*   RU-AD */ "جمهورية أديغيا",
        /*   RU-SE */ "شمال أوسيتيا-ألانيا الجمهورية",
        /*   RU-KB */ "قبردينو بلقاريا",
        /*   RU-KC */ "كراشاي-الشركس الجمهورية",
        /*   RU-CE */ "جمهورية الشيشان",
        /*   RU-CU */ "جمهورية التشفاش",
        /*     IVA */ "إيفانوفو أوبلاست",
        /*     LIP */ "ليبيتسك أوبلاست",
        /*     ORL */ "أوريول أوبلاست",
        /*     TUL */ "تولا أوبلاست",
        /*   RU-BE */ "بيلغورود أوبلاست",
        /*     VLA */ "فلاديمير أوبلاست",
        /*     KRS */ "كورسك أوبلاست",
        /*     KLU */ "كالوغا أوبلاست",
        /*   RU-TT */ "تامبوف أوبلاست",
        /*     BRY */ "بريانسك أوبلاست",
        /*     YAR */ "ياروسلافل أوبلاست",
        /*     RYA */ "ريازان",
        /*     AST */ "أستراخان أوبلاست",
        /*     MOS */ "موسكو أوبلاست",
        /*     SMO */ "سمولينسك أوبلاست",
        /*   RU-DA */ "جمهورية داغستان",
        /*     VOR */ "فورونيج أوبلاست",
        /*     NGR */ "نوفغورود أوبلاست",
        /*     PSK */ "بسكوف أوبلاست",
        /*     KOS */ "كوستروما أوبلاست",
        /*     STA */ "ستافروبول كراي",
        /*     KDA */ "كراسنودار كراي",
        /*   RU-KL */ "جمهورية كالميكيا",
        /*     TVE */ "تفير أوبلاست",
        /*     LEN */ "لينينغراد أوبلاست",
        /*     ROS */ "روستوف",
        /*     VGG */ "فولغوغراد أوبلاست",
        /*     VLG */ "منطقة فولوغدا",
        /*     MUR */ "مورمانسك أوبلاست",
        /*   RU-KR */ "جمهورية كاريليا",
        /*     NEN */ "أوكروغ نينيتس الذاتية",
        /*   RU-KO */ "جمهورية كومي",
        /*     ARK */ "أرخانجيلسك أوبلاست",
        /*   RU-MO */ "جمهورية موردوفيا",
        /*     NIZ */ "نيجني نوفغورود أوبلاست",
        /*     PNZ */ "بانزا أوبلاست",
        /*   RU-KI */ "كيروف أوبلاست",
        /*   RU-ME */ "ماري جمهورية شركة",
        /*     ORE */ "أورينبورغ أوبلاست",
        /*     ULY */ "أوليانوفسك أوبلاست",
        /*   RU-PM */ "بيرم كراي",
        /*   RU-BA */ "جمهورية بشكيريا",
        /*   RU-UD */ "جمهورية الأدمرت",
        /*   RU-TA */ "جمهورية تتارستان",
        /*     SAM */ "سمارا أوبلاست",
        /*     SAR */ "ساراتوف أوبلاست",
        /*     YAN */ "يامالو نينتس",
        /*   RU-KM */ "خانتي المنسي",
        /*     SVE */ "سفيردلوفسك أوبلاست",
        /*     TYU */ "تيومين أوبلاست",
        /*     KGN */ "كورغان أوبلاست",
        /*   RU-CH */ "تشيليابينسك أوبلاست",
        /*   RU-BU */ "جمهورية بورياتيا",
        /*     ZAB */ "كراي عبر البايكال",
        /*     IRK */ "إيركوتسك أوبلاست",
        /*     NVS */ "نوفوسيبيرسك",
        /*     TOM */ "منطقة تومسك",
        /*     OMS */ "أومسك أوبلاست",
        /*   RU-KK */ "جمهورية خاكاسيا",
        /*     KEM */ "كيميروفو أوبلاست",
        /*   RU-AL */ "جمهورية التاي",
        /*     ALT */ "التاي كراي",
        /*   RU-TY */ "جمهورية توفا",
        /*     KYA */ "كراسنويارسك كراي",
        /*     MAG */ "ماجادان أوبلاست",
        /*     CHU */ "تشوكوتكا أوكروغ",
        /*     KAM */ "كامتشاتكا كراي",
        /*     SAK */ "ساخالين أوبلاست",
        /*   RU-PO */ "بريمورسكي كراي",
        /*     YEV */ "الأوبلاست اليهودية الذاتية",
        /*     KHA */ "خاباروفسك كراي",
        /*     AMU */ "أمور أوبلاست",
        /*   RU-SA */ "جمهورية ساخا|ياقوتيا الجمهورية",
        /*     CAN */ "كندا",
        /*     RUS */ "روسيا",
        /*   CN-SH */ "شنغهاي",
        /*   CN-TJ */ "تيانجين",
        /*   CN-BJ */ "بكين",
        /*   CN-HI */ "هاينان",
        /*   CN-NX */ "نينغشيا هوى",
        /*   CN-CQ */ "تشونغتشينغ",
        /*   CN-ZJ */ "تشجيانغ",
        /*   CN-JS */ "جيانغسو",
        /*   CN-FJ */ "فوجيان",
        /*   CN-AH */ "انهوى",
        /*   CN-LN */ "لياونينغ",
        /*   CN-SD */ "شاندونغ",
        /*   CN-SX */ "شانشى",
        /*   CN-JX */ "جيانغشى",
        /*   CN-HA */ "خنان",
        /*   CN-GZ */ "قويتشو",
        /*   CN-GD */ "قوانغدونغ",
        /*   CN-HB */ "هوبى",
        /*   CN-JL */ "جيلين",
        /*   CN-HE */ "خبى",
        /*   CN-SN */ "شنشى",
        /*   CN-NM */ "ني المغول|منغوليا الداخلية",
        /*   CN-HL */ "هيلونغجيانغ",
        /*   CN-HN */ "هونان",
        /*   CN-GX */ "قوانغشى لقومية تشوانغ",
        /*   CN-SC */ "سيتشوان",
        /*   CN-YN */ "يونان",
        /*   CN-XZ */ "زيزانغ|التبت",
        /*   CN-GS */ "قانسو",
        /*   CN-QH */ "تشينغهاى",
        /*   CN-XJ */ "شينجيانغ الويغورية",
        /*     CHN */ "الصين",
        /*     UMI */ "جزر الولايات المتحدة الصغيرة النائية",
        /*     CPT */ "جزيرة كليبرتون",
        /*     ATA */ "القارة القطبية الجنوبية",
        /*     AAA */ "دولي"
#else // MAPCODE_SUPPORT_LANGUAGE_AR
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_AR
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_AR_H__
